@@ -195,9 +195,9 @@ typedef struct {
 } hole_count_t;
 
 #include "obj_pstk_inlines.h"
-static rnd_r_dir_t hole_counting_callback(const rnd_box_t * b, void *cl)
+static rnd_rtree_dir_t hole_counting_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
-	pcb_pstk_t *ps = (pcb_pstk_t *)b;
+	pcb_pstk_t *ps = (pcb_pstk_t *)obj;
 	pcb_pstk_proto_t *proto = pcb_pstk_get_proto(ps);
 	hole_count_t *hcs = (hole_count_t *)cl;
 
@@ -207,12 +207,12 @@ static rnd_r_dir_t hole_counting_callback(const rnd_box_t * b, void *cl)
 		else
 			hcs->nunplated++;
 	}
-	return RND_R_DIR_FOUND_CONTINUE;
+	return rnd_RTREE_DIR_FOUND_CONT;
 }
 
-static rnd_r_dir_t slot_counting_callback(const rnd_box_t *b, void *cl)
+static rnd_rtree_dir_t slot_counting_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
-	pcb_pstk_t *ps = (pcb_pstk_t *)b;
+	pcb_pstk_t *ps = (pcb_pstk_t *)obj;
 	pcb_pstk_proto_t *proto = pcb_pstk_get_proto(ps);
 	hole_count_t *hcs = (hole_count_t *)cl;
 
@@ -222,14 +222,14 @@ static rnd_r_dir_t slot_counting_callback(const rnd_box_t *b, void *cl)
 		else
 			hcs->nunplated++;
 	}
-	return RND_R_DIR_FOUND_CONTINUE;
+	return rnd_RTREE_DIR_FOUND_CONT;
 }
 
 void pcb_board_count_holes(pcb_board_t *pcb, int *plated, int *unplated, const rnd_box_t *within_area)
 {
 	hole_count_t hcs = { 0, 0 };
 
-	rnd_r_search(pcb->Data->padstack_tree, within_area, NULL, hole_counting_callback, &hcs, NULL);
+	rnd_rtree_search_any(pcb->Data->padstack_tree, (rnd_rtree_box_t *)within_area, NULL, hole_counting_callback, &hcs, NULL);
 
 	if (plated != NULL)
 		*plated = hcs.nplated;
@@ -241,7 +241,7 @@ void pcb_board_count_slots(pcb_board_t *pcb, int *plated, int *unplated, const r
 {
 	hole_count_t hcs = { 0, 0 };
 
-	rnd_r_search(pcb->Data->padstack_tree, within_area, NULL, slot_counting_callback, &hcs, NULL);
+	rnd_rtree_search_any(pcb->Data->padstack_tree, (rnd_rtree_box_t *)within_area, NULL, slot_counting_callback, &hcs, NULL);
 
 	if (plated != NULL)
 		*plated = hcs.nplated;
@@ -274,8 +274,11 @@ static void pcb_board_resize_(pcb_board_t *pcb, rnd_coord_t x1, rnd_coord_t y1,
 	pcb->hidlib.dwg.X2 = x2;
 	pcb->hidlib.dwg.Y2 = y2;
 
-	if (pcb == PCB)
-		pcb_board_replaced();
+	if (pcb == PCB) {
+		rnd_event(&pcb->hidlib, RND_EVENT_DESIGN_META_CHANGED, NULL);
+		rnd_event(&pcb->hidlib, PCB_EVENT_BOARD_EDITED, NULL);
+		rnd_gui->invalidate_all(rnd_gui);
+	}
 }
 
 /*** undoable board resize ***/
