@@ -292,6 +292,7 @@ fgw_error_t pcb_act_LoadPixmap(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	double dpi = 600.0;
 	rnd_pixmap_t *pxm;
 	pcb_gfx_t *g;
+	pcb_layer_type_t lyt;
 
 	RND_ACT_MAY_CONVARG(1, FGW_STR, LoadPixmap, fn = argv[1].val.str);
 
@@ -323,6 +324,11 @@ fgw_error_t pcb_act_LoadPixmap(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		RND_MIL_TO_COORD((double)pxm->sx / dpi * 1000.0), RND_MIL_TO_COORD((double)pxm->sy / dpi * 1000.0),
 		0, pcb_flag_make(0));
 
+	/* when imported onto a bottom layer, auto-set y-mirror (photo taken from the bottom side of the board) */
+	lyt = pcb_layer_flags_(g->parent.layer);
+	if (lyt & PCB_LYT_BOTTOM)
+		g->ymirror = 1;
+
 	pcb_gfx_set_pixmap_free(g, pxm, 0);
 
 	RND_ACT_IRES(0);
@@ -395,37 +401,37 @@ void pcb_buffer_rotate90(pcb_buffer_t *Buffer, unsigned int Number)
 	PCB_LINE_ALL_LOOP(Buffer->Data);
 	{
 		if (layer->line_tree != NULL)
-			rnd_r_delete_entry(layer->line_tree, (rnd_box_t *) line);
+			rnd_rtree_delete(layer->line_tree, line, (rnd_rtree_box_t *)line);
 		pcb_line_rotate90(line, Buffer->X, Buffer->Y, Number);
 		if (layer->line_tree != NULL)
-			rnd_r_insert_entry(layer->line_tree, (rnd_box_t *) line);
+			rnd_rtree_insert(layer->line_tree, line, (rnd_rtree_box_t *)line);
 	}
 	PCB_ENDALL_LOOP;
 	PCB_ARC_ALL_LOOP(Buffer->Data);
 	{
 		if (layer->arc_tree != NULL)
-			rnd_r_delete_entry(layer->arc_tree, (rnd_box_t *) arc);
+			rnd_rtree_delete(layer->arc_tree, arc, (rnd_rtree_box_t *)arc);
 		pcb_arc_rotate90(arc, Buffer->X, Buffer->Y, Number);
 		if (layer->arc_tree != NULL)
-			rnd_r_insert_entry(layer->arc_tree, (rnd_box_t *) arc);
+			rnd_rtree_insert(layer->arc_tree, arc, (rnd_rtree_box_t *)arc);
 	}
 	PCB_ENDALL_LOOP;
 	PCB_TEXT_ALL_LOOP(Buffer->Data);
 	{
 		if (layer->text_tree != NULL)
-			rnd_r_delete_entry(layer->text_tree, (rnd_box_t *) text);
+			rnd_rtree_delete(layer->text_tree, text, (rnd_rtree_box_t *)text);
 		pcb_text_rotate90(text, Buffer->X, Buffer->Y, Number);
 		if (layer->text_tree != NULL)
-			rnd_r_insert_entry(layer->text_tree, (rnd_box_t *) text);
+			rnd_rtree_insert(layer->text_tree, text, (rnd_rtree_box_t *)text);
 	}
 	PCB_ENDALL_LOOP;
 	PCB_POLY_ALL_LOOP(Buffer->Data);
 	{
 		if (layer->polygon_tree != NULL)
-			rnd_r_delete_entry(layer->polygon_tree, (rnd_box_t *) polygon);
+			rnd_rtree_delete(layer->polygon_tree, polygon, (rnd_rtree_box_t *)polygon);
 		pcb_poly_rotate90(polygon, Buffer->X, Buffer->Y, Number);
 		if (layer->polygon_tree != NULL)
-			rnd_r_insert_entry(layer->polygon_tree, (rnd_box_t *) polygon);
+			rnd_rtree_insert(layer->polygon_tree, polygon, (rnd_rtree_box_t *)polygon);
 	}
 	PCB_ENDALL_LOOP;
 
