@@ -4,7 +4,7 @@
  *  pcb-rnd, interactive printed circuit board design
  *  (this file is based on PCB, interactive printed circuit board design)
  *  Copyright (C) 1994,1995,1996 Thomas Nau
- *  Copyright (C) 2020 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2020,2023 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -187,12 +187,21 @@ void pcb_data_uninit(pcb_data_t *data)
 		pcb_layer_free_fields(layer, 0);
 
 	if (!is_subc) {
-		if (data->subc_tree)
-			rnd_r_destroy_tree(&data->subc_tree);
-		if (data->padstack_tree)
-			rnd_r_destroy_tree(&data->padstack_tree);
-		if (data->rat_tree)
-			rnd_r_destroy_tree(&data->rat_tree);
+		if (data->subc_tree) {
+			rnd_rtree_uninit(data->subc_tree);
+			free(data->subc_tree);
+			data->subc_tree = NULL;
+		}
+		if (data->padstack_tree) {
+			rnd_rtree_uninit(data->padstack_tree);
+			free(data->padstack_tree);
+			data->padstack_tree = NULL;
+		}
+		if (data->rat_tree) {
+			rnd_rtree_uninit(data->rat_tree);
+			free(data->rat_tree);
+			data->rat_tree = NULL;
+		}
 	}
 
 	for (layer = data->Layer, i = 0; i < PCB_MAX_LAYER; layer++, i++)
@@ -231,10 +240,24 @@ rnd_bool pcb_data_is_empty(pcb_data_t *Data)
 
 rnd_box_t *pcb_data_bbox(rnd_box_t *out, pcb_data_t *Data, rnd_bool ignore_floaters)
 {
+	pcb_layer_t *aux = NULL;
+
 	/* preset identifiers with highest and lowest possible values */
 	out->X1 = out->Y1 = RND_MAX_COORD;
 	out->X2 = out->Y2 = -RND_MAX_COORD;
 
+	if (ignore_floaters) {
+		long n;
+
+		for(n = 0; n < Data->LayerN; n++) {
+			if (strcmp(Data->Layer[n].name, SUBC_AUX_NAME) == 0) {
+				aux = Data->Layer + n;
+				break;
+			}
+		}
+	}
+
+
 	/* now scan for the lowest/highest X and Y coordinate */
 	PCB_PADSTACK_LOOP(Data);
 	{
@@ -253,6 +276,7 @@ rnd_box_t *pcb_data_bbox(rnd_box_t *out, pcb_data_t *Data, rnd_bool ignore_float
 	PCB_LINE_ALL_LOOP(Data);
 	{
 		pcb_line_bbox(line);
+		if (ignore_floaters && (aux != NULL) && (line->parent.layer == aux)) continue; /* ignore aux layer objects */
 		if (!ignore_floaters || !PCB_FLAG_TEST(PCB_FLAG_FLOATER, line))
 			rnd_box_bump_box(out, &line->BoundingBox);
 	}
@@ -688,18 +712,18 @@ void pcb_data_clip_polys(pcb_data_t *data)
 
 #define rsearch(tree) \
 	do { \
-		rnd_r_dir_t tmp = rnd_r_search(tree, starting_region, region_in_search, rectangle_in_region, closure, num_found); \
-		if (tmp == RND_R_DIR_CANCEL) return tmp; \
+		rnd_rtree_dir_t tmp = rnd_rtree_search_any(tree, starting_region, region_in_search, rectangle_in_region, closure, num_found); \
+		if (tmp == rnd_RTREE_DIR_STOP) return tmp; \
 		res |= tmp; \
 	} while(0);
 
-rnd_r_dir_t pcb_data_r_search(pcb_data_t *data, pcb_objtype_t types, const rnd_box_t *starting_region,
-						 rnd_r_dir_t (*region_in_search) (const rnd_box_t *region, void *cl),
-						 rnd_r_dir_t (*rectangle_in_region) (const rnd_box_t *box, void *cl),
-						 void *closure, int *num_found, rnd_bool vis_only)
+rnd_rtree_dir_t pcb_data_r_search(pcb_data_t *data, pcb_objtype_t types, const rnd_rtree_box_t *starting_region,
+						 rnd_rtree_dir_t (*region_in_search)(void *cl, void *obj, const rnd_rtree_box_t *region),
+						 rnd_rtree_dir_t (*rectangle_in_region)(void *cl, void *obj, const rnd_rtree_box_t *box),
+						 void *closure, long *num_found, rnd_bool vis_only)
 {
 	rnd_layer_id_t lid;
-	rnd_r_dir_t res = 0;
+	rnd_rtree_dir_t res = 0;
 
 	if (!vis_only || PCB->RatOn)
 		if (types & PCB_OBJ_RAT)  rsearch(data->rat_tree);
@@ -879,40 +903,40 @@ unsigned long pcb_data_clear_obj_flag(pcb_data_t *data, pcb_objtype_t tmask, uns
 	if (flag & PCB_FLAG_WARN)
 		conf_core.temp.rat_warn = rnd_false;
 
-	if (tmask & PCB_OBJ_PSTK)
-		for(n = rnd_r_first(data->padstack_tree, &it); n != NULL; n = rnd_r_next(&it))
+	if ((tmask & PCB_OBJ_PSTK) && (data->padstack_tree != NULL))
+		for(n = rnd_rtree_all_first(&it, data->padstack_tree); n != NULL; n = rnd_rtree_all_next(&it))
 			CHK_CLEAR(n);
 
-	if (tmask & PCB_OBJ_RAT)
-		for(n = rnd_r_first(data->rat_tree, &it); n != NULL; n = rnd_r_next(&it))
+	if ((tmask & PCB_OBJ_RAT) && (data->rat_tree != NULL))
+		for(n = rnd_rtree_all_first(&it, data->rat_tree); n != NULL; n = rnd_rtree_all_next(&it))
 			CHK_CLEAR(n);
 
-	if (tmask & PCB_OBJ_SUBC)
-		for(n = rnd_r_first(data->subc_tree, &it); n != NULL; n = rnd_r_next(&it))
+	if ((tmask & PCB_OBJ_SUBC) && (data->subc_tree != NULL))
+		for(n = rnd_rtree_all_first(&it, data->subc_tree); n != NULL; n = rnd_rtree_all_next(&it))
 			CHK_CLEAR(n);
 
 	if ((tmask & (PCB_OBJ_LINE | PCB_OBJ_ARC | PCB_OBJ_POLY | PCB_OBJ_TEXT | PCB_OBJ_GFX)) == 0)
 		return cnt; /* do not run the layer loop if no layer object is requested */
 
 	for(li = 0, l = data->Layer; li < data->LayerN; li++,l++) {
-		if (tmask & PCB_OBJ_LINE)
-			for(n = rnd_r_first(l->line_tree, &it); n != NULL; n = rnd_r_next(&it))
+		if ((tmask & PCB_OBJ_LINE) && (l->line_tree != NULL))
+			for(n = rnd_rtree_all_first(&it, l->line_tree); n != NULL; n = rnd_rtree_all_next(&it))
 				CHK_CLEAR(n);
 
-		if (tmask & PCB_OBJ_ARC)
-			for(n = rnd_r_first(l->arc_tree, &it); n != NULL; n = rnd_r_next(&it))
+		if ((tmask & PCB_OBJ_ARC) && (l->arc_tree != NULL))
+			for(n = rnd_rtree_all_first(&it, l->arc_tree); n != NULL; n = rnd_rtree_all_next(&it))
 				CHK_CLEAR(n);
 
-		if (tmask & PCB_OBJ_POLY)
-			for(n = rnd_r_first(l->polygon_tree, &it); n != NULL; n = rnd_r_next(&it))
+		if ((tmask & PCB_OBJ_POLY) && (l->polygon_tree != NULL))
+			for(n = rnd_rtree_all_first(&it, l->polygon_tree); n != NULL; n = rnd_rtree_all_next(&it))
 				CHK_CLEAR(n);
 
-		if (tmask & PCB_OBJ_TEXT)
-			for(n = rnd_r_first(l->text_tree, &it); n != NULL; n = rnd_r_next(&it))
+		if ((tmask & PCB_OBJ_TEXT) && (l->text_tree != NULL))
+			for(n = rnd_rtree_all_first(&it, l->text_tree); n != NULL; n = rnd_rtree_all_next(&it))
 				CHK_CLEAR(n);
 
-		if (tmask & PCB_OBJ_GFX)
-			for(n = rnd_r_first(l->gfx_tree, &it); n != NULL; n = rnd_r_next(&it))
+		if ((tmask & PCB_OBJ_GFX) && (l->gfx_tree != NULL))
+			for(n = rnd_rtree_all_first(&it, l->gfx_tree); n != NULL; n = rnd_rtree_all_next(&it))
 				CHK_CLEAR(n);
 	}
 	return cnt;
@@ -932,30 +956,38 @@ void pcb_data_dynflag_clear(pcb_data_t *data, pcb_dynf_t dynf)
 	int li;
 	pcb_layer_t *l;
 
-	for(n = rnd_r_first(data->padstack_tree, &it); n != NULL; n = rnd_r_next(&it))
-		PCB_DFLAG_CLR(&((pcb_any_obj_t *)n)->Flags, dynf);
+	if (data->padstack_tree != NULL)
+		for(n = rnd_rtree_all_first(&it, data->padstack_tree); n != NULL; n = rnd_rtree_all_next(&it))
+			PCB_DFLAG_CLR(&((pcb_any_obj_t *)n)->Flags, dynf);
 
-	for(n = rnd_r_first(data->subc_tree, &it); n != NULL; n = rnd_r_next(&it))
-		PCB_DFLAG_CLR(&((pcb_any_obj_t *)n)->Flags, dynf);
+	if (data->subc_tree != NULL)
+		for(n = rnd_rtree_all_first(&it, data->subc_tree); n != NULL; n = rnd_rtree_all_next(&it))
+			PCB_DFLAG_CLR(&((pcb_any_obj_t *)n)->Flags, dynf);
 
-	for(n = rnd_r_first(data->rat_tree, &it); n != NULL; n = rnd_r_next(&it))
-		PCB_DFLAG_CLR(&((pcb_any_obj_t *)n)->Flags, dynf);
+	if (data->rat_tree != NULL)
+		for(n = rnd_rtree_all_first(&it, data->rat_tree); n != NULL; n = rnd_rtree_all_next(&it))
+			PCB_DFLAG_CLR(&((pcb_any_obj_t *)n)->Flags, dynf);
 
 	for(li = 0, l = data->Layer; li < data->LayerN; li++,l++) {
-		for(n = rnd_r_first(l->line_tree, &it); n != NULL; n = rnd_r_next(&it))
-			PCB_DFLAG_CLR(&((pcb_any_obj_t *)n)->Flags, dynf);
+		if (l->line_tree != NULL)
+			for(n = rnd_rtree_all_first(&it, l->line_tree); n != NULL; n = rnd_rtree_all_next(&it))
+				PCB_DFLAG_CLR(&((pcb_any_obj_t *)n)->Flags, dynf);
 
-		for(n = rnd_r_first(l->arc_tree, &it); n != NULL; n = rnd_r_next(&it))
-			PCB_DFLAG_CLR(&((pcb_any_obj_t *)n)->Flags, dynf);
+		if (l->arc_tree != NULL)
+			for(n = rnd_rtree_all_first(&it, l->arc_tree); n != NULL; n = rnd_rtree_all_next(&it))
+				PCB_DFLAG_CLR(&((pcb_any_obj_t *)n)->Flags, dynf);
 
-		for(n = rnd_r_first(l->polygon_tree, &it); n != NULL; n = rnd_r_next(&it))
-			PCB_DFLAG_CLR(&((pcb_any_obj_t *)n)->Flags, dynf);
+		if (l->polygon_tree != NULL)
+			for(n = rnd_rtree_all_first(&it, l->polygon_tree); n != NULL; n = rnd_rtree_all_next(&it))
+				PCB_DFLAG_CLR(&((pcb_any_obj_t *)n)->Flags, dynf);
 
-		for(n = rnd_r_first(l->text_tree, &it); n != NULL; n = rnd_r_next(&it))
-			PCB_DFLAG_CLR(&((pcb_any_obj_t *)n)->Flags, dynf);
+		if (l->text_tree != NULL)
+			for(n = rnd_rtree_all_first(&it, l->text_tree); n != NULL; n = rnd_rtree_all_next(&it))
+				PCB_DFLAG_CLR(&((pcb_any_obj_t *)n)->Flags, dynf);
 
-		for(n = rnd_r_first(l->gfx_tree, &it); n != NULL; n = rnd_r_next(&it))
-			PCB_DFLAG_CLR(&((pcb_any_obj_t *)n)->Flags, dynf);
+		if (l->gfx_tree != NULL)
+			for(n = rnd_rtree_all_first(&it, l->gfx_tree); n != NULL; n = rnd_rtree_all_next(&it))
+				PCB_DFLAG_CLR(&((pcb_any_obj_t *)n)->Flags, dynf);
 	}
 }
 
