@@ -30,7 +30,7 @@
 #define PCB_DRAW_H
 
 #include "config.h"
-#include <librnd/core/hid.h>
+#include <librnd/hid/hid.h>
 #include "layer.h"
 
 /* holds information about output window */
@@ -184,11 +184,11 @@ void pcb_draw_delay_label_add(pcb_any_obj_t *obj);
 #define pcb_draw_term_need_gfx(obj) \
 	(((obj)->term != NULL) && !PCB_FLAG_TEST(PCB_FLAG_FOUND, (obj)) && !PCB_FLAG_TEST(PCB_FLAG_WARN, (obj)) && !PCB_FLAG_TEST(PCB_FLAG_SELECTED, (obj)))
 
-#define pcb_draw_term_hid_permission() (rnd_gui->heavy_term_layer_ind)
+#define pcb_draw_term_hid_permission() (rnd_render->gui)
 
 #define PCB_DRAW_TERM_GFX_WIDTH (-3)
 
 void pcb_expose_main(rnd_hid_t *hid, const rnd_hid_expose_ctx_t *ctx, rnd_xform_t *xform_caller);
-void pcb_expose_preview(rnd_hid_t *hid, const rnd_hid_expose_ctx_t *e);
+void pcb_expose_preview(rnd_hid_t *hid, rnd_hid_expose_ctx_t *e);
 
 #endif
