@@ -62,15 +62,15 @@ int rnd_mem_any_set(unsigned char *ptr, int bytes)
 	return 0;
 }
 
-void pcb_flag_erase(pcb_flag_t * f)
+void pcb_flag_uninit(pcb_flag_t *f)
 {
 	pcb_unknown_flag_t *u, *next;
-	for (u = f->unknowns; u != NULL; u = next) {
+	for(u = f->unknowns; u != NULL; u = next) {
 		free(u->str);
 		next = u->next;
 		free(u);
 	}
-	f->unknowns = NULL;
+	memset(f, 0, sizeof(pcb_flag_t));
 }
 
 int pcb_flag_eq(pcb_flag_t *f1, pcb_flag_t *f2)
