@@ -31,12 +31,14 @@
 
 #include <librnd/core/globalconst.h>
 
+#define PCB_MIN_SIZE         0
+
 #define PCB_MAX_LAYER        38    /* max number of layer, check source code for more changes, a *lot* more changes */
 /* new array size that allows substrate layers */
 #define PCB_MAX_LAYERGRP     ((PCB_MAX_LAYER+8)*2)    /* max number of layer groups, a.k.a. physical layers: a few extra outer layers per side, pluse one substrate per real layer */
-#define PCB_MIN_THICKNESS    RND_MIN_SIZE
+#define PCB_MIN_THICKNESS    PCB_MIN_SIZE
 #define PCB_MAX_THICKNESS    RND_MAX_COORD
-#define PCB_MIN_ARCRADIUS    RND_MIN_SIZE
+#define PCB_MIN_ARCRADIUS    PCB_MIN_SIZE
 #define PCB_MAX_ARCRADIUS    RND_MAX_COORD
 #define PCB_MIN_TEXTSCALE    1 /* scaling of text objects in percent (must be an integer greater than 0) */
 #define PCB_MAX_TEXTSCALE    10000
