@@ -152,22 +152,39 @@ void pcb_layer_free_fields(pcb_layer_t *layer, rnd_bool undoable)
 	}
 	list_map0(&layer->Polygon, pcb_poly_t, undoable ? UFC(obj_free_undoable) : UFC(pcb_poly_free));
 	if (!layer->is_bound) {
-		if (layer->line_tree)
-			rnd_r_destroy_tree(&layer->line_tree);
-		if (layer->arc_tree)
-			rnd_r_destroy_tree(&layer->arc_tree);
-		if (layer->text_tree)
-			rnd_r_destroy_tree(&layer->text_tree);
-		if (layer->polygon_tree)
-			rnd_r_destroy_tree(&layer->polygon_tree);
-		if (layer->gfx_tree)
-			rnd_r_destroy_tree(&layer->gfx_tree);
+		if (layer->line_tree) {
+			rnd_rtree_uninit(layer->line_tree);
+			free(layer->line_tree);
+			layer->line_tree = NULL;
+			}
+		if (layer->arc_tree) {
+			rnd_rtree_uninit(layer->arc_tree);
+			free(layer->arc_tree);
+			layer->arc_tree = NULL;
+		}
+		if (layer->text_tree) {
+			rnd_rtree_uninit(layer->text_tree);
+			free(layer->text_tree);
+			layer->text_tree = NULL;
+		}
+		if (layer->polygon_tree) {
+			rnd_rtree_uninit(layer->polygon_tree);
+			free(layer->polygon_tree);
+			layer->polygon_tree = NULL;
+		}
+		if (layer->gfx_tree){
+			rnd_rtree_uninit(layer->gfx_tree);
+			free(layer->gfx_tree);
+			layer->gfx_tree = NULL;
+		}
 	}
 	free((char *)layer->name);
 	memset(layer, 0, sizeof(pcb_layer_t));
 	layer->Attributes.post_change = layer_post_change;
 }
 
+#define RTREE_EMPTY(rt) (((rt) == NULL) || ((rt)->size == 0))
+
 rnd_bool pcb_layer_is_pure_empty(pcb_layer_t *layer)
 {
 	/* if any local list is non-empty, the layer is non-empty */
@@ -179,11 +196,11 @@ rnd_bool pcb_layer_is_pure_empty(pcb_layer_t *layer)
 	/* if the layer is locally empty, it might be a board layer that has
 	   objects from subcircuits so also check the rtrees */
 	return
-		RND_RTREE_EMPTY(layer->line_tree) && 
-		RND_RTREE_EMPTY(layer->arc_tree) && 
-		RND_RTREE_EMPTY(layer->gfx_tree) && 
-		RND_RTREE_EMPTY(layer->polygon_tree) && 
-		RND_RTREE_EMPTY(layer->text_tree);
+		RTREE_EMPTY(layer->line_tree) &&
+		RTREE_EMPTY(layer->arc_tree) &&
+		RTREE_EMPTY(layer->gfx_tree) &&
+		RTREE_EMPTY(layer->polygon_tree) &&
+		RTREE_EMPTY(layer->text_tree);
 }
 
 static rnd_bool pcb_layer_is_empty_glob(pcb_board_t *pcb, pcb_data_t *data, pcb_layer_t *layer)
@@ -921,7 +938,7 @@ static void layer_del_update_thermals(pcb_board_t *pcb, rnd_layer_id_t old_index
 		return;
 
 	/* thermals are referenced by layer IDs which are going to change now */
-	for(b = rnd_r_first(pcb->Data->padstack_tree, &it); b != NULL; b = rnd_r_next(&it)) {
+	for(b = rnd_rtree_all_first(&it, pcb->Data->padstack_tree); b != NULL; b = rnd_rtree_all_next(&it)) {
 		int n;
 		pcb_pstk_t *ps = (pcb_pstk_t *)b;
 		for(n = old_index; n < pcb->Data->LayerN-1; n++) {
@@ -1191,11 +1208,11 @@ rnd_layer_id_t pcb_layer2id(pcb_data_t *data, pcb_layer_t *ly)
 void pcb_layer_link_trees(pcb_layer_t *dst, pcb_layer_t *src)
 {
 	/* we can't link non-existing trees - make sure src does have the trees initialized */
-	if (src->line_tree == NULL) src->line_tree = rnd_r_create_tree();
-	if (src->arc_tree == NULL) src->arc_tree = rnd_r_create_tree();
-	if (src->text_tree == NULL) src->text_tree = rnd_r_create_tree();
-	if (src->polygon_tree == NULL) src->polygon_tree = rnd_r_create_tree();
-	if (src->gfx_tree == NULL) src->gfx_tree = rnd_r_create_tree();
+	if (src->line_tree == NULL) rnd_rtree_init(src->line_tree = malloc(sizeof(rnd_rtree_t)));
+	if (src->arc_tree == NULL) rnd_rtree_init(src->arc_tree = malloc(sizeof(rnd_rtree_t)));
+	if (src->text_tree == NULL) rnd_rtree_init(src->text_tree = malloc(sizeof(rnd_rtree_t)));
+	if (src->polygon_tree == NULL) rnd_rtree_init(src->polygon_tree = malloc(sizeof(rnd_rtree_t)));
+	if (src->gfx_tree == NULL) rnd_rtree_init(src->gfx_tree = malloc(sizeof(rnd_rtree_t)));
 
 	dst->line_tree = src->line_tree;
 	dst->arc_tree = src->arc_tree;
