@@ -31,16 +31,17 @@
 /* Virtual layers for UI and debug */
 #include "config.h"
 #include "board.h"
+#include "data.h"
 #include "layer.h"
 #include "event.h"
 #include <librnd/core/compat_misc.h>
 #include "genvector/vtp0.h"
+#include "genht/hash.h"
 #include "layer_ui.h"
 
 vtp0_t pcb_uilayers;
 
-
-pcb_layer_t *pcb_uilayer_alloc(const char *cookie, const char *name, const rnd_color_t *color)
+pcb_layer_t *pcb_uilayer_alloc(pcb_board_t *pcb, const char *cookie, const char *name, const rnd_color_t *color)
 {
 	int n;
 	pcb_layer_t *l;
@@ -67,8 +68,8 @@ found:;
 	l->name = rnd_strdup(name);
 	l->meta.real.vis = 1;
 	l->parent_type = PCB_PARENT_UI;
-	l->parent.any = NULL;
-	rnd_event(&PCB->hidlib, PCB_EVENT_LAYERS_CHANGED, NULL);
+	l->parent.any = pcb->uilayer_data;
+	rnd_event(&pcb->hidlib, PCB_EVENT_LAYERS_CHANGED, NULL);
 	return l;
 }
 
@@ -103,6 +104,10 @@ void pcb_uilayer_free_all_cookie(const char *cookie)
 	rnd_event(&PCB->hidlib, PCB_EVENT_LAYERS_CHANGED, NULL);
 }
 
+void pcb_uilayer_init(void)
+{
+}
+
 void pcb_uilayer_uninit(void)
 {
 	vtp0_uninit(&pcb_uilayers);
