@@ -102,13 +102,12 @@ pcb_arc_t *pcb_arc_alloc(pcb_layer_t *layer)
 	return pcb_arc_alloc_id(layer, pcb_create_ID_get());
 }
 
-/* computes the bounding box of an arc */
-static rnd_box_t pcb_arc_bbox_(const pcb_arc_t *Arc, int mini)
+/* computes the centerline bounding box of an arc */
+rnd_box_t pcb_arc_bbox_cline(const pcb_arc_t *Arc)
 {
 	double ca1, ca2, sa1, sa2;
 	double minx, maxx, miny, maxy, delta;
 	rnd_angle_t ang1, ang2;
-	rnd_coord_t width;
 	rnd_box_t res;
 
 	/* first normalize angles: ang1 < ang2, both angles between 0 and 720 */
@@ -155,6 +154,17 @@ static rnd_box_t pcb_arc_bbox_(const pcb_arc_t *Arc, int mini)
 	res.Y1 = Arc->Y + Arc->Height * miny;
 	res.Y2 = Arc->Y + Arc->Height * maxy;
 
+	return res;
+}
+
+/* computes the bounding box of an arc */
+static rnd_box_t pcb_arc_bbox_(const pcb_arc_t *Arc, int mini)
+{
+	rnd_box_t res;
+	rnd_coord_t width;
+
+	res = pcb_arc_bbox_cline(Arc);
+
 	if (!mini) {
 		width = (Arc->Thickness + Arc->Clearance) / 2;
 		/* Adjust for our discrete polygon approximation */
@@ -239,12 +249,12 @@ void pcb_arc_set_angles(pcb_layer_t *Layer, pcb_arc_t *a, rnd_angle_t new_sa, rn
 		new_sa = 0;
 	}
 	pcb_poly_restore_to_poly(PCB->Data, PCB_OBJ_ARC, Layer, a);
-	rnd_r_delete_entry(Layer->arc_tree, (rnd_box_t *) a);
+	rnd_rtree_delete(Layer->arc_tree, a, (rnd_rtree_box_t *)a);
 	pcb_undo_add_obj_to_change_angles(PCB_OBJ_ARC, a, a, a);
 	a->StartAngle = new_sa;
 	a->Delta = new_da;
 	pcb_arc_bbox(a);
-	rnd_r_insert_entry(Layer->arc_tree, (rnd_box_t *) a);
+	rnd_rtree_insert(Layer->arc_tree, a, (rnd_rtree_box_t *)a);
 	pcb_poly_clear_from_poly(PCB->Data, PCB_OBJ_ARC, Layer, a);
 }
 
@@ -252,12 +262,12 @@ void pcb_arc_set_angles(pcb_layer_t *Layer, pcb_arc_t *a, rnd_angle_t new_sa, rn
 void pcb_arc_set_radii(pcb_layer_t *Layer, pcb_arc_t *a, rnd_coord_t new_width, rnd_coord_t new_height)
 {
 	pcb_poly_restore_to_poly(PCB->Data, PCB_OBJ_ARC, Layer, a);
-	rnd_r_delete_entry(Layer->arc_tree, (rnd_box_t *) a);
+	rnd_rtree_delete(Layer->arc_tree, a, (rnd_rtree_box_t *)a);
 	pcb_undo_add_obj_to_change_radii(PCB_OBJ_ARC, a, a, a);
 	a->Width = new_width;
 	a->Height = new_height;
 	pcb_arc_bbox(a);
-	rnd_r_insert_entry(Layer->arc_tree, (rnd_box_t *) a);
+	rnd_rtree_insert(Layer->arc_tree, a, (rnd_rtree_box_t *)a);
 	pcb_poly_clear_from_poly(PCB->Data, PCB_OBJ_ARC, Layer, a);
 }
 
@@ -348,8 +358,8 @@ void pcb_add_arc_on_layer(pcb_layer_t *Layer, pcb_arc_t *Arc)
 {
 	pcb_arc_bbox(Arc);
 	if (!Layer->arc_tree)
-		Layer->arc_tree = rnd_r_create_tree();
-	rnd_r_insert_entry(Layer->arc_tree, (rnd_box_t *) Arc);
+		rnd_rtree_init(Layer->arc_tree = malloc(sizeof(rnd_rtree_t)));
+	rnd_rtree_insert(Layer->arc_tree, Arc, (rnd_rtree_box_t *)Arc);
 	Arc->type = PCB_OBJ_ARC;
 	PCB_SET_PARENT(Arc, layer, Layer);
 }
@@ -359,7 +369,7 @@ void pcb_add_arc_on_layer(pcb_layer_t *Layer, pcb_arc_t *Arc)
 void pcb_arc_free(pcb_arc_t *arc)
 {
 	if ((arc->parent.layer != NULL) && (arc->parent.layer->arc_tree != NULL))
-		rnd_r_delete_entry(arc->parent.layer->arc_tree, (rnd_box_t *)arc);
+		rnd_rtree_delete(arc->parent.layer->arc_tree, arc, (rnd_rtree_box_t *)arc);
 	pcb_attribute_free(&arc->Attributes);
 	pcb_arc_unreg(arc);
 	pcb_obj_common_free((pcb_any_obj_t *)arc);
@@ -430,7 +440,7 @@ void pcb_arc_pre(pcb_arc_t *arc)
 	if (ly == NULL)
 		return;
 	if (ly->arc_tree != NULL)
-		rnd_r_delete_entry(ly->arc_tree, (rnd_box_t *)arc);
+		rnd_rtree_delete(ly->arc_tree, arc, (rnd_rtree_box_t *)arc);
 	pcb_poly_restore_to_poly(ly->parent.data, PCB_OBJ_ARC, ly, arc);
 }
 
@@ -440,7 +450,7 @@ void pcb_arc_post(pcb_arc_t *arc)
 	if (ly == NULL)
 		return;
 	if (ly->arc_tree != NULL)
-		rnd_r_insert_entry(ly->arc_tree, (rnd_box_t *)arc);
+		rnd_rtree_insert(ly->arc_tree, arc, (rnd_rtree_box_t *)arc);
 	pcb_poly_clear_from_poly(ly->parent.data, PCB_OBJ_ARC, ly, arc);
 }
 
@@ -464,7 +474,7 @@ static int undo_arc_geo_swap(void *udata)
 	pcb_layer_t *layer = g->arc->parent.layer;
 
 	if (layer->arc_tree != NULL)
-		rnd_r_delete_entry(layer->arc_tree, (rnd_box_t *)g->arc);
+		rnd_rtree_delete(layer->arc_tree, g->arc, (rnd_rtree_box_t *)g->arc);
 	pcb_poly_restore_to_poly(layer->parent.data, PCB_OBJ_ARC, layer, g->arc);
 
 	rnd_swap(rnd_coord_t, g->Thickness, g->arc->Thickness);
@@ -478,7 +488,7 @@ static int undo_arc_geo_swap(void *udata)
 
 	pcb_arc_bbox(g->arc);
 	if (layer->arc_tree != NULL)
-		rnd_r_insert_entry(layer->arc_tree, (rnd_box_t *)g->arc);
+		rnd_rtree_insert(layer->arc_tree, g->arc, (rnd_rtree_box_t *)g->arc);
 	pcb_poly_clear_from_poly(layer->parent.data, PCB_OBJ_ARC, layer, g->arc);
 
 	return 0;
@@ -534,7 +544,7 @@ void *pcb_arcop_move_buffer(pcb_opctx_t *ctx, pcb_layer_t *dstly, pcb_arc_t *arc
 	}
 
 	pcb_poly_restore_to_poly(ctx->buffer.src, PCB_OBJ_ARC, srcly, arc);
-	rnd_r_delete_entry(srcly->arc_tree, (rnd_box_t *) arc);
+	rnd_rtree_delete(srcly->arc_tree, arc, (rnd_rtree_box_t *)arc);
 
 	pcb_arc_unreg(arc);
 	pcb_arc_reg(dstly, arc);
@@ -542,8 +552,8 @@ void *pcb_arcop_move_buffer(pcb_opctx_t *ctx, pcb_layer_t *dstly, pcb_arc_t *arc
 	PCB_FLAG_CLEAR(PCB_FLAG_FOUND, arc);
 
 	if (!dstly->arc_tree)
-		dstly->arc_tree = rnd_r_create_tree();
-	rnd_r_insert_entry(dstly->arc_tree, (rnd_box_t *) arc);
+		rnd_rtree_init(dstly->arc_tree = malloc(sizeof(rnd_rtree_t)));
+	rnd_rtree_insert(dstly->arc_tree, arc, (rnd_rtree_box_t *)arc);
 	pcb_poly_clear_from_poly(ctx->buffer.dst, PCB_OBJ_ARC, dstly, arc);
 
 	return arc;
@@ -564,11 +574,11 @@ void *pcb_arcop_change_size(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_arc_t *Arc
 	if (value <= PCB_MAX_THICKNESS && value >= PCB_MIN_THICKNESS && value != Arc->Thickness) {
 		pcb_undo_add_obj_to_size(PCB_OBJ_ARC, Layer, Arc, Arc);
 		pcb_arc_invalidate_erase(Arc);
-		rnd_r_delete_entry(Layer->arc_tree, (rnd_box_t *) Arc);
+		rnd_rtree_delete(Layer->arc_tree, Arc, (rnd_rtree_box_t *)Arc);
 		pcb_poly_restore_to_poly(PCB->Data, PCB_OBJ_ARC, Layer, Arc);
 		Arc->Thickness = value;
 		pcb_arc_bbox(Arc);
-		rnd_r_insert_entry(Layer->arc_tree, (rnd_box_t *) Arc);
+		rnd_rtree_insert(Layer->arc_tree, Arc, (rnd_rtree_box_t *)Arc);
 		pcb_poly_clear_from_poly(PCB->Data, PCB_OBJ_ARC, Layer, Arc);
 		pcb_arc_invalidate_draw(Layer, Arc);
 		return Arc;
@@ -591,11 +601,11 @@ void *pcb_arcop_change_clear_size(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_arc_
 	if (value != Arc->Clearance) {
 		pcb_undo_add_obj_to_clear_size(PCB_OBJ_ARC, Layer, Arc, Arc);
 		pcb_arc_invalidate_erase(Arc);
-		rnd_r_delete_entry(Layer->arc_tree, (rnd_box_t *) Arc);
+		rnd_rtree_delete(Layer->arc_tree, Arc, (rnd_rtree_box_t *)Arc);
 		pcb_poly_restore_to_poly(PCB->Data, PCB_OBJ_ARC, Layer, Arc);
 		Arc->Clearance = value;
 		pcb_arc_bbox(Arc);
-		rnd_r_insert_entry(Layer->arc_tree, (rnd_box_t *) Arc);
+		rnd_rtree_insert(Layer->arc_tree, Arc, (rnd_rtree_box_t *)Arc);
 		pcb_poly_clear_from_poly(PCB->Data, PCB_OBJ_ARC, Layer, Arc);
 		pcb_arc_invalidate_draw(Layer, Arc);
 		return Arc;
@@ -628,11 +638,11 @@ void *pcb_arcop_change_radius(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_arc_t *A
 	if (value != *dst) {
 		pcb_undo_add_obj_to_change_radii(PCB_OBJ_ARC, Layer, Arc, Arc);
 		pcb_arc_invalidate_erase(Arc);
-		rnd_r_delete_entry(Layer->arc_tree, (rnd_box_t *) Arc);
+		rnd_rtree_delete(Layer->arc_tree, Arc, (rnd_rtree_box_t *)Arc);
 		pcb_poly_restore_to_poly(PCB->Data, PCB_OBJ_ARC, Layer, Arc);
 		*dst = value;
 		pcb_arc_bbox(Arc);
-		rnd_r_insert_entry(Layer->arc_tree, (rnd_box_t *) Arc);
+		rnd_rtree_insert(Layer->arc_tree, Arc, (rnd_rtree_box_t *)Arc);
 		pcb_poly_clear_from_poly(PCB->Data, PCB_OBJ_ARC, Layer, Arc);
 		pcb_arc_invalidate_draw(Layer, Arc);
 		return Arc;
@@ -667,11 +677,11 @@ void *pcb_arcop_change_angle(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_arc_t *Ar
 	if (value != *dst) {
 		pcb_undo_add_obj_to_change_angles(PCB_OBJ_ARC, Layer, Arc, Arc);
 		pcb_arc_invalidate_erase(Arc);
-		rnd_r_delete_entry(Layer->arc_tree, (rnd_box_t *) Arc);
+		rnd_rtree_delete(Layer->arc_tree, Arc, (rnd_rtree_box_t *)Arc);
 		pcb_poly_restore_to_poly(PCB->Data, PCB_OBJ_ARC, Layer, Arc);
 		*dst = value;
 		pcb_arc_bbox(Arc);
-		rnd_r_insert_entry(Layer->arc_tree, (rnd_box_t *) Arc);
+		rnd_rtree_insert(Layer->arc_tree, Arc, (rnd_rtree_box_t *)Arc);
 		pcb_poly_clear_from_poly(PCB->Data, PCB_OBJ_ARC, Layer, Arc);
 		pcb_arc_invalidate_draw(Layer, Arc);
 		return Arc;
@@ -750,10 +760,10 @@ void *pcb_arcop_move_noclip(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_arc_t *Arc
 
 void *pcb_arcop_move(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_arc_t *Arc)
 {
-	rnd_r_delete_entry(Layer->arc_tree, (rnd_box_t *) Arc);
+	rnd_rtree_delete(Layer->arc_tree, Arc, (rnd_rtree_box_t *)Arc);
 	pcb_poly_restore_to_poly(PCB->Data, PCB_OBJ_ARC, Layer, Arc);
 	pcb_arcop_move_noclip(ctx, Layer, Arc);
-	rnd_r_insert_entry(Layer->arc_tree, (rnd_box_t *) Arc);
+	rnd_rtree_insert(Layer->arc_tree, Arc, (rnd_rtree_box_t *)Arc);
 	pcb_poly_clear_from_poly(PCB->Data, PCB_OBJ_ARC, Layer, Arc);
 	return Arc;
 }
@@ -761,11 +771,11 @@ void *pcb_arcop_move(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_arc_t *Arc)
 void *pcb_arcop_clip(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_arc_t *Arc)
 {
 	if (ctx->clip.restore) {
-		rnd_r_delete_entry(Layer->arc_tree, (rnd_box_t *) Arc);
+		rnd_rtree_delete(Layer->arc_tree, Arc, (rnd_rtree_box_t *)Arc);
 		pcb_poly_restore_to_poly(PCB->Data, PCB_OBJ_ARC, Layer, Arc);
 	}
 	if (ctx->clip.clear) {
-		rnd_r_insert_entry(Layer->arc_tree, (rnd_box_t *) Arc);
+		rnd_rtree_insert(Layer->arc_tree, Arc, (rnd_rtree_box_t *)Arc);
 		pcb_poly_clear_from_poly(PCB->Data, PCB_OBJ_ARC, Layer, Arc);
 	}
 	return Arc;
@@ -774,14 +784,14 @@ void *pcb_arcop_clip(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_arc_t *Arc)
 /* moves an arc between layers; lowlevel routines */
 void *pcb_arcop_move_to_layer_low(pcb_opctx_t *ctx, pcb_layer_t * Source, pcb_arc_t * arc, pcb_layer_t * Destination)
 {
-	rnd_r_delete_entry(Source->arc_tree, (rnd_box_t *) arc);
+	rnd_rtree_delete(Source->arc_tree, arc, (rnd_rtree_box_t *)arc);
 
 	pcb_arc_unreg(arc);
 	pcb_arc_reg(Destination, arc);
 
 	if (!Destination->arc_tree)
-		Destination->arc_tree = rnd_r_create_tree();
-	rnd_r_insert_entry(Destination->arc_tree, (rnd_box_t *) arc);
+		rnd_rtree_init(Destination->arc_tree = malloc(sizeof(rnd_rtree_t)));
+	rnd_rtree_insert(Destination->arc_tree, arc, (rnd_rtree_box_t *)arc);
 
 	return arc;
 }
@@ -814,7 +824,7 @@ void *pcb_arcop_move_to_layer(pcb_opctx_t *ctx, pcb_layer_t * Layer, pcb_arc_t *
 /* destroys an arc from a layer */
 void *pcb_arcop_destroy(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_arc_t *Arc)
 {
-	rnd_r_delete_entry(Layer->arc_tree, (rnd_box_t *) Arc);
+	rnd_rtree_delete(Layer->arc_tree, Arc, (rnd_rtree_box_t *)Arc);
 
 	pcb_arc_free(Arc);
 	return NULL;
@@ -871,11 +881,11 @@ void pcb_arc_rotate90(pcb_arc_t *Arc, rnd_coord_t X, rnd_coord_t Y, unsigned Num
 void pcb_arc_rotate(pcb_layer_t *layer, pcb_arc_t *arc, rnd_coord_t X, rnd_coord_t Y, double cosa, double sina, rnd_angle_t angle)
 {
 	if (layer->arc_tree != NULL)
-		rnd_r_delete_entry(layer->arc_tree, (rnd_box_t *) arc);
+		rnd_rtree_delete(layer->arc_tree, arc, (rnd_rtree_box_t *)arc);
 	rnd_rotate(&arc->X, &arc->Y, X, Y, cosa, sina);
 	arc->StartAngle = rnd_normalize_angle(arc->StartAngle + angle);
 	if (layer->arc_tree != NULL)
-		rnd_r_insert_entry(layer->arc_tree, (rnd_box_t *) arc);
+		rnd_rtree_insert(layer->arc_tree, arc, (rnd_rtree_box_t *)arc);
 }
 
 void pcb_arc_mirror(pcb_arc_t *arc, rnd_coord_t y_offs, rnd_bool undoable)
@@ -900,13 +910,13 @@ void pcb_arc_mirror(pcb_arc_t *arc, rnd_coord_t y_offs, rnd_bool undoable)
 
 void pcb_arc_flip_side(pcb_layer_t *layer, pcb_arc_t *arc)
 {
-	rnd_r_delete_entry(layer->arc_tree, (rnd_box_t *) arc);
+	rnd_rtree_delete(layer->arc_tree, arc, (rnd_rtree_box_t *)arc);
 	arc->X = PCB_SWAP_X(arc->X);
 	arc->Y = PCB_SWAP_Y(arc->Y);
 	arc->StartAngle = RND_SWAP_ANGLE(arc->StartAngle);
 	arc->Delta = RND_SWAP_DELTA(arc->Delta);
 	pcb_arc_bbox(arc);
-	rnd_r_insert_entry(layer->arc_tree, (rnd_box_t *) arc);
+	rnd_rtree_insert(layer->arc_tree, arc, (rnd_rtree_box_t *)arc);
 }
 
 void pcb_arc_scale(pcb_arc_t *arc, double sx, double sy, double sth)
@@ -940,10 +950,10 @@ void *pcb_arcop_rotate90(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_arc_t *Arc)
 	pcb_arc_invalidate_erase(Arc);
 	pcb_poly_restore_to_poly(PCB->Data, PCB_OBJ_ARC, Layer, Arc);
 	if (Layer->arc_tree != NULL)
-		rnd_r_delete_entry(Layer->arc_tree, (rnd_box_t *) Arc);
+		rnd_rtree_delete(Layer->arc_tree, Arc, (rnd_rtree_box_t *)Arc);
 	pcb_arc_rotate90(Arc, ctx->rotate.center_x, ctx->rotate.center_y, ctx->rotate.number);
 	if (Layer->arc_tree != NULL)
-		rnd_r_insert_entry(Layer->arc_tree, (rnd_box_t *) Arc);
+		rnd_rtree_insert(Layer->arc_tree, Arc, (rnd_rtree_box_t *)Arc);
 	pcb_poly_clear_from_poly(PCB->Data, PCB_OBJ_ARC, Layer, Arc);
 	pcb_arc_invalidate_draw(Layer, Arc);
 	return Arc;
@@ -1240,34 +1250,34 @@ static void pcb_arc_draw(pcb_draw_info_t *info, pcb_arc_t *arc, int allow_term_g
 	pcb_arc_draw_(info, arc, allow_term_gfx);
 }
 
-rnd_r_dir_t pcb_arc_draw_callback(const rnd_box_t * b, void *cl)
+rnd_rtree_dir_t pcb_arc_draw_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
-	pcb_arc_t *arc = (pcb_arc_t *)b;
+	pcb_arc_t *arc = (pcb_arc_t *)obj;
 	pcb_draw_info_t *info = cl;
 
-	if (pcb_hidden_floater((pcb_any_obj_t*)b, info) || pcb_partial_export((pcb_any_obj_t*)b, info))
-		return RND_R_DIR_FOUND_CONTINUE;
+	if (pcb_hidden_floater((pcb_any_obj_t*)obj, info) || pcb_partial_export((pcb_any_obj_t*)obj, info))
+		return rnd_RTREE_DIR_FOUND_CONT;
 
 	if (!PCB->SubcPartsOn && pcb_lobj_parent_subc(arc->parent_type, &arc->parent))
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 
 	pcb_arc_draw(info, arc, 0);
-	return RND_R_DIR_FOUND_CONTINUE;
+	return rnd_RTREE_DIR_FOUND_CONT;
 }
 
-rnd_r_dir_t pcb_arc_draw_term_callback(const rnd_box_t * b, void *cl)
+rnd_rtree_dir_t pcb_arc_draw_term_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
-	pcb_arc_t *arc = (pcb_arc_t *)b;
+	pcb_arc_t *arc = (pcb_arc_t *)obj;
 	pcb_draw_info_t *info = cl;
 
-	if (pcb_hidden_floater((pcb_any_obj_t*)b, info) || pcb_partial_export((pcb_any_obj_t*)b, info))
-		return RND_R_DIR_FOUND_CONTINUE;
+	if (pcb_hidden_floater((pcb_any_obj_t*)obj, info) || pcb_partial_export((pcb_any_obj_t*)obj, info))
+		return rnd_RTREE_DIR_FOUND_CONT;
 
 	if (!PCB->SubcPartsOn && pcb_lobj_parent_subc(arc->parent_type, &arc->parent))
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 
 	pcb_arc_draw(info, arc, 1);
-	return RND_R_DIR_FOUND_CONTINUE;
+	return rnd_RTREE_DIR_FOUND_CONT;
 }
 
 /* erases an arc on a layer */
@@ -1276,7 +1286,6 @@ void pcb_arc_invalidate_erase(pcb_arc_t *Arc)
 	if (!Arc->Thickness)
 		return;
 	pcb_draw_invalidate(Arc);
-	pcb_flag_erase(&Arc->Flags);
 }
 
 void pcb_arc_invalidate_draw(pcb_layer_t *Layer, pcb_arc_t *Arc)
