@@ -199,8 +199,8 @@ void pcb_add_gfx_on_layer(pcb_layer_t *Layer, pcb_gfx_t *gfx)
 {
 	pcb_gfx_bbox(gfx);
 	if (!Layer->gfx_tree)
-		Layer->gfx_tree = rnd_r_create_tree();
-	rnd_r_insert_entry(Layer->gfx_tree, (rnd_box_t *)gfx);
+		rnd_rtree_init(Layer->gfx_tree = malloc(sizeof(rnd_rtree_t)));
+	rnd_rtree_insert(Layer->gfx_tree, gfx, (rnd_rtree_box_t *)gfx);
 	gfx->type = PCB_OBJ_GFX;
 	PCB_SET_PARENT(gfx, layer, Layer);
 }
@@ -210,7 +210,7 @@ void pcb_add_gfx_on_layer(pcb_layer_t *Layer, pcb_gfx_t *gfx)
 void pcb_gfx_free(pcb_gfx_t *gfx)
 {
 	if ((gfx->parent.layer != NULL) && (gfx->parent.layer->gfx_tree != NULL))
-		rnd_r_delete_entry(gfx->parent.layer->gfx_tree, (rnd_box_t *)gfx);
+		rnd_rtree_delete(gfx->parent.layer->gfx_tree, gfx, (rnd_rtree_box_t *)gfx);
 	pcb_attribute_free(&gfx->Attributes);
 	pcb_gfx_unreg(gfx);
 	pcb_obj_common_free((pcb_any_obj_t *)gfx);
@@ -254,7 +254,7 @@ void pcb_gfx_pre(pcb_gfx_t *gfx)
 	if (ly == NULL)
 		return;
 	if (ly->gfx_tree != NULL)
-		rnd_r_delete_entry(ly->gfx_tree, (rnd_box_t *)gfx);
+		rnd_rtree_delete(ly->gfx_tree, gfx, (rnd_rtree_box_t *)gfx);
 }
 
 void pcb_gfx_post(pcb_gfx_t *gfx)
@@ -264,7 +264,7 @@ void pcb_gfx_post(pcb_gfx_t *gfx)
 	if (ly == NULL)
 		return;
 	if (ly->gfx_tree != NULL)
-		rnd_r_insert_entry(ly->gfx_tree, (rnd_box_t *)gfx);
+		rnd_rtree_insert(ly->gfx_tree, gfx, (rnd_rtree_box_t *)gfx);
 }
 
 /***** operations *****/
@@ -275,6 +275,7 @@ typedef struct {
 	pcb_gfx_t *gfx; /* it is safe to save the object pointer because it is persistent (through the removed object list) */
 	rnd_coord_t cx, cy, sx, sy;
 	rnd_angle_t rot;
+	int xmirror, ymirror;
 } undo_gfx_geo_t;
 
 static int undo_gfx_geo_swap(void *udata)
@@ -283,7 +284,7 @@ static int undo_gfx_geo_swap(void *udata)
 	pcb_layer_t *layer = g->gfx->parent.layer;
 
 	if (layer->gfx_tree != NULL)
-		rnd_r_delete_entry(layer->gfx_tree, (rnd_box_t *)g->gfx);
+		rnd_rtree_delete(layer->gfx_tree, g->gfx, (rnd_rtree_box_t *)g->gfx);
 
 	rnd_swap(rnd_coord_t, g->cx, g->gfx->cx);
 	rnd_swap(rnd_coord_t, g->cy, g->gfx->cy);
@@ -291,13 +292,25 @@ static int undo_gfx_geo_swap(void *udata)
 	rnd_swap(rnd_coord_t, g->sy, g->gfx->sy);
 	rnd_swap(rnd_angle_t, g->rot, g->gfx->rot);
 
-	if (g->rot != g->gfx->rot)
+	if (g->xmirror != g->gfx->xmirror) {
+		int tmp = g->gfx->xmirror;
+		g->gfx->xmirror = g->xmirror;
+		g->xmirror = tmp;
+	}
+
+	if (g->ymirror != g->gfx->ymirror) {
+		int tmp = g->gfx->ymirror;
+		g->gfx->ymirror = g->ymirror;
+		g->ymirror = tmp;
+	}
+
+	if ((g->rot != g->gfx->rot) || (g->xmirror != g->gfx->xmirror) || (g->ymirror != g->gfx->ymirror))
 		g->gfx->pxm_xformed = pcb_pixmap_alloc_insert_transformed(&pcb_pixmaps, g->gfx->pxm_neutral, g->gfx->rot, g->sx, g->sy, g->gfx->xmirror, g->gfx->ymirror);
 
 	pcb_gfx_update(g->gfx);
 	pcb_gfx_bbox(g->gfx);
 	if (layer->gfx_tree != NULL)
-		rnd_r_insert_entry(layer->gfx_tree, (rnd_box_t *)g->gfx);
+		rnd_rtree_insert(layer->gfx_tree, g->gfx, (rnd_rtree_box_t *)g->gfx);
 
 	return 0;
 }
@@ -351,7 +364,7 @@ void *pcb_gfxop_move_buffer(pcb_opctx_t *ctx, pcb_layer_t *dstly, pcb_gfx_t *gfx
 		dstly = &ctx->buffer.dst->Layer[lid];
 	}
 
-	rnd_r_delete_entry(srcly->gfx_tree, (rnd_box_t *) gfx);
+	rnd_rtree_delete(srcly->gfx_tree, gfx, (rnd_rtree_box_t *)gfx);
 
 	pcb_gfx_unreg(gfx);
 	pcb_gfx_reg(dstly, gfx);
@@ -359,8 +372,8 @@ void *pcb_gfxop_move_buffer(pcb_opctx_t *ctx, pcb_layer_t *dstly, pcb_gfx_t *gfx
 	PCB_FLAG_CLEAR(PCB_FLAG_FOUND, gfx);
 
 	if (!dstly->gfx_tree)
-		dstly->gfx_tree = rnd_r_create_tree();
-	rnd_r_insert_entry(dstly->gfx_tree, (rnd_box_t *) gfx);
+		rnd_rtree_init(dstly->gfx_tree = malloc(sizeof(rnd_rtree_t)));
+	rnd_rtree_insert(dstly->gfx_tree, gfx, (rnd_rtree_box_t *)gfx);
 
 	return gfx;
 }
@@ -409,23 +422,23 @@ void *pcb_gfxop_move_noclip(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_gfx_t *gfx
 
 void *pcb_gfxop_move(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_gfx_t *gfx)
 {
-	rnd_r_delete_entry(Layer->gfx_tree, (rnd_box_t *)gfx);
+	rnd_rtree_delete(Layer->gfx_tree, gfx, (rnd_rtree_box_t *)gfx);
 	pcb_gfxop_move_noclip(ctx, Layer, gfx);
-	rnd_r_insert_entry(Layer->gfx_tree, (rnd_box_t *)gfx);
+	rnd_rtree_insert(Layer->gfx_tree, gfx, (rnd_rtree_box_t *)gfx);
 	return gfx;
 }
 
 /* moves a gfx between layers; lowlevel routines */
 void *pcb_gfxop_move_to_layer_low(pcb_opctx_t *ctx, pcb_layer_t * Source, pcb_gfx_t * gfx, pcb_layer_t * Destination)
 {
-	rnd_r_delete_entry(Source->gfx_tree, (rnd_box_t *)gfx);
+	rnd_rtree_delete(Source->gfx_tree, gfx, (rnd_rtree_box_t *)gfx);
 
 	pcb_gfx_unreg(gfx);
 	pcb_gfx_reg(Destination, gfx);
 
 	if (!Destination->gfx_tree)
-		Destination->gfx_tree = rnd_r_create_tree();
-	rnd_r_insert_entry(Destination->gfx_tree, (rnd_box_t *)gfx);
+		rnd_rtree_init(Destination->gfx_tree = malloc(sizeof(rnd_rtree_t)));
+	rnd_rtree_insert(Destination->gfx_tree, gfx, (rnd_rtree_box_t *)gfx);
 
 	return gfx;
 }
@@ -456,7 +469,7 @@ void *pcb_gfxop_move_to_layer(pcb_opctx_t *ctx, pcb_layer_t * Layer, pcb_gfx_t *
 /* destroys a gfx from a layer */
 void *pcb_gfxop_destroy(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_gfx_t *gfx)
 {
-	rnd_r_delete_entry(Layer->gfx_tree, (rnd_box_t *) gfx);
+	rnd_rtree_delete(Layer->gfx_tree, gfx, (rnd_rtree_box_t *)gfx);
 
 	pcb_gfx_free(gfx);
 	return NULL;
@@ -497,7 +510,7 @@ void pcb_gfx_rotate90(pcb_gfx_t *gfx, rnd_coord_t X, rnd_coord_t Y, unsigned Num
 void pcb_gfx_rotate(pcb_layer_t *layer, pcb_gfx_t *gfx, rnd_coord_t X, rnd_coord_t Y, double cosa, double sina, rnd_angle_t angle)
 {
 	if (layer->gfx_tree != NULL)
-		rnd_r_delete_entry(layer->gfx_tree, (rnd_box_t *) gfx);
+		rnd_rtree_delete(layer->gfx_tree, gfx, (rnd_rtree_box_t *)gfx);
 
 	gfx->rot = rnd_normalize_angle(gfx->rot + angle);
 	gfx->pxm_xformed = pcb_pixmap_alloc_insert_transformed(&pcb_pixmaps, gfx->pxm_neutral, gfx->rot, gfx->sx, gfx->sy, gfx->xmirror, gfx->ymirror);
@@ -505,7 +518,7 @@ void pcb_gfx_rotate(pcb_layer_t *layer, pcb_gfx_t *gfx, rnd_coord_t X, rnd_coord
 	pcb_gfx_bbox(gfx);
 
 	if (layer->gfx_tree != NULL)
-		rnd_r_insert_entry(layer->gfx_tree, (rnd_box_t *) gfx);
+		rnd_rtree_insert(layer->gfx_tree, gfx, (rnd_rtree_box_t *)gfx);
 }
 
 void pcb_gfx_mirror(pcb_gfx_t *gfx, rnd_coord_t y_offs, rnd_bool undoable)
@@ -520,7 +533,10 @@ void pcb_gfx_mirror(pcb_gfx_t *gfx, rnd_coord_t y_offs, rnd_bool undoable)
 	g->sx = gfx->sx;
 	g->sy = gfx->sy;
 	g->rot = gfx->rot;
-TODO("implement a mirror bit")
+	g->xmirror = gfx->xmirror;
+	g->ymirror = gfx->ymirror;
+
+TODO("probably need to swap y mirror");
 
 	undo_gfx_geo_swap(g);
 	if (undoable) pcb_undo_inc_serial();
@@ -528,13 +544,13 @@ TODO("implement a mirror bit")
 
 void pcb_gfx_flip_side(pcb_layer_t *layer, pcb_gfx_t *gfx)
 {
-	rnd_r_delete_entry(layer->gfx_tree, (rnd_box_t *)gfx);
+	rnd_rtree_delete(layer->gfx_tree, gfx, (rnd_rtree_box_t *)gfx);
 	gfx->cx = PCB_SWAP_X(gfx->cx);
 	gfx->cy = PCB_SWAP_Y(gfx->cy);
 	gfx->rot = RND_SWAP_ANGLE(gfx->rot);
 	pcb_gfx_update(gfx);
 	pcb_gfx_bbox(gfx);
-	rnd_r_insert_entry(layer->gfx_tree, (rnd_box_t *)gfx);
+	rnd_rtree_insert(layer->gfx_tree, gfx, (rnd_rtree_box_t *)gfx);
 }
 
 void pcb_gfx_chg_geo(pcb_gfx_t *gfx, rnd_coord_t cx, rnd_coord_t cy, rnd_coord_t sx, rnd_coord_t sy,  rnd_angle_t rot, rnd_bool undoable)
@@ -549,11 +565,33 @@ void pcb_gfx_chg_geo(pcb_gfx_t *gfx, rnd_coord_t cx, rnd_coord_t cy, rnd_coord_t
 	g->sx = sx;
 	g->sy = sy;
 	g->rot = rot;
+	g->xmirror = gfx->xmirror;
+	g->ymirror = gfx->ymirror;
 
 	undo_gfx_geo_swap(g);
 	if (undoable) pcb_undo_inc_serial();
 }
 
+void pcb_gfx_chg_mirror(pcb_gfx_t *gfx, int *xmir, int *ymir, rnd_bool undoable)
+{
+	undo_gfx_geo_t gtmp, *g = &gtmp;
+
+	if (undoable) g = pcb_undo_alloc(pcb_data_get_top(gfx->parent.layer->parent.data), &undo_gfx_geo, sizeof(undo_gfx_geo_t));
+
+	g->gfx = gfx;
+	g->cx = gfx->cx;
+	g->cy = gfx->cy;
+	g->sx = gfx->sx;
+	g->sy = gfx->sy;
+	g->rot = gfx->rot;
+	g->xmirror = xmir == NULL ? gfx->xmirror : *xmir;
+	g->ymirror = ymir == NULL ? gfx->ymirror : *ymir;
+
+	undo_gfx_geo_swap(g);
+	if (undoable) pcb_undo_inc_serial();
+}
+
+
 void pcb_gfx_scale(pcb_gfx_t *gfx, double sx, double sy, double sth)
 {
 	int onbrd = (gfx->parent.layer != NULL) && (!gfx->parent.layer->is_bound);
@@ -576,10 +614,10 @@ void *pcb_gfxop_rotate90(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_gfx_t *gfx)
 {
 	pcb_gfx_invalidate_erase(gfx);
 	if (Layer->gfx_tree != NULL)
-		rnd_r_delete_entry(Layer->gfx_tree, (rnd_box_t *) gfx);
+		rnd_rtree_delete(Layer->gfx_tree, gfx, (rnd_rtree_box_t *)gfx);
 	pcb_gfx_rotate90(gfx, ctx->rotate.center_x, ctx->rotate.center_y, ctx->rotate.number);
 	if (Layer->gfx_tree != NULL)
-		rnd_r_insert_entry(Layer->gfx_tree, (rnd_box_t *) gfx);
+		rnd_rtree_insert(Layer->gfx_tree, gfx, (rnd_rtree_box_t *)gfx);
 	pcb_gfx_invalidate_draw(Layer, gfx);
 	return gfx;
 }
@@ -761,7 +799,7 @@ void gfx_set_resize_gui(rnd_design_t *hl, pcb_gfx_t *gfx, rnd_bool allow_x, rnd_
 
 	len = rnd_get_value(lens, NULL, NULL, &succ);
 	if (succ)
-		gfx_set_resize_by_pixel_dist(gfx, px2-px1, py2-py1, len, allow_x, allow_y, 1);
+		gfx_set_resize_by_pixel_dist(gfx, RND_ABS(px2-px1), RND_ABS(py2-py1), len, allow_x, allow_y, 1);
 	free(lens);
 }
 
@@ -932,33 +970,33 @@ void pcb_gfx_draw(pcb_draw_info_t *info, pcb_gfx_t *gfx, int allow_term_gfx)
 	pcb_gfx_draw_(info, gfx, allow_term_gfx);
 }
 
-RND_INLINE rnd_r_dir_t pcb_gfx_draw_callback_(pcb_gfx_t *gfx, void *cl)
+RND_INLINE rnd_rtree_dir_t pcb_gfx_draw_callback_(pcb_gfx_t *gfx, void *cl)
 {
 	pcb_draw_info_t *info = cl;
 
 	if (pcb_hidden_floater((pcb_any_obj_t*)gfx, info) || pcb_partial_export((pcb_any_obj_t*)gfx, info))
-		return RND_R_DIR_FOUND_CONTINUE;
+		return rnd_RTREE_DIR_FOUND_CONT;
 
 	if (!PCB->SubcPartsOn && pcb_lobj_parent_subc(gfx->parent_type, &gfx->parent))
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 
 	pcb_gfx_draw(info, gfx, 0);
-	return RND_R_DIR_FOUND_CONTINUE;
+	return rnd_RTREE_DIR_FOUND_CONT;
 }
 
-rnd_r_dir_t pcb_gfx_draw_under_callback(const rnd_box_t *b, void *cl)
+rnd_rtree_dir_t pcb_gfx_draw_under_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
-	pcb_gfx_t *gfx = (pcb_gfx_t *)b;
+	pcb_gfx_t *gfx = (pcb_gfx_t *)obj;
 	if (!gfx->render_under)
-		return RND_R_DIR_FOUND_CONTINUE;
+		return rnd_RTREE_DIR_FOUND_CONT;
 	return pcb_gfx_draw_callback_(gfx, cl);
 }
 
-rnd_r_dir_t pcb_gfx_draw_above_callback(const rnd_box_t *b, void *cl)
+rnd_rtree_dir_t pcb_gfx_draw_above_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
-	pcb_gfx_t *gfx = (pcb_gfx_t *)b;
+	pcb_gfx_t *gfx = (pcb_gfx_t *)obj;
 	if (gfx->render_under)
-		return RND_R_DIR_FOUND_CONTINUE;
+		return rnd_RTREE_DIR_FOUND_CONT;
 	return pcb_gfx_draw_callback_(gfx, cl);
 }
 
@@ -966,7 +1004,6 @@ rnd_r_dir_t pcb_gfx_draw_above_callback(const rnd_box_t *b, void *cl)
 void pcb_gfx_invalidate_erase(pcb_gfx_t *gfx)
 {
 	pcb_draw_invalidate(gfx);
-	pcb_flag_erase(&gfx->Flags);
 }
 
 void pcb_gfx_invalidate_draw(pcb_layer_t *Layer, pcb_gfx_t *gfx)
