@@ -4,7 +4,7 @@
  *  pcb-rnd, interactive printed circuit board design
  *  (this file is based on PCB, interactive printed circuit board design)
  *  Copyright (C) 1994,1995,1996 Thomas Nau
- *  Copyright (C) 2020 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2020,2023 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -117,7 +117,7 @@ pcb_poly_t *pcb_poly_alloc(pcb_layer_t *layer)
 void pcb_poly_free(pcb_poly_t *poly)
 {
 	if ((poly->parent.layer != NULL) && (poly->parent.layer->polygon_tree != NULL))
-		rnd_r_delete_entry(poly->parent.layer->polygon_tree, (rnd_box_t *)poly);
+		rnd_rtree_delete(poly->parent.layer->polygon_tree, poly, (rnd_rtree_box_t *)poly);
 	pcb_attribute_free(&poly->Attributes);
 	pcb_poly_unreg(poly);
 	pcb_obj_common_free((pcb_any_obj_t *)poly);
@@ -210,7 +210,7 @@ void pcb_poly_rotate90(pcb_poly_t *Polygon, rnd_coord_t X, rnd_coord_t Y, unsign
 void pcb_poly_rotate(pcb_layer_t *layer, pcb_poly_t *polygon, rnd_coord_t X, rnd_coord_t Y, double cosa, double sina)
 {
 	if (layer->polygon_tree != NULL)
-		rnd_r_delete_entry(layer->polygon_tree, (rnd_box_t *) polygon);
+		rnd_rtree_delete(layer->polygon_tree, polygon, (rnd_rtree_box_t *)polygon);
 	PCB_POLY_POINT_LOOP(polygon);
 	{
 		rnd_rotate(&point->X, &point->Y, X, Y, cosa, sina);
@@ -220,7 +220,7 @@ void pcb_poly_rotate(pcb_layer_t *layer, pcb_poly_t *polygon, rnd_coord_t X, rnd
 		pcb_poly_init_clip(layer->parent.data, layer, polygon);
 	pcb_poly_bbox(polygon);
 	if (layer->polygon_tree != NULL)
-		rnd_r_insert_entry(layer->polygon_tree, (rnd_box_t *) polygon);
+		rnd_rtree_insert(layer->polygon_tree, polygon, (rnd_rtree_box_t *)polygon);
 }
 
 static rnd_polyarea_t *pcb_poly_is_valid_build(pcb_poly_t *p, int start, int end)
@@ -360,7 +360,7 @@ static int undo_poly_mirror_swap(void *udata)
 	pcb_layer_t *layer = g->poly->parent.layer;
 
 	if (layer->polygon_tree != NULL)
-		rnd_r_delete_entry(layer->polygon_tree, (rnd_box_t *)g->poly);
+		rnd_rtree_delete(layer->polygon_tree, g->poly, (rnd_rtree_box_t *)g->poly);
 	PCB_POLY_POINT_LOOP(g->poly);
 	{
 		point->X = PCB_SWAP_X(point->X);
@@ -371,7 +371,7 @@ static int undo_poly_mirror_swap(void *udata)
 		pcb_poly_init_clip(layer->parent.data, layer, g->poly);
 	pcb_poly_bbox(g->poly);
 	if (layer->polygon_tree != NULL)
-		rnd_r_insert_entry(layer->polygon_tree, (rnd_box_t *)g->poly);
+		rnd_rtree_insert(layer->polygon_tree, g->poly, (rnd_rtree_box_t *)g->poly);
 
 	return 0;
 }
@@ -406,7 +406,7 @@ void pcb_poly_mirror(pcb_poly_t *poly, rnd_coord_t y_offs, rnd_bool undoable)
 
 void pcb_poly_flip_side(pcb_layer_t *layer, pcb_poly_t *polygon)
 {
-	rnd_r_delete_entry(layer->polygon_tree, (rnd_box_t *) polygon);
+	rnd_rtree_delete(layer->polygon_tree, polygon, (rnd_rtree_box_t *)polygon);
 	PCB_POLY_POINT_LOOP(polygon);
 	{
 		point->X = PCB_SWAP_X(point->X);
@@ -416,7 +416,7 @@ void pcb_poly_flip_side(pcb_layer_t *layer, pcb_poly_t *polygon)
 	if (layer->parent_type == PCB_PARENT_DATA)
 		pcb_poly_init_clip(layer->parent.data, layer, polygon);
 	pcb_poly_bbox(polygon);
-	rnd_r_insert_entry(layer->polygon_tree, (rnd_box_t *) polygon);
+	rnd_rtree_insert(layer->polygon_tree, polygon, (rnd_rtree_box_t *)polygon);
 	/* hmmm, how to handle clip */
 }
 
@@ -548,8 +548,8 @@ void pcb_add_poly_on_layer(pcb_layer_t *Layer, pcb_poly_t *polygon)
 {
 	pcb_poly_bbox(polygon);
 	if (!Layer->polygon_tree)
-		Layer->polygon_tree = rnd_r_create_tree();
-	rnd_r_insert_entry(Layer->polygon_tree, (rnd_box_t *) polygon);
+		rnd_rtree_init(Layer->polygon_tree = malloc(sizeof(rnd_rtree_t)));
+	rnd_rtree_insert(Layer->polygon_tree, polygon, (rnd_rtree_box_t *)polygon);
 	PCB_SET_PARENT(polygon, layer, Layer);
 	pcb_poly_clear_from_poly(Layer->parent.data, PCB_OBJ_POLY, Layer, polygon);
 }
@@ -641,6 +641,7 @@ pcb_poly_t *pcb_poly_copy(pcb_poly_t *Dest, pcb_poly_t *Src, rnd_coord_t dx, rnd
 	}
 	pcb_poly_bbox(Dest);
 	Dest->Flags = Src->Flags;
+	Dest->enforce_clearance = Src->enforce_clearance;
 	PCB_FLAG_CLEAR(PCB_FLAG_FOUND, Dest);
 	return Dest;
 }
@@ -706,8 +707,8 @@ void *pcb_polyop_add_to_buffer(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_poly_t
 	 * skeleton polygon object, which won't have correct bounds.
 	 */
 	if (!layer->polygon_tree)
-		layer->polygon_tree = rnd_r_create_tree();
-	rnd_r_insert_entry(layer->polygon_tree, (rnd_box_t *) polygon);
+		rnd_rtree_init(layer->polygon_tree = malloc(sizeof(rnd_rtree_t)));
+	rnd_rtree_insert(layer->polygon_tree, polygon, (rnd_rtree_box_t *)polygon);
 
 	PCB_FLAG_CLEAR(PCB_FLAG_FOUND | ctx->buffer.extraflg, polygon);
 	return polygon;
@@ -731,7 +732,7 @@ void *pcb_polyop_move_buffer(pcb_opctx_t *ctx, pcb_layer_t *dstly, pcb_poly_t *p
 
 	pcb_poly_pprestore(polygon);
 
-	rnd_r_delete_entry(srcly->polygon_tree, (rnd_box_t *)polygon);
+	rnd_rtree_delete(srcly->polygon_tree, polygon, (rnd_rtree_box_t *)polygon);
 
 	pcb_poly_unreg(polygon);
 	pcb_poly_reg(dstly, polygon);
@@ -739,8 +740,8 @@ void *pcb_polyop_move_buffer(pcb_opctx_t *ctx, pcb_layer_t *dstly, pcb_poly_t *p
 	PCB_FLAG_CLEAR(PCB_FLAG_FOUND, polygon);
 
 	if (!dstly->polygon_tree)
-		dstly->polygon_tree = rnd_r_create_tree();
-	rnd_r_insert_entry(dstly->polygon_tree, (rnd_box_t *)polygon);
+		rnd_rtree_init(dstly->polygon_tree = malloc(sizeof(rnd_rtree_t)));
+	rnd_rtree_insert(dstly->polygon_tree, polygon, (rnd_rtree_box_t *)polygon);
 
 	pcb_poly_ppclear(polygon);
 	return polygon;
@@ -767,10 +768,10 @@ void *pcb_polyop_change_clear_size(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_pol
 			pcb_undo_add_obj_to_clear_size(PCB_OBJ_POLY, Layer, poly, poly);
 			pcb_poly_restore_to_poly(ctx->chgsize.pcb->Data, PCB_OBJ_POLY, Layer, poly);
 			pcb_poly_invalidate_erase(poly);
-			rnd_r_delete_entry(Layer->polygon_tree, (rnd_box_t *)poly);
+			rnd_rtree_delete(Layer->polygon_tree, poly, (rnd_rtree_box_t *)poly);
 			poly->Clearance = value;
 			pcb_poly_bbox(poly);
-			rnd_r_insert_entry(Layer->polygon_tree, (rnd_box_t *)poly);
+			rnd_rtree_insert(Layer->polygon_tree, poly, (rnd_rtree_box_t *)poly);
 			pcb_poly_clear_from_poly(ctx->chgsize.pcb->Data, PCB_OBJ_POLY, Layer, poly);
 			pcb_poly_invalidate_draw(Layer, poly);
 			return poly;
@@ -781,10 +782,15 @@ void *pcb_polyop_change_clear_size(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_pol
 
 	/* poly does not clear other polys */
 	rnd_message(RND_MSG_WARNING,
-		"To change the clearance of objects in a polygon, change \nthe objects, not the polygon.\n"
-		"Alternatively, set the clearpolypoly flag on the polygon to \nallow it to clear other polygons.\n"
-		"Hint: To set a minimum clearance for a group of objects, \nselect them all then :MinClearGap(Selected,=10,mil)\n",
-		"Ok", NULL);
+		"This operation had no visible effect.\n"
+		"If you meant this polygon should clear into other polygons, first set the clearpolypoly flag.\n"
+		"To change the clearance of objects within a polygon, change \nthe objects, not the polygon.\n");
+	rnd_message(RND_MSG_WARNING,
+		"Alternative: Consider using polygon-side clearance\n"
+		"   (host polygon's enforce_clearance property)\n"
+		"Alternative: The user script minclrgap can change clearance value to \nmeet a minimum value on all selected objects\n"
+		"   see: http://repo.hu/cgi-bin/edakrill.cgi?cmd=show&krill=igor2/script/pcb-rnd/minclrgap.krill\n"
+		"\n\n", NULL);
 
 	return NULL;
 }
@@ -805,13 +811,13 @@ static int undo_poly_enfc_swap(void *udata)
 	pcb_poly_restore_to_poly(g->data, PCB_OBJ_POLY, layer, g->poly);
 	pcb_poly_invalidate_erase(g->poly);
 	if (layer->polygon_tree != NULL)
-		rnd_r_delete_entry(layer->polygon_tree, (rnd_box_t *)g->poly);
+		rnd_rtree_delete(layer->polygon_tree, g->poly, (rnd_rtree_box_t *)g->poly);
 	tmp = g->poly->enforce_clearance;
 	g->poly->enforce_clearance = g->enfc;
 	g->enfc = tmp;
 	pcb_poly_bbox(g->poly);
 	if (layer->polygon_tree != NULL)
-		rnd_r_insert_entry(layer->polygon_tree, (rnd_box_t *)g->poly);
+		rnd_rtree_insert(layer->polygon_tree, g->poly, (rnd_rtree_box_t *)g->poly);
 	pcb_poly_clear_from_poly(g->data, PCB_OBJ_POLY, layer, g->poly);
 	if (layer->polygon_tree != NULL)
 		pcb_poly_invalidate_draw(layer, g->poly);
@@ -897,7 +903,7 @@ void *pcb_polyop_insert_point(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_poly_t *
 	 * second, shift the points up to make room for the new point
 	 */
 	pcb_poly_invalidate_erase(Polygon);
-	rnd_r_delete_entry(Layer->polygon_tree, (rnd_box_t *) Polygon);
+	rnd_rtree_delete(Layer->polygon_tree, Polygon, (rnd_rtree_box_t *)Polygon);
 	save = *pcb_poly_point_new(Polygon, ctx->insert.x, ctx->insert.y);
 	for (n = Polygon->PointN - 1; n > ctx->insert.idx; n--)
 		Polygon->Points[n] = Polygon->Points[n - 1];
@@ -912,7 +918,7 @@ void *pcb_polyop_insert_point(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_poly_t *
 	pcb_undo_add_obj_to_insert_point(PCB_OBJ_POLY_POINT, Layer, Polygon, &Polygon->Points[ctx->insert.idx]);
 
 	pcb_poly_bbox(Polygon);
-	rnd_r_insert_entry(Layer->polygon_tree, (rnd_box_t *) Polygon);
+	rnd_rtree_insert(Layer->polygon_tree, Polygon, (rnd_rtree_box_t *)Polygon);
 	pcb_poly_init_clip(PCB->Data, Layer, Polygon);
 	if (ctx->insert.forcible || !pcb_poly_remove_excess_points(Layer, Polygon))
 		pcb_poly_invalidate_draw(Layer, Polygon);
@@ -969,10 +975,10 @@ void *pcb_polyop_move_noclip(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_poly_t *P
 
 void *pcb_polyop_move(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_poly_t *Polygon)
 {
-	rnd_r_delete_entry(Layer->polygon_tree, (rnd_box_t *) Polygon);
+	rnd_rtree_delete(Layer->polygon_tree, Polygon, (rnd_rtree_box_t *)Polygon);
 	pcb_poly_pprestore(Polygon);
 	pcb_polyop_move_noclip(ctx, Layer, Polygon);
-	rnd_r_insert_entry(Layer->polygon_tree, (rnd_box_t *) Polygon);
+	rnd_rtree_insert(Layer->polygon_tree, Polygon, (rnd_rtree_box_t *)Polygon);
 	pcb_poly_ppclear(Polygon);
 	return Polygon;
 }
@@ -980,11 +986,11 @@ void *pcb_polyop_move(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_poly_t *Polygon)
 void *pcb_polyop_clip(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_poly_t *Polygon)
 {
 	if (ctx->clip.restore) {
-		rnd_r_delete_entry(Layer->polygon_tree, (rnd_box_t *) Polygon);
+		rnd_rtree_delete(Layer->polygon_tree, Polygon, (rnd_rtree_box_t *)Polygon);
 		pcb_poly_pprestore(Polygon);
 	}
 	if (ctx->clip.clear) {
-		rnd_r_insert_entry(Layer->polygon_tree, (rnd_box_t *) Polygon);
+		rnd_rtree_insert(Layer->polygon_tree, Polygon, (rnd_rtree_box_t *)Polygon);
 		pcb_poly_ppclear(Polygon);
 	}
 	return Polygon;
@@ -996,10 +1002,10 @@ void *pcb_polyop_move_point(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_poly_t *Po
 	if (Layer->meta.real.vis) {
 		pcb_poly_invalidate_erase(Polygon);
 	}
-	rnd_r_delete_entry(Layer->polygon_tree, (rnd_box_t *) Polygon);
+	rnd_rtree_delete(Layer->polygon_tree, Polygon, (rnd_rtree_box_t *)Polygon);
 	RND_MOVE_POINT(Point->X, Point->Y, ctx->move.dx, ctx->move.dy);
 	pcb_poly_bbox(Polygon);
-	rnd_r_insert_entry(Layer->polygon_tree, (rnd_box_t *) Polygon);
+	rnd_rtree_insert(Layer->polygon_tree, Polygon, (rnd_rtree_box_t *)Polygon);
 	pcb_poly_remove_excess_points(Layer, Polygon);
 	pcb_poly_init_clip(PCB->Data, Layer, Polygon);
 	if (Layer->meta.real.vis)
@@ -1011,15 +1017,15 @@ void *pcb_polyop_move_point(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_poly_t *Po
 /* moves a polygon between layers; lowlevel routines */
 void *pcb_polyop_move_to_layer_low(pcb_opctx_t *ctx, pcb_layer_t * Source, pcb_poly_t * polygon, pcb_layer_t * Destination)
 {
-	rnd_r_delete_entry(Source->polygon_tree, (rnd_box_t *) polygon);
+	rnd_rtree_delete(Source->polygon_tree, polygon, (rnd_rtree_box_t *)polygon);
 
 	pcb_poly_pprestore(polygon);
 	pcb_poly_unreg(polygon);
 	pcb_poly_reg(Destination, polygon);
 
 	if (!Destination->polygon_tree)
-		Destination->polygon_tree = rnd_r_create_tree();
-	rnd_r_insert_entry(Destination->polygon_tree, (rnd_box_t *) polygon);
+		rnd_rtree_init(Destination->polygon_tree = malloc(sizeof(rnd_rtree_t)));
+	rnd_rtree_insert(Destination->polygon_tree, polygon, (rnd_rtree_box_t *)polygon);
 
 	pcb_poly_ppclear(polygon);
 	return polygon;
@@ -1052,7 +1058,7 @@ void *pcb_polyop_move_to_layer(pcb_opctx_t *ctx, pcb_layer_t * Layer, pcb_poly_t
 void *pcb_polyop_destroy(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_poly_t *Polygon)
 {
 	pcb_term_del_auto((pcb_any_obj_t *)Polygon);
-	rnd_r_delete_entry(Layer->polygon_tree, (rnd_box_t *) Polygon);
+	rnd_rtree_delete(Layer->polygon_tree, Polygon, (rnd_rtree_box_t *)Polygon);
 	pcb_poly_free_fields(Polygon);
 
 	pcb_poly_free(Polygon);
@@ -1078,7 +1084,7 @@ void *pcb_polyop_destroy_point(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_poly_t
 	if (contour_points <= 3)
 		return pcb_polyop_remove_counter(ctx, Layer, Polygon, contour);
 
-	rnd_r_delete_entry(Layer->polygon_tree, (rnd_box_t *) Polygon);
+	rnd_rtree_delete(Layer->polygon_tree, Polygon, (rnd_rtree_box_t *)Polygon);
 
 	/* remove point from list, keep point order */
 	for (i = point_idx; i < Polygon->PointN - 1; i++)
@@ -1091,7 +1097,7 @@ void *pcb_polyop_destroy_point(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_poly_t
 			Polygon->HoleIndex[i]--;
 
 	pcb_poly_bbox(Polygon);
-	rnd_r_insert_entry(Layer->polygon_tree, (rnd_box_t *) Polygon);
+	rnd_rtree_insert(Layer->polygon_tree, Polygon, (rnd_rtree_box_t *)Polygon);
 	pcb_poly_init_clip(PCB->Data, Layer, Polygon);
 	pcb_poly_ppclear(Polygon);
 	return Polygon;
@@ -1187,7 +1193,7 @@ void *pcb_polyop_remove_point(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_poly_t *
 
 	/* insert the polygon-point into the undo list */
 	pcb_undo_add_obj_to_remove_point(PCB_OBJ_POLY_POINT, Layer, Polygon, point_idx);
-	rnd_r_delete_entry(Layer->polygon_tree, (rnd_box_t *) Polygon);
+	rnd_rtree_delete(Layer->polygon_tree, Polygon, (rnd_rtree_box_t *)Polygon);
 
 	/* remove point from list, keep point order */
 	for (i = point_idx; i < Polygon->PointN - 1; i++)
@@ -1200,7 +1206,7 @@ void *pcb_polyop_remove_point(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_poly_t *
 			Polygon->HoleIndex[i]--;
 
 	pcb_poly_bbox(Polygon);
-	rnd_r_insert_entry(Layer->polygon_tree, (rnd_box_t *) Polygon);
+	rnd_rtree_insert(Layer->polygon_tree, Polygon, (rnd_rtree_box_t *)Polygon);
 	pcb_poly_remove_excess_points(Layer, Polygon);
 	pcb_poly_init_clip(PCB->Data, Layer, Polygon);
 
@@ -1223,8 +1229,8 @@ void *pcb_polyop_copy(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_poly_t *Polygon)
 	pcb_poly_copy(polygon, Polygon, ctx->copy.DeltaX, ctx->copy.DeltaY);
 	pcb_poly_copy_meta(polygon, Polygon);
 	if (!Layer->polygon_tree)
-		Layer->polygon_tree = rnd_r_create_tree();
-	rnd_r_insert_entry(Layer->polygon_tree, (rnd_box_t *) polygon);
+		rnd_rtree_init(Layer->polygon_tree = malloc(sizeof(rnd_rtree_t)));
+	rnd_rtree_insert(Layer->polygon_tree, polygon, (rnd_rtree_box_t *)polygon);
 	pcb_poly_init_clip(PCB->Data, Layer, polygon);
 	pcb_poly_invalidate_draw(Layer, polygon);
 	pcb_undo_add_obj_to_create(PCB_OBJ_POLY, Layer, polygon, polygon);
@@ -1238,10 +1244,10 @@ void *pcb_polyop_rotate90(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_poly_t *Poly
 	if (Layer->meta.real.vis)
 		pcb_poly_invalidate_erase(Polygon);
 	if (Layer->polygon_tree != NULL)
-		rnd_r_delete_entry(Layer->polygon_tree, (rnd_box_t *) Polygon);
+		rnd_rtree_delete(Layer->polygon_tree, Polygon, (rnd_rtree_box_t *)Polygon);
 	pcb_poly_rotate90(Polygon, ctx->rotate.center_x, ctx->rotate.center_y, ctx->rotate.number);
 	if (Layer->polygon_tree != NULL)
-		rnd_r_insert_entry(Layer->polygon_tree, (rnd_box_t *) Polygon);
+		rnd_rtree_insert(Layer->polygon_tree, Polygon, (rnd_rtree_box_t *)Polygon);
 	pcb_poly_init_clip(PCB->Data, Layer, Polygon);
 	if (Layer->meta.real.vis)
 		pcb_poly_invalidate_draw(Layer, Polygon);
@@ -1297,7 +1303,7 @@ void pcb_poly_pre(pcb_poly_t *poly)
 
 	pcb_poly_pprestore(poly);
 	if (ly->polygon_tree != NULL)
-		rnd_r_delete_entry(ly->polygon_tree, (rnd_box_t *)poly);
+		rnd_rtree_delete(ly->polygon_tree, poly, (rnd_rtree_box_t *)poly);
 }
 
 void pcb_poly_post(pcb_poly_t *poly)
@@ -1307,7 +1313,7 @@ void pcb_poly_post(pcb_poly_t *poly)
 		return;
 
 	if (ly->polygon_tree != NULL)
-		rnd_r_insert_entry(ly->polygon_tree, (rnd_box_t *)poly);
+		rnd_rtree_insert(ly->polygon_tree, poly, (rnd_rtree_box_t *)poly);
 	pcb_poly_ppclear(poly);
 }
 
@@ -1384,6 +1390,17 @@ void pcb_poly_draw_label(pcb_draw_info_t *info, pcb_poly_t *poly, rnd_bool vis_s
 	}
 }
 
+/* Draw an as-drawn contour loop (outline or hole); first point is 'from',
+   last point is 'to'-1. */
+static void poly_draw_annot_loop(pcb_poly_t *poly, rnd_cardinal_t from, rnd_cardinal_t to)
+{
+	rnd_cardinal_t n;
+
+	for(n = from + 1; n < to; n++)
+		rnd_render->draw_line(pcb_draw_out.fgGC, poly->Points[n-1].X, poly->Points[n-1].Y, poly->Points[n].X, poly->Points[n].Y);
+	rnd_render->draw_line(pcb_draw_out.fgGC, poly->Points[n-1].X, poly->Points[n-1].Y, poly->Points[from].X, poly->Points[from].Y);
+}
+
 void pcb_poly_draw_annotation(pcb_draw_info_t *info, pcb_poly_t *poly)
 {
 	rnd_cardinal_t n, np;
@@ -1399,14 +1416,15 @@ void pcb_poly_draw_annotation(pcb_draw_info_t *info, pcb_poly_t *poly)
 	rnd_hid_set_line_width(pcb_draw_out.fgGC, -1);
 	rnd_hid_set_line_cap(pcb_draw_out.fgGC, rnd_cap_round);
 
-	if (poly->HoleIndexN > 0)
-		np = poly->HoleIndex[0];
-	else
-		np = poly->PointN;
+	/* draw the outline */
+	np = (poly->HoleIndexN > 0) ? poly->HoleIndex[0] : poly->PointN;
+	poly_draw_annot_loop(poly, 0, np);
 
-	for(n = 1; n < np; n++)
-		rnd_render->draw_line(pcb_draw_out.fgGC, poly->Points[n-1].X, poly->Points[n-1].Y, poly->Points[n].X, poly->Points[n].Y);
-	rnd_render->draw_line(pcb_draw_out.fgGC, poly->Points[n-1].X, poly->Points[n-1].Y, poly->Points[0].X, poly->Points[0].Y);
+	/* draw each cutout */
+	for(n = 0; n < poly->HoleIndexN; n++) {
+		np = ((n+1) < poly->HoleIndexN) ? poly->HoleIndex[n+1] : poly->PointN;
+		poly_draw_annot_loop(poly, poly->HoleIndex[n], np);
+	}
 }
 
 static void pcb_poly_draw_tr_offs(pcb_poly_it_t *it, rnd_coord_t offs)
@@ -1577,32 +1595,32 @@ static void pcb_poly_draw(pcb_draw_info_t *info, pcb_poly_t *polygon, int allow_
 	pcb_poly_draw_(info, polygon, allow_term_gfx);
 }
 
-rnd_r_dir_t pcb_poly_draw_callback(const rnd_box_t * b, void *cl)
+rnd_rtree_dir_t pcb_poly_draw_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
 	pcb_draw_info_t *i = cl;
-	pcb_poly_t *polygon = (pcb_poly_t *) b;
+	pcb_poly_t *polygon = (pcb_poly_t *)obj;
 
-	if (pcb_hidden_floater((pcb_any_obj_t*)b, i) || pcb_partial_export((pcb_any_obj_t*)b, i))
-		return RND_R_DIR_FOUND_CONTINUE;
+	if (pcb_hidden_floater((pcb_any_obj_t*)obj, i) || pcb_partial_export((pcb_any_obj_t*)obj, i))
+		return rnd_RTREE_DIR_FOUND_CONT;
 
 	if (!polygon->Clipped)
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 
 	if (!PCB->SubcPartsOn && pcb_lobj_parent_subc(polygon->parent_type, &polygon->parent))
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 
 	pcb_poly_draw(i, polygon, 0);
 
-	return RND_R_DIR_FOUND_CONTINUE;
+	return rnd_RTREE_DIR_FOUND_CONT;
 }
 
-rnd_r_dir_t pcb_poly_draw_term_callback(const rnd_box_t * b, void *cl)
+rnd_rtree_dir_t pcb_poly_draw_term_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
 	pcb_draw_info_t *i = cl;
-	pcb_poly_t *polygon = (pcb_poly_t *) b;
+	pcb_poly_t *polygon = (pcb_poly_t *)obj;
 
-	if (pcb_hidden_floater((pcb_any_obj_t*)b, i) || pcb_partial_export((pcb_any_obj_t*)b, i))
-		return RND_R_DIR_FOUND_CONTINUE;
+	if (pcb_hidden_floater((pcb_any_obj_t*)obj, i) || pcb_partial_export((pcb_any_obj_t*)obj, i))
+		return rnd_RTREE_DIR_FOUND_CONT;
 
 	if (polygon->Clipped == NULL) {
 		/* if poly is cleared out of existence, it may still have some annotations
@@ -1610,22 +1628,21 @@ rnd_r_dir_t pcb_poly_draw_term_callback(const rnd_box_t * b, void *cl)
 		   only thing affected is the as-drawn contour */
 		if (conf_core.editor.as_drawn_poly)
 			pcb_draw_annotation_add((pcb_any_obj_t *)polygon);
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 	}
 
 	if (!PCB->SubcPartsOn && pcb_lobj_parent_subc(polygon->parent_type, &polygon->parent))
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 
 	pcb_poly_draw(i, polygon, 1);
 
-	return RND_R_DIR_FOUND_CONTINUE;
+	return rnd_RTREE_DIR_FOUND_CONT;
 }
 
 /* erases a polygon on a layer */
 void pcb_poly_invalidate_erase(pcb_poly_t *Polygon)
 {
 	pcb_draw_invalidate(Polygon);
-	pcb_flag_erase(&Polygon->Flags);
 }
 
 void pcb_poly_invalidate_draw(pcb_layer_t *Layer, pcb_poly_t *Polygon)
