@@ -106,7 +106,7 @@ pcb_pstk_t *pcb_pstk_alloc(pcb_data_t *data)
 void pcb_pstk_free(pcb_pstk_t *ps)
 {
 	if ((ps->parent.data != NULL) && (ps->parent.data->padstack_tree != NULL))
-		rnd_r_delete_entry(ps->parent.data->padstack_tree, (rnd_box_t *)ps);
+		rnd_rtree_delete(ps->parent.data->padstack_tree, ps, (rnd_rtree_box_t *)ps);
 	pcb_attribute_free(&ps->Attributes);
 	pcb_pstk_unreg(ps);
 	free(ps->thermals.shape);
@@ -151,15 +151,17 @@ void pcb_pstk_add(pcb_data_t *data, pcb_pstk_t *ps)
 {
 	pcb_pstk_bbox(ps);
 	if (!data->padstack_tree)
-		data->padstack_tree = rnd_r_create_tree();
-	rnd_r_insert_entry(data->padstack_tree, (rnd_box_t *)ps);
+		rnd_rtree_init(data->padstack_tree = malloc(sizeof(rnd_rtree_t)));
+	rnd_rtree_insert(data->padstack_tree, ps, (rnd_rtree_box_t *)ps);
 	PCB_SET_PARENT(ps, data, data);
 }
 
-void pcb_pstk_bbox_ts(rnd_box_t *dst, pcb_pstk_proto_t *proto, pcb_pstk_tshape_t *ts, rnd_coord_t ox, rnd_coord_t oy)
+void pcb_pstk_bbox_ts(rnd_box_t *dst, pcb_pstk_proto_t *proto, pcb_pstk_tshape_t *ts, rnd_coord_t ox, rnd_coord_t oy, rnd_bool with_clearance, rnd_coord_t ps_clearance)
 {
 	int n, sn;
 	pcb_line_t line;
+	rnd_coord_t max_clr = 0;
+
 	assert(proto != NULL);
 
 	dst->X1 = dst->X2 = ox;
@@ -168,10 +170,34 @@ void pcb_pstk_bbox_ts(rnd_box_t *dst, pcb_pstk_proto_t *proto, pcb_pstk_tshape_t
 	if (ts != NULL)
 	for(sn = 0; sn < ts->len; sn++) {
 		pcb_pstk_shape_t *shape = ts->shape + sn;
+		rnd_coord_t clr = 0;
+		rnd_box_t tmpbox;
+
+		if (with_clearance) {
+			if (ps_clearance != 0) /* global clearance overrides */
+				clr = ps_clearance;
+			else
+				clr = shape->clearance/2;
+
+			if (clr > max_clr)
+				max_clr = clr;
+		}
+
+
 		switch(shape->shape) {
 			case PCB_PSSH_POLY:
+				tmpbox.X1 = tmpbox.Y1 = +RND_COORD_MAX;
+				tmpbox.X2 = tmpbox.Y2 = -RND_COORD_MAX;
+
 				for(n = 0; n < shape->data.poly.len; n++)
-					rnd_box_bump_point(dst, shape->data.poly.x[n] + ox, shape->data.poly.y[n] + oy);
+					rnd_box_bump_point(&tmpbox, shape->data.poly.x[n] + ox, shape->data.poly.y[n] + oy);
+
+				if (clr != 0) {
+					tmpbox.X1 -= clr; tmpbox.Y1 -= clr;
+					tmpbox.X2 += clr; tmpbox.Y2 += clr;
+				}
+
+				rnd_box_bump_box(dst, &tmpbox);
 				break;
 			case PCB_PSSH_LINE:
 				line.Point1.X = shape->data.line.x1 + ox;
@@ -179,14 +205,14 @@ void pcb_pstk_bbox_ts(rnd_box_t *dst, pcb_pstk_proto_t *proto, pcb_pstk_tshape_t
 				line.Point2.X = shape->data.line.x2 + ox;
 				line.Point2.Y = shape->data.line.y2 + oy;
 				line.Thickness = shape->data.line.thickness;
-				line.Clearance = 0;
+				line.Clearance = clr*2;
 				line.Flags = pcb_flag_make(shape->data.line.square ? PCB_FLAG_SQUARE : 0);
 				pcb_line_bbox(&line);
 				rnd_box_bump_box(dst, &line.BoundingBox);
 				break;
 			case PCB_PSSH_CIRC:
-				rnd_box_bump_point(dst, ox - shape->data.circ.dia/2, oy - shape->data.circ.dia/2);
-				rnd_box_bump_point(dst, ox + shape->data.circ.dia/2, oy + shape->data.circ.dia/2);
+				rnd_box_bump_point(dst, ox - shape->data.circ.dia/2 - clr, oy - shape->data.circ.dia/2 - clr);
+				rnd_box_bump_point(dst, ox + shape->data.circ.dia/2 + clr, oy + shape->data.circ.dia/2 + clr);
 				break;
 			case PCB_PSSH_HSHADOW:
 				break;
@@ -195,26 +221,23 @@ void pcb_pstk_bbox_ts(rnd_box_t *dst, pcb_pstk_proto_t *proto, pcb_pstk_tshape_t
 
 	if (proto->hdia != 0) {
 		/* corner case: no copper around the hole all 360 deg - let the hole stick out */
-		rnd_box_bump_point(dst, ox - proto->hdia/2, oy - proto->hdia/2);
-		rnd_box_bump_point(dst, ox + proto->hdia/2, oy + proto->hdia/2);
+		rnd_box_bump_point(dst, ox - proto->hdia/2 - max_clr, oy - proto->hdia/2 - max_clr);
+		rnd_box_bump_point(dst, ox + proto->hdia/2 + max_clr, oy + proto->hdia/2 + max_clr);
 	}
 
 	rnd_close_box(dst);
 }
 
+/* padstack is a special case: there can be local clearance in the proto when (obj)->Clearance is 0 */
+#define PCB_PSTK_HAS_CLEARANCE(obj) \
+	(PCB_FLAG_TEST(PCB_FLAG_CLEARLINE, (obj)))
+
 static void pcb_pstk_bbox_(rnd_box_t *dst, pcb_pstk_t *ps, rnd_bool copper_only)
 {
 	pcb_pstk_proto_t *proto = pcb_pstk_get_proto(ps);
 	pcb_pstk_tshape_t *ts = pcb_pstk_get_tshape(ps);
 
-	pcb_pstk_bbox_ts(dst, proto, ts, ps->x, ps->y);
-
-	if (!copper_only && PCB_NONPOLY_HAS_CLEARANCE(ps)) {
-		dst->X1 -= ps->Clearance;
-		dst->Y1 -= ps->Clearance;
-		dst->X2 += ps->Clearance;
-		dst->Y2 += ps->Clearance;
-	}
+	pcb_pstk_bbox_ts(dst, proto, ts, ps->x, ps->y, !copper_only && PCB_PSTK_HAS_CLEARANCE(ps), ps->Clearance);
 }
 
 
@@ -536,26 +559,26 @@ static void pcb_pstk_draw_shape_thin(pcb_draw_info_t *info, rnd_hid_gc_t gc, pcb
 	}
 }
 
-rnd_r_dir_t pcb_pstk_draw_callback(const rnd_box_t *b, void *cl)
+rnd_rtree_dir_t pcb_pstk_draw_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
 	pcb_draw_info_t *info = cl;
-	pcb_pstk_t *ps = (pcb_pstk_t *)b;
+	pcb_pstk_t *ps = (pcb_pstk_t *)obj;
 	pcb_pstk_shape_t *shape;
 	pcb_layergrp_t *grp = NULL;
 
-	pcb_obj_noexport(info, ps, return RND_R_DIR_NOT_FOUND);
+	pcb_obj_noexport(info, ps, return rnd_RTREE_DIR_NOT_FOUND_CONT);
 
-	if (pcb_hidden_floater((pcb_any_obj_t*)b, info) || pcb_partial_export((pcb_any_obj_t*)b, info))
-		return RND_R_DIR_FOUND_CONTINUE;
+	if (pcb_hidden_floater((pcb_any_obj_t*)ps, info) || pcb_partial_export((pcb_any_obj_t*)ps, info))
+		return rnd_RTREE_DIR_FOUND_CONT;
 
 	if (!PCB->SubcPartsOn && pcb_gobj_parent_subc(ps->parent_type, &ps->parent))
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 
 	if (info->objcb.pstk.gid < 0) {
 		if (info->objcb.pstk.shape_mask != 0)
 			shape = pcb_pstk_shape(ps, info->objcb.pstk.shape_mask, info->objcb.pstk.comb);
 		else
-			return RND_R_DIR_NOT_FOUND;
+			return rnd_RTREE_DIR_NOT_FOUND_CONT;
 	}
 	else {
 		int n;
@@ -564,7 +587,7 @@ rnd_r_dir_t pcb_pstk_draw_callback(const rnd_box_t *b, void *cl)
 		for(n = 0, lid = grp->lid; n < grp->len; n++,lid++) {
 			if (*lid < ps->thermals.used) {
 				if ((ps->thermals.shape[*lid] & PCB_THERMAL_ON) && ((ps->thermals.shape[*lid] & 3) == PCB_THERMAL_NOSHAPE))
-					return RND_R_DIR_NOT_FOUND;
+					return rnd_RTREE_DIR_NOT_FOUND_CONT;
 			}
 		}
 	}
@@ -586,12 +609,12 @@ rnd_r_dir_t pcb_pstk_draw_callback(const rnd_box_t *b, void *cl)
 			pcb_draw_delay_label_add((pcb_any_obj_t *)ps);
 	}
 
-	return RND_R_DIR_FOUND_CONTINUE;
+	return rnd_RTREE_DIR_FOUND_CONT;
 }
 
-rnd_r_dir_t pcb_pstk_draw_mark_callback(const rnd_box_t *b, void *cl)
+rnd_rtree_dir_t pcb_pstk_draw_mark_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
-	pcb_pstk_t *ps = (pcb_pstk_t *)b;
+	pcb_pstk_t *ps = (pcb_pstk_t *)obj;
 	pcb_pstk_proto_t *proto;
 	rnd_coord_t mark, mark2;
 
@@ -605,7 +628,7 @@ rnd_r_dir_t pcb_pstk_draw_mark_callback(const rnd_box_t *b, void *cl)
 
 	mark2 = mark*2;
 	if (mark2 < rnd_render->coord_per_pix)
-		return RND_R_DIR_FOUND_CONTINUE;
+		return rnd_RTREE_DIR_FOUND_CONT;
 
 	/* draw the cross using xor */
 	set_ps_annot_color(pcb_draw_out.fgGC, ps);
@@ -617,20 +640,20 @@ rnd_r_dir_t pcb_pstk_draw_mark_callback(const rnd_box_t *b, void *cl)
 	else
 		rnd_render->draw_line(pcb_draw_out.fgGC, ps->x-rnd_render->coord_per_pix, ps->y, ps->x+rnd_render->coord_per_pix, ps->y);
 
-	return RND_R_DIR_FOUND_CONTINUE;
+	return rnd_RTREE_DIR_FOUND_CONT;
 }
 
-rnd_r_dir_t pcb_pstk_draw_label_callback(const rnd_box_t *b, void *cl)
+rnd_rtree_dir_t pcb_pstk_draw_label_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
 	pcb_draw_info_t *info = cl;
-	pcb_pstk_t *ps = (pcb_pstk_t *)b;
+	pcb_pstk_t *ps = (pcb_pstk_t *)obj;
 	int is_drawn = (ps->draw_stamp == info->draw_stamp);
 
 	/* do not draw any label if the padstack is not visible, to avoid overlapping
 	   term labels of sides: two SMD pads on the two sides, turn off bottom to
 	   see top only */
 	if (!is_drawn)
-		return RND_R_DIR_FOUND_CONTINUE;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 
 	/* draw the label if enabled, after everything else is drawn */
 	if (ps->term != NULL) {
@@ -641,47 +664,47 @@ rnd_r_dir_t pcb_pstk_draw_label_callback(const rnd_box_t *b, void *cl)
 	if (ps->noexport)
 		pcb_obj_noexport_mark(ps, ps->x, ps->y);
 
-	return RND_R_DIR_FOUND_CONTINUE;
+	return rnd_RTREE_DIR_FOUND_CONT;
 }
 
-rnd_r_dir_t pcb_pstk_draw_hole_callback(const rnd_box_t *b, void *cl)
+rnd_rtree_dir_t pcb_pstk_draw_hole_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
 	pcb_draw_info_t *info = cl;
-	pcb_pstk_t *ps = (pcb_pstk_t *)b;
+	pcb_pstk_t *ps = (pcb_pstk_t *)obj;
 	pcb_pstk_proto_t *proto;
 
-	pcb_obj_noexport(info, ps, return RND_R_DIR_NOT_FOUND);
+	pcb_obj_noexport(info, ps, return rnd_RTREE_DIR_NOT_FOUND_CONT);
 
 	if (pcb_hidden_floater(ps, info) || pcb_partial_export(ps, info))
-		return RND_R_DIR_FOUND_CONTINUE;
+		return rnd_RTREE_DIR_FOUND_CONT;
 
 	/* hide subc parts if requested */
 	if (!info->pcb->SubcPartsOn && pcb_gobj_parent_subc(ps->parent_type, &ps->parent))
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 
 	/* no hole in this layer group */
 	if (info->objcb.pstk.gid >= 0) {
 		if (!pcb_pstk_bb_drills(info->pcb, ps, info->objcb.pstk.gid, &proto))
-			return RND_R_DIR_FOUND_CONTINUE;
+			return rnd_RTREE_DIR_FOUND_CONT;
 	}
 	else
 		proto = pcb_pstk_get_proto(ps);
 
 	/* No hole at all */
 	if ((proto == NULL) || (proto->hdia <= 0))
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 
 	/* hole is plated, but the caller doesn't want plated holes */
 	if (proto->hplated && (!(info->objcb.pstk.holetype & PCB_PHOLE_PLATED)))
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 
 	/* hole is unplated, but the caller doesn't want unplated holes */
 	if (!proto->hplated && (!(info->objcb.pstk.holetype & PCB_PHOLE_UNPLATED)))
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 
 	/* BBvia, but the caller doesn't want BBvias */
 	if (((proto->htop != 0) || (proto->hbottom != 0)) && (!(info->objcb.pstk.holetype & PCB_PHOLE_BB)))
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 
 	/* actual hole */
 	rnd_hid_set_line_width(pcb_draw_out.drillGC, 0);
@@ -699,51 +722,51 @@ rnd_r_dir_t pcb_pstk_draw_hole_callback(const rnd_box_t *b, void *cl)
 		rnd_render->draw_arc(pcb_draw_out.fgGC, ps->x, ps->y, r, r, 20, 290);
 	}
 
-	return RND_R_DIR_FOUND_CONTINUE;
+	return rnd_RTREE_DIR_FOUND_CONT;
 }
 
-rnd_r_dir_t pcb_pstk_draw_slot_callback(const rnd_box_t *b, void *cl)
+rnd_rtree_dir_t pcb_pstk_draw_slot_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
 	pcb_draw_info_t *info = cl;
-	pcb_pstk_t *ps = (pcb_pstk_t *)b;
+	pcb_pstk_t *ps = (pcb_pstk_t *)obj;
 	pcb_pstk_proto_t *proto;
 	pcb_pstk_shape_t *shape;
 
-	pcb_obj_noexport(info, ps, return RND_R_DIR_NOT_FOUND);
+	pcb_obj_noexport(info, ps, return rnd_RTREE_DIR_NOT_FOUND_CONT);
 
 	if (pcb_hidden_floater(ps, info) || pcb_partial_export(ps, info))
-		return RND_R_DIR_FOUND_CONTINUE;
+		return rnd_RTREE_DIR_FOUND_CONT;
 
 	/* hide subc parts if requested */
 	if (!info->pcb->SubcPartsOn && pcb_gobj_parent_subc(ps->parent_type, &ps->parent))
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 
 	/* no slot in this layer group */
 	if (info->objcb.pstk.gid >= 0) {
 		if (!pcb_pstk_bb_drills(info->pcb, ps, info->objcb.pstk.gid, &proto))
-			return RND_R_DIR_FOUND_CONTINUE;
+			return rnd_RTREE_DIR_FOUND_CONT;
 	}
 	else
 		proto = pcb_pstk_get_proto(ps);
 
 	if (proto == NULL)
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 
 	/* No slot at all */
 	if (proto->mech_idx < 0)
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 
 	/* hole is plated, but the caller doesn't want plated holes */
 	if (proto->hplated && (!(info->objcb.pstk.holetype & PCB_PHOLE_PLATED)))
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 
 	/* hole is unplated, but the caller doesn't want unplated holes */
 	if (!proto->hplated && (!(info->objcb.pstk.holetype & PCB_PHOLE_UNPLATED)))
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 
 	/* BBslot, but the caller doesn't want BBslot */
 	if (((proto->htop != 0) || (proto->hbottom != 0)) && (!(info->objcb.pstk.holetype & PCB_PHOLE_BB)))
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 
 	/* actual slot */
 	shape = pcb_pstk_shape(ps, PCB_LYT_MECH, PCB_LYC_AUTO);
@@ -756,7 +779,7 @@ rnd_r_dir_t pcb_pstk_draw_slot_callback(const rnd_box_t *b, void *cl)
 			pcb_pstk_draw_shape_solid(info, pcb_draw_out.drillGC, ps, shape);
 	}
 
-	return RND_R_DIR_FOUND_CONTINUE;
+	return rnd_RTREE_DIR_FOUND_CONT;
 }
 
 void pcb_pstk_thindraw(pcb_draw_info_t *info, rnd_hid_gc_t gc, pcb_pstk_t *ps)
@@ -772,10 +795,20 @@ void pcb_pstk_thindraw(pcb_draw_info_t *info, rnd_hid_gc_t gc, pcb_pstk_t *ps)
 		if (shape == NULL)
 			shape = pcb_pstk_shape_gid(pcb, ps, gid, PCB_LYC_SUB, NULL);
 	}
-	else { /* no pcb means buffer - take the first shape, whichever layer it is for */
-		pcb_pstk_tshape_t *ts = pcb_pstk_get_tshape(ps);
-		if ((ts != NULL)  && (ts->len > 0))
-			shape = ts->shape;
+	else { /* no pcb means buffer  */
+		pcb_pstk_tshape_t *ts;
+
+		/* try a copper shape first */
+		shape = pcb_pstk_shape(ps, PCB_LYT_COPPER | PCB_LYT_TOP, 0);
+		if (shape == NULL)
+			shape = pcb_pstk_shape(ps, PCB_LYT_COPPER | PCB_LYT_BOTTOM, 0);
+
+		/* fallback: take the first shape, whichever layer it is for */
+		if (shape == NULL) {
+			ts = pcb_pstk_get_tshape(ps);
+			if ((ts != NULL) && (ts->len > 0))
+				shape = ts->shape;
+		}
 	}
 
 	if (shape != NULL)
@@ -785,9 +818,9 @@ void pcb_pstk_thindraw(pcb_draw_info_t *info, rnd_hid_gc_t gc, pcb_pstk_t *ps)
 		rnd_render->draw_arc(gc, ps->x, ps->y, proto->hdia/2, proto->hdia/2, 0, 360);
 	}
 	else {
-		shape = pcb_pstk_shape(ps, PCB_LYT_MECH, PCB_LYC_AUTO);
-		if (shape != NULL)
-			pcb_pstk_draw_shape_thin(info, gc, ps, shape);
+		pcb_pstk_shape_t *mech_shape = pcb_pstk_shape(ps, PCB_LYT_MECH, PCB_LYC_AUTO);
+		if ((mech_shape != NULL) && (mech_shape != shape))
+			pcb_pstk_draw_shape_thin(info, gc, ps, mech_shape);
 	}
 }
 
@@ -847,7 +880,7 @@ void pcb_pstk_draw_preview(pcb_board_t *pcb, const pcb_pstk_t *ps, char *layers,
 			if (info.objcb.pstk.shape_mask == PCB_LYT_MECH)
 				draw_hole = 1;
 			else
-				pcb_pstk_draw_callback((rnd_box_t *)ps, &info);
+				pcb_pstk_draw_callback(&info, (void *)ps, (rnd_rtree_box_t *)ps);
 		}
 	}
 
@@ -865,22 +898,22 @@ void pcb_pstk_draw_preview(pcb_board_t *pcb, const pcb_pstk_t *ps, char *layers,
 			if (info.objcb.pstk.shape_mask == PCB_LYT_MECH)
 				draw_hole = 2;
 			else
-				pcb_pstk_draw_callback((rnd_box_t *)ps, &info);
+				pcb_pstk_draw_callback(&info, (void *)ps, (rnd_rtree_box_t *)ps);
 		}
 	}
 
 	if (draw_hole) {
 		info.objcb.pstk.shape_mask = PCB_LYT_MECH;
 		info.objcb.pstk.is_current = (draw_hole > 1);
-		pcb_pstk_draw_hole_callback((rnd_box_t *)ps, &info);
-		pcb_pstk_draw_slot_callback((rnd_box_t *)ps, &info);
+		pcb_pstk_draw_hole_callback(&info, (void *)ps, (rnd_rtree_box_t *)ps);
+		pcb_pstk_draw_slot_callback(&info, (void *)ps, (rnd_rtree_box_t *)ps);
 	}
 
 	if (mark)
-		pcb_pstk_draw_mark_callback((rnd_box_t *)ps, &info);
+		pcb_pstk_draw_mark_callback(&info, (void *)ps, (rnd_rtree_box_t *)ps);
 
 	if (label)
-		pcb_pstk_draw_label_callback((rnd_box_t *)ps, &info);
+		pcb_pstk_draw_label_callback(&info, (void *)ps, (rnd_rtree_box_t *)ps);
 }
 
 
@@ -1115,6 +1148,8 @@ static rnd_bool pcb_pstk_shape_hole_break(pcb_pstk_shape_t *shp, rnd_coord_t hdi
 		case PCB_PSSH_HSHADOW:
 			return 0; /* there's no copper that could break */
 		case PCB_PSSH_CIRC:
+			if (shp->data.circ.dia <= 0)
+				return 0; /* historical: compat padstack loader will create 0 sized copper circles for the clearance side effect */
 			dist = sqrt((double)shp->data.circ.x*(double)shp->data.circ.x + (double)shp->data.circ.y*(double)shp->data.circ.y);
 			neck = (double)(shp->data.circ.dia - hdia) / 2.0 - dist;
 			break;
@@ -1210,17 +1245,17 @@ static int undo_pstk_mirror_swap(void *udata)
 
 	/* if mirror center is not 0, also move, to emulate that the mirror took
 	   place around that point */
-	if (((g->y_offs != 0) || (ps->y != 0)) && (g->y_offs != PCB_PSTK_DONT_MIRROR_COORDS)) {
+	if (g->y_offs != PCB_PSTK_DONT_MIRROR_COORDS) {
 		pcb_poly_restore_to_poly(ps->parent.data, PCB_OBJ_PSTK, NULL, ps);
 		pcb_pstk_invalidate_erase(ps);
 		if (ps->parent.data->padstack_tree != NULL)
-			rnd_r_delete_entry(ps->parent.data->padstack_tree, (rnd_box_t *)ps);
+			rnd_rtree_delete(ps->parent.data->padstack_tree, ps, (rnd_rtree_box_t *)ps);
 
 		ps->y = PCB_SWAP_Y(ps->y) + g->y_offs;
 		pcb_pstk_bbox(ps);
 
 		if (ps->parent.data->padstack_tree != NULL)
-			rnd_r_insert_entry(ps->parent.data->padstack_tree, (rnd_box_t *)ps);
+			rnd_rtree_insert(ps->parent.data->padstack_tree, ps, (rnd_rtree_box_t *)ps);
 		pcb_poly_clear_from_poly(ps->parent.data, PCB_OBJ_PSTK, NULL, ps);
 		pcb_pstk_invalidate_draw(ps);
 	}
@@ -1429,7 +1464,7 @@ static int undo_change_instance_swap(void *udata)
 	pcb_poly_restore_to_poly(ps->parent.data, PCB_OBJ_PSTK, NULL, ps);
 	pcb_pstk_invalidate_erase(ps);
 	if (ps->parent.data->padstack_tree != NULL)
-		rnd_r_delete_entry(ps->parent.data->padstack_tree, (rnd_box_t *)ps);
+		rnd_rtree_delete(ps->parent.data->padstack_tree, ps, (rnd_rtree_box_t *)ps);
 
 	swap(ps->proto,      u->proto,     rnd_cardinal_t);
 	swap(ps->Clearance,  u->clearance, rnd_coord_t);
@@ -1443,7 +1478,7 @@ static int undo_change_instance_swap(void *udata)
 
 	pcb_pstk_bbox(ps);
 	if (ps->parent.data->padstack_tree != NULL)
-		rnd_r_insert_entry(ps->parent.data->padstack_tree, (rnd_box_t *)ps);
+		rnd_rtree_insert(ps->parent.data->padstack_tree, ps, (rnd_rtree_box_t *)ps);
 	pcb_poly_clear_from_poly(ps->parent.data, PCB_OBJ_PSTK, NULL, ps);
 	pcb_pstk_invalidate_draw(ps);
 
@@ -1586,7 +1621,7 @@ void pcb_pstk_pre(pcb_pstk_t *pstk)
 {
 	pcb_data_t *data = pstk->parent.data;
 	if (data->padstack_tree != NULL)
-		rnd_r_delete_entry(data->padstack_tree, (rnd_box_t *)pstk);
+		rnd_rtree_delete(data->padstack_tree, pstk, (rnd_rtree_box_t *)pstk);
 	pcb_poly_restore_to_poly(data, PCB_OBJ_PSTK, NULL, pstk);
 }
 
@@ -1594,7 +1629,7 @@ void pcb_pstk_post(pcb_pstk_t *pstk)
 {
 	pcb_data_t *data = pstk->parent.data;
 	if (data->padstack_tree != NULL)
-		rnd_r_insert_entry(data->padstack_tree, (rnd_box_t *)pstk);
+		rnd_rtree_insert(data->padstack_tree, pstk, (rnd_rtree_box_t *)pstk);
 	pcb_poly_clear_from_poly(data, PCB_OBJ_PSTK, NULL, pstk);
 }
 
@@ -1618,7 +1653,7 @@ rnd_coord_t pcb_pstk_pen_dia(pcb_board_t *pcb)
 	if (proto == NULL)
 		return 0;
 
-	pcb_pstk_bbox_ts(&bb, proto, &proto->tr.array[0], 0, 0);
+	pcb_pstk_bbox_ts(&bb, proto, &proto->tr.array[0], 0, 0, 0, 0);
 
 	return RND_MAX(bb.X2 - bb.X1, bb.Y2 - bb.Y1);
 }
