@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  pcb-rnd, interactive printed circuit board design
- *  Copyright (C) 2017,2020 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2017,2020,2024 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -496,7 +496,7 @@ TODO("layer: make a real scoring mechanism here instead of ly1, ly2, ly3")
 
 	if (remove_src) {
 		if (src->parent.data->padstack_tree != NULL)
-			rnd_r_delete_entry(src->parent.data->padstack_tree, (rnd_box_t *)src);
+			rnd_rtree_delete(src->parent.data->padstack_tree, src, (rnd_rtree_box_t *)src);
 		pcb_pstk_free(src);
 	}
 
@@ -509,8 +509,8 @@ int pcb_pstk_proto_conv_selection(pcb_board_t *pcb, pcb_pstk_proto_t *dst, int q
 	vtp0_t objs;
 
 	vtp0_init(&objs);
-	pcb_data_list_by_flag(pcb->Data, &objs, PCB_OBJ_CLASS_REAL, PCB_FLAG_SELECTED);
-	ret = pcb_pstk_proto_conv(pcb->Data, dst, quiet, &objs, ox, oy);
+	pcb_data_list_by_flag(PCB_REAL_DATA(pcb), &objs, PCB_OBJ_CLASS_REAL, PCB_FLAG_SELECTED);
+	ret = pcb_pstk_proto_conv(PCB_REAL_DATA(pcb), dst, quiet, &objs, ox, oy);
 	vtp0_uninit(&objs);
 
 	return ret;
@@ -1254,6 +1254,34 @@ void pcb_pstk_shape_grow_(pcb_pstk_shape_t *shp, rnd_bool is_absolute, rnd_coord
 	}
 }
 
+void pcb_pstk_shape_move_(pcb_pstk_shape_t *shp, rnd_coord_t dx, rnd_coord_t dy)
+{
+	int n;
+
+	switch(shp->shape) {
+		case PCB_PSSH_LINE:
+			shp->data.line.x1 += dx;
+			shp->data.line.y1 += dy;
+			shp->data.line.x2 += dx;
+			shp->data.line.y2 += dy;
+			break;
+		case PCB_PSSH_CIRC:
+			shp->data.circ.x += dx;
+			shp->data.circ.y += dy;
+			break;
+		case PCB_PSSH_HSHADOW:
+			break;
+		case PCB_PSSH_POLY:
+			rnd_polyarea_free(&shp->data.poly.pa);
+			for(n = 0; n < shp->data.poly.len; n++) {
+				shp->data.poly.x[n] += dx;
+				shp->data.poly.y[n] += dy;
+			}
+			pcb_pstk_shape_update_pa(&shp->data.poly);
+			break;
+	}
+}
+
 
 static void pcb_pstk_shape_scale_(pcb_pstk_shape_t *shp, double sx, double sy)
 {
@@ -1472,6 +1500,23 @@ void pcb_pstk_shape_grow(pcb_pstk_proto_t *proto, int tridx, int shpidx, rnd_boo
 	pcb_pstk_shape_grow_(shp, is_absolute, val);
 }
 
+void pcb_pstk_shape_move(pcb_pstk_proto_t *proto, int tridx, int shpidx, rnd_coord_t dx, rnd_coord_t dy, int undoable)
+{
+	pcb_pstk_tshape_t *tshp = &proto->tr.array[tridx];
+	pcb_pstk_shape_t *shp = &tshp->shape[shpidx];
+
+	if (undoable) {
+		undo_shape_geo_t *g = pstk_shape_geo_undo_init(proto, tridx, shpidx);
+		if (g != NULL) {
+			pcb_pstk_shape_copy(&g->shp, shp);
+			g->shp_valid = 1;
+			pcb_undo_inc_serial();
+		}
+	}
+
+	pcb_pstk_shape_move_(shp, dx, dy);
+}
+
 void pcb_pstk_shape_scale(pcb_pstk_proto_t *proto, int tridx, int shpidx, double sx, double sy, int undoable)
 {
 	pcb_pstk_tshape_t *tshp = &proto->tr.array[tridx];
@@ -1501,6 +1546,30 @@ void pcb_pstk_proto_grow(pcb_pstk_proto_t *proto, rnd_bool is_absolute, rnd_coor
 	pcb_pstk_proto_update(proto);
 }
 
+void pcb_pstk_proto_move(pcb_pstk_proto_t *proto, rnd_coord_t dx, rnd_coord_t dy, int undoable)
+{
+	int n, i;
+
+	/* do the same move on all shapes of all transformed variants */
+	for(n = 0; n < proto->tr.used; n++) {
+		pcb_pstk_tshape_t *ts = &proto->tr.array[n];
+		rnd_coord_t tx = dx, ty = dy;
+
+		if (ts->rot != 0) {
+			double rad = (-ts->rot) / RND_RAD_TO_DEG;
+			rnd_rotate(&tx, &ty, 0, 0, cos(rad), sin(rad));
+		}
+		if (ts->smirror)
+			ty = -ty;
+		if (ts->xmirror)
+			tx = -tx;
+
+		for(i = 0; i < proto->tr.array[n].len; i++)
+			pcb_pstk_shape_move(proto, n, i, tx, ty, undoable);
+	}
+	pcb_pstk_proto_update(proto);
+}
+
 int pcb_pstk_alloc_shape_idx(pcb_pstk_proto_t *proto, int tr_idx)
 {
 	int d = proto->tr.array[tr_idx].len;
