@@ -63,8 +63,6 @@
 #include <librnd/hid/hid_inlines.h>
 #include "extobj.h"
 
-#define SUBC_AUX_NAME "subc-aux"
-
 static const char core_subc_cookie[] = "core-subc";
 
 void pcb_subc_reg(pcb_data_t *data, pcb_subc_t *subc)
@@ -139,7 +137,7 @@ void pcb_subc_free(pcb_subc_t *sc)
 {
 	pcb_extobj_del_pre(sc);
 	if ((sc->parent.data != NULL) && (sc->parent.data->subc_tree != NULL))
-		rnd_r_delete_entry(sc->parent.data->subc_tree, (rnd_box_t *)sc);
+		rnd_rtree_delete(sc->parent.data->subc_tree, sc, (rnd_rtree_box_t *)sc);
 	pcb_attribute_free(&sc->Attributes);
 	if (sc->parent_type != PCB_PARENT_INVALID)
 		pcb_subc_unreg(sc);
@@ -919,6 +917,7 @@ void pcb_subc_dup_layer_objs(pcb_subc_t *dst_sc, pcb_layer_t *dl, pcb_layer_t *s
 	pcb_gfx_t *gfx, *ngfx;
 	gdl_iterator_t it;
 	pcb_board_t *pcb = NULL;
+	pcb_subc_t *src_sc = sl->parent.data->parent.subc;
 
 	assert(dst_sc->parent_type == PCB_PARENT_DATA);
 	if (dst_sc->parent.data->parent_type != PCB_PARENT_INVALID) {
@@ -929,12 +928,15 @@ void pcb_subc_dup_layer_objs(pcb_subc_t *dst_sc, pcb_layer_t *dl, pcb_layer_t *s
 	if (pcb != NULL)
 		pcb_data_clip_inhibit_inc(pcb->Data);
 
+	if (src_sc->aux_layer == NULL)
+		pcb_subc_cache_find_aux(src_sc);
+
 	linelist_foreach(&sl->Line, &it, line) {
 		nline = pcb_line_dup_at(dl, line, dx, dy);
 		MAYBE_KEEP_ID(nline, line);
 		if (nline != NULL) {
 			PCB_SET_PARENT(nline, layer, dl);
-			if (!PCB_FLAG_TEST(PCB_FLAG_FLOATER, nline)) {
+			if (!PCB_FLAG_TEST(PCB_FLAG_FLOATER, nline) && (sl != src_sc->aux_layer)) {
 				pcb_box_bump_box_noflt(&dst_sc->BoundingBox, &nline->BoundingBox);
 				pcb_box_bump_box_noflt(&dst_sc->bbox_naked, &nline->bbox_naked);
 			}
@@ -1065,7 +1067,7 @@ pcb_subc_t *pcb_subc_dup_at(pcb_board_t *pcb, pcb_data_t *dst, const pcb_subc_t
 	/* bind the via rtree so that vias added in this subc show up on the board */
 	if (pcb != NULL) {
 		if (pcb->Data->padstack_tree == NULL)
-			pcb->Data->padstack_tree = rnd_r_create_tree();
+			rnd_rtree_init(pcb->Data->padstack_tree = malloc(sizeof(rnd_rtree_t)));
 		sc->data->padstack_tree = pcb->Data->padstack_tree;
 	}
 
@@ -1115,8 +1117,8 @@ pcb_subc_t *pcb_subc_dup_at(pcb_board_t *pcb, pcb_data_t *dst, const pcb_subc_t
 
 	if (pcb != NULL) {
 		if (!dst->subc_tree)
-			dst->subc_tree = rnd_r_create_tree();
-		rnd_r_insert_entry(dst->subc_tree, (rnd_box_t *)sc);
+			rnd_rtree_init(dst->subc_tree = malloc(sizeof(rnd_rtree_t)));
+		rnd_rtree_insert(dst->subc_tree, sc, (rnd_rtree_box_t *)sc);
 	}
 
 	return sc;
@@ -1138,7 +1140,6 @@ void pcb_subc_bbox(pcb_subc_t *sc)
 void EraseSubc(pcb_subc_t *sc)
 {
 	pcb_draw_invalidate(sc);
-/*	pcb_flag_erase(&sc->Flags); ??? */
 }
 
 void DrawSubc(pcb_subc_t *sc)
@@ -1173,9 +1174,9 @@ void *pcb_subc_op(pcb_data_t *Data, pcb_subc_t *sc, pcb_opfunc_t *opfunc, pcb_op
 	EraseSubc(sc);
 	if (pcb_data_get_top(Data) != NULL) {
 		if (Data->subc_tree != NULL)
-			rnd_r_delete_entry(Data->subc_tree, (rnd_box_t *)sc);
+			rnd_rtree_delete(Data->subc_tree, sc, (rnd_rtree_box_t *)sc);
 		else
-			Data->subc_tree = rnd_r_create_tree();
+			rnd_rtree_init(Data->subc_tree = malloc(sizeof(rnd_rtree_t)));
 	}
 
 	/* for calculating the new bounding box on the fly */
@@ -1184,6 +1185,9 @@ void *pcb_subc_op(pcb_data_t *Data, pcb_subc_t *sc, pcb_opfunc_t *opfunc, pcb_op
 	sc->bbox_naked.X1 = sc->bbox_naked.Y1 = RND_MAX_COORD;
 	sc->bbox_naked.X2 = sc->bbox_naked.Y2 = -RND_MAX_COORD;
 
+	if (sc->aux_layer == NULL)
+		pcb_subc_cache_find_aux(sc);
+
 	/* execute on layer locals */
 	for(n = 0; n < sc->data->LayerN; n++) {
 		pcb_layer_t *sl = sc->data->Layer + n;
@@ -1194,10 +1198,9 @@ void *pcb_subc_op(pcb_data_t *Data, pcb_subc_t *sc, pcb_opfunc_t *opfunc, pcb_op
 		pcb_gfx_t *gfx;
 		gdl_iterator_t it;
 
-
 		linelist_foreach(&sl->Line, &it, line) {
 			pcb_object_operation(opfunc, ctx, PCB_OBJ_LINE, sl, line, line);
-			if (!PCB_FLAG_TEST(PCB_FLAG_FLOATER, line)) {
+			if (!PCB_FLAG_TEST(PCB_FLAG_FLOATER, line) && (sl != sc->aux_layer)) {
 				pcb_box_bump_box_noflt(&sc->BoundingBox, &line->BoundingBox);
 				pcb_box_bump_box_noflt(&sc->bbox_naked, &line->bbox_naked);
 			}
@@ -1259,16 +1262,17 @@ void *pcb_subc_op(pcb_data_t *Data, pcb_subc_t *sc, pcb_opfunc_t *opfunc, pcb_op
 		if (sc->extobj != NULL) { /* ugly corner case: extobj calls may have added the subc to the rtree already, do not add it twice */
 			rnd_rtree_it_t it;
 			rnd_box_t *b;
-
-			for(b = rnd_r_first(Data->subc_tree, &it); b != NULL; b = rnd_r_next(&it)) {
-				if (b == (rnd_box_t *)sc) {
-					doit = 0;
-					break;
+			if (Data->subc_tree != NULL) {
+				for(b = rnd_rtree_all_first(&it, Data->subc_tree); b != NULL; b = rnd_rtree_all_next(&it)) {
+					if (b == (rnd_box_t *)sc) {
+						doit = 0;
+						break;
+					}
 				}
 			}
 		}
-		if (doit)
-			rnd_r_insert_entry(Data->subc_tree, (rnd_box_t *)sc);
+		if (doit && (Data->subc_tree != NULL))
+			rnd_rtree_insert(Data->subc_tree, (void *)sc, (rnd_rtree_box_t *)sc);
 	}
 
 	sc->part_changed_bbox_dirty = 0; /* we've just recalculated the bbox */
@@ -1436,7 +1440,7 @@ static int subc_relocate_layer_objs(pcb_layer_t *dl, pcb_data_t *src_data, pcb_l
 	linelist_foreach(&sl->Line, &it, line) {
 		if (src_has_real_layer) {
 			pcb_poly_restore_to_poly(src_data, PCB_OBJ_LINE, sl, line);
-			rnd_r_delete_entry(sl->line_tree, (rnd_box_t *)line);
+			rnd_rtree_delete(sl->line_tree, line, (rnd_rtree_box_t *)line);
 			chg++;
 		}
 		PCB_FLAG_CLEAR(PCB_FLAG_WARN | PCB_FLAG_FOUND | PCB_FLAG_SELECTED, line);
@@ -1445,7 +1449,7 @@ static int subc_relocate_layer_objs(pcb_layer_t *dl, pcb_data_t *src_data, pcb_l
 			pcb_line_reg(dl, line);
 		}
 		if ((dl != NULL) && (dl->line_tree != NULL)) {
-			rnd_r_insert_entry(dl->line_tree, (rnd_box_t *)line);
+			rnd_rtree_insert(dl->line_tree, line, (rnd_rtree_box_t *)line);
 			chg++;
 		}
 		if (dst_is_pcb && (dl != NULL))
@@ -1455,7 +1459,7 @@ static int subc_relocate_layer_objs(pcb_layer_t *dl, pcb_data_t *src_data, pcb_l
 	arclist_foreach(&sl->Arc, &it, arc) {
 		if (src_has_real_layer) {
 			pcb_poly_restore_to_poly(src_data, PCB_OBJ_ARC, sl, arc);
-			rnd_r_delete_entry(sl->arc_tree, (rnd_box_t *)arc);
+			rnd_rtree_delete(sl->arc_tree, arc, (rnd_rtree_box_t *)arc);
 			chg++;
 		}
 		PCB_FLAG_CLEAR(PCB_FLAG_WARN | PCB_FLAG_FOUND | PCB_FLAG_SELECTED, arc);
@@ -1464,7 +1468,7 @@ static int subc_relocate_layer_objs(pcb_layer_t *dl, pcb_data_t *src_data, pcb_l
 			pcb_arc_reg(dl, arc);
 		}
 		if ((dl != NULL) && (dl->arc_tree != NULL)) {
-			rnd_r_insert_entry(dl->arc_tree, (rnd_box_t *)arc);
+			rnd_rtree_insert(dl->arc_tree, arc, (rnd_rtree_box_t *)arc);
 			chg++;
 		}
 		if (dst_is_pcb && (dl != NULL))
@@ -1474,7 +1478,7 @@ static int subc_relocate_layer_objs(pcb_layer_t *dl, pcb_data_t *src_data, pcb_l
 	textlist_foreach(&sl->Text, &it, text) {
 		if (src_has_real_layer) {
 			pcb_poly_restore_to_poly(src_data, PCB_OBJ_LINE, sl, text);
-			rnd_r_delete_entry(sl->text_tree, (rnd_box_t *)text);
+			rnd_rtree_delete(sl->text_tree, text, (rnd_rtree_box_t *)text);
 			chg++;
 		}
 		PCB_FLAG_CLEAR(PCB_FLAG_WARN | PCB_FLAG_FOUND | PCB_FLAG_SELECTED, text);
@@ -1483,7 +1487,7 @@ static int subc_relocate_layer_objs(pcb_layer_t *dl, pcb_data_t *src_data, pcb_l
 			pcb_text_reg(dl, text);
 		}
 		if ((dl != NULL) && (dl->text_tree != NULL)) {
-			rnd_r_insert_entry(dl->text_tree, (rnd_box_t *)text);
+			rnd_rtree_insert(dl->text_tree, text, (rnd_rtree_box_t *)text);
 			chg++;
 		}
 		if (dst_is_pcb && (dl != NULL))
@@ -1493,7 +1497,7 @@ static int subc_relocate_layer_objs(pcb_layer_t *dl, pcb_data_t *src_data, pcb_l
 	polylist_foreach(&sl->Polygon, &it, poly) {
 		pcb_poly_pprestore(poly);
 		if (src_has_real_layer) {
-			rnd_r_delete_entry(sl->polygon_tree, (rnd_box_t *)poly);
+			rnd_rtree_delete(sl->polygon_tree, poly, (rnd_rtree_box_t *)poly);
 			chg++;
 		}
 		PCB_FLAG_CLEAR(PCB_FLAG_WARN | PCB_FLAG_FOUND | PCB_FLAG_SELECTED, poly);
@@ -1502,7 +1506,7 @@ static int subc_relocate_layer_objs(pcb_layer_t *dl, pcb_data_t *src_data, pcb_l
 			pcb_poly_reg(dl, poly);
 		}
 		if ((dl != NULL) && (dl->polygon_tree != NULL)) {
-			rnd_r_insert_entry(dl->polygon_tree, (rnd_box_t *)poly);
+			rnd_rtree_insert(dl->polygon_tree, poly, (rnd_rtree_box_t *)poly);
 			chg++;
 		}
 		if (dst_is_pcb && (dl != NULL))
@@ -1511,7 +1515,7 @@ static int subc_relocate_layer_objs(pcb_layer_t *dl, pcb_data_t *src_data, pcb_l
 
 	gfxlist_foreach(&sl->Gfx, &it, gfx) {
 		if (src_has_real_layer) {
-			rnd_r_delete_entry(sl->gfx_tree, (rnd_box_t *)gfx);
+			rnd_rtree_delete(sl->gfx_tree, gfx, (rnd_rtree_box_t *)gfx);
 			chg++;
 		}
 		PCB_FLAG_CLEAR(PCB_FLAG_WARN | PCB_FLAG_FOUND | PCB_FLAG_SELECTED, gfx);
@@ -1520,7 +1524,7 @@ static int subc_relocate_layer_objs(pcb_layer_t *dl, pcb_data_t *src_data, pcb_l
 			pcb_gfx_reg(dl, gfx);
 		}
 		if ((dl != NULL) && (dl->gfx_tree != NULL)) {
-			rnd_r_insert_entry(dl->gfx_tree, (rnd_box_t *)gfx);
+			rnd_rtree_insert(dl->gfx_tree, gfx, (rnd_rtree_box_t *)gfx);
 			chg++;
 		}
 	}
@@ -1534,7 +1538,7 @@ static int subc_bind_globals(pcb_data_t *dst, pcb_subc_t *sc, int dst_is_pcb)
 
 	if ((dst != NULL) && (dst_is_pcb)) {
 		if (dst->padstack_tree == NULL)
-			dst->padstack_tree = rnd_r_create_tree();
+			rnd_rtree_init(dst->padstack_tree = malloc(sizeof(rnd_rtree_t)));
 		sc->data->padstack_tree = dst->padstack_tree;
 		chg++;
 	}
@@ -1557,10 +1561,10 @@ static int subc_relocate_globals(pcb_data_t *dst, pcb_data_t *new_parent, pcb_su
 		assert(proto != NULL); /* the prototype must be accessible at the source else we can't add it in the dest */
 		pcb_poly_restore_to_poly(ps->parent.data, PCB_OBJ_PSTK, NULL, ps);
 		if (sc->data->padstack_tree != NULL)
-			rnd_r_delete_entry(sc->data->padstack_tree, (rnd_box_t *)ps);
+			rnd_rtree_delete(sc->data->padstack_tree, ps, (rnd_rtree_box_t *)ps);
 		PCB_FLAG_CLEAR(PCB_FLAG_WARN | PCB_FLAG_FOUND | PCB_FLAG_SELECTED, ps);
 		if ((dst != NULL) && (dst->padstack_tree != NULL))
-			rnd_r_insert_entry(dst->padstack_tree, (rnd_box_t *)ps);
+			rnd_rtree_insert(dst->padstack_tree, ps, (rnd_rtree_box_t *)ps);
 		if ((move_obj) && (dst != NULL)) {
 			pcb_pstk_unreg(ps);
 			pcb_pstk_reg(dst, ps);
@@ -1600,7 +1604,7 @@ void *pcb_subcop_move_buffer(pcb_opctx_t *ctx, pcb_subc_t *sc)
 			clip.clip.pcb = ctx->buffer.pcb;
 			pcb_subc_op(ctx->buffer.pcb->Data, sc, &ClipFunctions, &clip, PCB_SUBCOP_UNDO_SUBC);
 		}
-		rnd_r_delete_entry(ctx->buffer.pcb->Data->subc_tree, (rnd_box_t *)sc);
+		rnd_rtree_delete(ctx->buffer.pcb->Data->subc_tree, sc, (rnd_rtree_box_t *)sc);
 	}
 
 	pcb_subc_unreg(sc);
@@ -1608,8 +1612,8 @@ void *pcb_subcop_move_buffer(pcb_opctx_t *ctx, pcb_subc_t *sc)
 
 	if (dst_is_pcb) {
 		if (ctx->buffer.dst->subc_tree == NULL)
-			ctx->buffer.dst->subc_tree = rnd_r_create_tree();
-		rnd_r_insert_entry(ctx->buffer.dst->subc_tree, (rnd_box_t *)sc);
+			rnd_rtree_init(ctx->buffer.dst->subc_tree = malloc(sizeof(rnd_rtree_t)));
+		rnd_rtree_insert(ctx->buffer.dst->subc_tree, sc, (rnd_rtree_box_t *)sc);
 	}
 
 	if (dst_is_pcb)
@@ -1628,11 +1632,11 @@ void *pcb_subcop_move_buffer(pcb_opctx_t *ctx, pcb_subc_t *sc)
 			}
 			else {
 				/* need to create the trees so that move and other ops work */
-				if (sl->line_tree == NULL) sl->line_tree = rnd_r_create_tree();
-				if (sl->arc_tree == NULL) sl->arc_tree = rnd_r_create_tree();
-				if (sl->text_tree == NULL) sl->text_tree = rnd_r_create_tree();
-				if (sl->polygon_tree == NULL) sl->polygon_tree = rnd_r_create_tree();
-				if (sl->gfx_tree == NULL) sl->gfx_tree = rnd_r_create_tree();
+				if (sl->line_tree == NULL)    rnd_rtree_init(sl->line_tree = malloc(sizeof(rnd_rtree_t)));
+				if (sl->arc_tree == NULL)     rnd_rtree_init(sl->arc_tree = malloc(sizeof(rnd_rtree_t)));
+				if (sl->text_tree == NULL)    rnd_rtree_init(sl->text_tree = malloc(sizeof(rnd_rtree_t)));
+				if (sl->polygon_tree == NULL) rnd_rtree_init(sl->polygon_tree = malloc(sizeof(rnd_rtree_t)));
+				if (sl->gfx_tree == NULL)     rnd_rtree_init(sl->gfx_tree = malloc(sizeof(rnd_rtree_t)));
 				if (!(sl->meta.bound.type & PCB_LYT_VIRTUAL))
 					rnd_message(RND_MSG_ERROR, "Couldn't bind subc layer %s on buffer move\n", sl->name == NULL ? "<anonymous>" : sl->name);
 			}
@@ -1640,10 +1644,29 @@ void *pcb_subcop_move_buffer(pcb_opctx_t *ctx, pcb_subc_t *sc)
 		else
 			dl = ctx->buffer.dst->Layer + n;
 
-		if (dst_is_pcb)
+		if (dst_is_pcb) {
 			subc_bind_layer(dl, sl, dst_is_pcb);
-		else
+		}
+		else {
 			subc_relocate_layer_objs(dl, ctx->buffer.src, sl, src_has_real_layer, dst_is_pcb, 0);
+
+			/* Happens when moving the subc into buffer, most notably into removelist:
+			   - layer objects got registered in dl-> trees
+			   - if we don't do the bindings here, subc won't remember its layer objects are registered in which trees
+			   - on subc free, layer objects are freed, but rtree del won't run as subc's layer rtree is NULL
+			   - layer objects will remain on old dl-> trees (e.g. on removelist trees)
+			   - as long as the object is still alive in removelist, it goes on unnoticed; the undo list keeps objects alive; but these are really ghost objects in the rtree because sc free already free'd the layer object
+			   - clearing the undo list, {u c}, will flush the remove list and that will expose the bug in form of  ghost rtree objects are invalid memory reads now
+			   - see TODO:7 @ r38121
+				(anchor #1)
+			*/
+			if ((sl->line_tree != NULL) || (sl->arc_tree != NULL) || (sl->text_tree != NULL) || (sl->polygon_tree != NULL))
+				rnd_message(RND_MSG_ERROR, "pcb_subcop_move_buffer(): expected empty layer object trees.\nPlease report this bug.\n");
+			/* gfx_tree is always bound for some reason (do not free it, it's on the board) */
+			if (sl->gfx_tree != NULL)
+				sl->gfx_tree = NULL;
+			pcb_layer_link_trees(sl, dl);
+		}
 	}
 
 	if (dst_is_pcb) {
@@ -1654,8 +1677,11 @@ void *pcb_subcop_move_buffer(pcb_opctx_t *ctx, pcb_subc_t *sc)
 		clip.clip.pcb = ctx->buffer.pcb;
 		pcb_subc_op(ctx->buffer.dst, sc, &ClipFunctions, &clip, PCB_SUBCOP_UNDO_SUBC);
 	}
-	else
+	else {
 		subc_relocate_globals(ctx->buffer.dst, sc->data, sc, dst_is_pcb, 0);
+		/* see anchor #1 above */
+		sc->data->padstack_tree = ctx->buffer.dst->padstack_tree;
+	}
 
 
 	PCB_FLAG_CLEAR(PCB_FLAG_WARN | PCB_FLAG_FOUND | PCB_FLAG_SELECTED, sc);
@@ -1740,11 +1766,11 @@ int pcb_subc_rebind(pcb_board_t *pcb, pcb_subc_t *sc)
 				continue;
 
 			/* make sure all trees exist on the dest layer - if these are the first objects there we may need to create them */
-			if (dl->line_tree == NULL) dl->line_tree = rnd_r_create_tree();
-			if (dl->arc_tree == NULL) dl->arc_tree = rnd_r_create_tree();
-			if (dl->text_tree == NULL) dl->text_tree = rnd_r_create_tree();
-			if (dl->polygon_tree == NULL) dl->polygon_tree = rnd_r_create_tree();
-			if (dl->gfx_tree == NULL) dl->gfx_tree = rnd_r_create_tree();
+			if (dl->line_tree == NULL)    rnd_rtree_init(dl->line_tree = malloc(sizeof(rnd_rtree_t)));
+			if (dl->arc_tree == NULL)     rnd_rtree_init(dl->arc_tree = malloc(sizeof(rnd_rtree_t)));
+			if (dl->text_tree == NULL)    rnd_rtree_init(dl->text_tree = malloc(sizeof(rnd_rtree_t)));
+			if (dl->polygon_tree == NULL) rnd_rtree_init(dl->polygon_tree = malloc(sizeof(rnd_rtree_t)));
+			if (dl->gfx_tree == NULL)     rnd_rtree_init(dl->gfx_tree = malloc(sizeof(rnd_rtree_t)));
 		}
 
 		if (subc_relocate_layer_objs(dl, pcb->Data, sl, src_has_real_layer, 1, 0) > 0)
@@ -1760,7 +1786,7 @@ int pcb_subc_rebind(pcb_board_t *pcb, pcb_subc_t *sc)
 void pcb_subc_bind_globals(pcb_board_t *pcb, pcb_subc_t *subc)
 {
 	if (pcb->Data->padstack_tree == NULL)
-		pcb->Data->padstack_tree = rnd_r_create_tree();
+		rnd_rtree_init(pcb->Data->padstack_tree = malloc(sizeof(rnd_rtree_t)));
 	subc->data->padstack_tree = pcb->Data->padstack_tree;
 TODO("subc: subc-in-subc: bind subc rtree")
 }
@@ -1902,7 +1928,7 @@ void *pcb_subcop_change_name(pcb_opctx_t *ctx, pcb_subc_t *sc)
 void *pcb_subcop_destroy(pcb_opctx_t *ctx, pcb_subc_t *sc)
 {
 	if (ctx->remove.pcb->Data->subc_tree != NULL)
-		rnd_r_delete_entry(ctx->remove.pcb->Data->subc_tree, (rnd_box_t *)sc);
+		rnd_rtree_delete(ctx->remove.pcb->Data->subc_tree, sc, (rnd_rtree_box_t *)sc);
 
 	EraseSubc(sc);
 	pcb_subc_free(sc);
@@ -1986,7 +2012,7 @@ static int undo_subc_mirror_swap(void *udata)
 	pcb_data_t *data = g->subc->parent.data;
 
 	if ((data != NULL) && (data->subc_tree != NULL))
-		rnd_r_delete_entry(data->subc_tree, (rnd_box_t *)g->subc);
+		rnd_rtree_delete(data->subc_tree, g->subc, (rnd_rtree_box_t *)g->subc);
 
 	pcb_undo_freeze_add();
 	pcb_data_mirror(g->subc->data, g->y_offs, g->smirror ? PCB_TXM_SIDE : PCB_TXM_COORD, g->smirror, 0);
@@ -1994,7 +2020,7 @@ static int undo_subc_mirror_swap(void *udata)
 	pcb_subc_bbox(g->subc);
 
 	if ((data != NULL) && (data->subc_tree != NULL))
-		rnd_r_insert_entry(data->subc_tree, (rnd_box_t *)g->subc);
+		rnd_rtree_insert(data->subc_tree, g->subc, (rnd_rtree_box_t *)g->subc);
 
 	return 0;
 }
@@ -2032,13 +2058,13 @@ void pcb_subc_mirror(pcb_data_t *data, pcb_subc_t *subc, rnd_coord_t y_offs, rnd
 void pcb_subc_scale(pcb_data_t *data, pcb_subc_t *subc, double sx, double sy, double sth, int recurse)
 {
 	if ((data != NULL) && (data->subc_tree != NULL))
-		rnd_r_delete_entry(data->subc_tree, (rnd_box_t *)subc);
+		rnd_rtree_delete(data->subc_tree, subc, (rnd_rtree_box_t *)subc);
 
 	pcb_data_scale(subc->data, sx, sy, sth, recurse);
 	pcb_subc_bbox(subc);
 
 	if ((data != NULL) && (data->subc_tree != NULL))
-		rnd_r_insert_entry(data->subc_tree, (rnd_box_t *)subc);
+		rnd_rtree_insert(data->subc_tree, subc, (rnd_rtree_box_t *)subc);
 }
 
 
@@ -2060,7 +2086,7 @@ rnd_bool pcb_subc_change_side(pcb_subc_t *subc, rnd_coord_t yoff)
 	/* mirror object geometry and stackup */
 
 	if ((data != NULL) && (data->subc_tree != NULL))
-		rnd_r_delete_entry(data->subc_tree, (rnd_box_t *)subc);
+		rnd_rtree_delete(data->subc_tree, subc, (rnd_rtree_box_t *)subc);
 
 	pcb_undo_freeze_add();
 	pcb_data_mirror(subc->data, yoff, PCB_TXM_SIDE, 1, 0);
@@ -2076,7 +2102,7 @@ rnd_bool pcb_subc_change_side(pcb_subc_t *subc, rnd_coord_t yoff)
 	pcb_subc_bbox(subc);
 
 	if ((data != NULL) && (data->subc_tree != NULL))
-		rnd_r_insert_entry(data->subc_tree, (rnd_box_t *)subc);
+		rnd_rtree_insert(data->subc_tree, subc, (rnd_rtree_box_t *)subc);
 
 	pcb_undo_add_subc_to_otherside(PCB_OBJ_SUBC, subc, subc, subc, yoff);
 
@@ -2096,7 +2122,7 @@ do { \
 		int on_bottom; \
 		if (pcb_subc_get_side(subc, &on_bottom) == 0) { \
 			if ((!!on_bottom) != (!!conf_core.editor.show_solder_side)) \
-				return RND_R_DIR_FOUND_CONTINUE; \
+				return rnd_RTREE_DIR_NOT_FOUND_CONT; \
 		} \
 	} \
 } while(0)
@@ -2106,10 +2132,10 @@ do { \
 #include "draw.h"
 
 
-rnd_r_dir_t pcb_draw_subc_mark(const rnd_box_t *b, void *cl)
+rnd_rtree_dir_t pcb_draw_subc_mark(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
 	pcb_draw_info_t *info = cl;
-	pcb_subc_t *subc = (pcb_subc_t *) b;
+	pcb_subc_t *subc = (pcb_subc_t *)obj;
 	rnd_box_t *bb = &subc->BoundingBox;
 	int selected, locked;
 	int freq = conf_core.appearance.subc.dash_freq;
@@ -2143,27 +2169,27 @@ rnd_r_dir_t pcb_draw_subc_mark(const rnd_box_t *b, void *cl)
 		pcb_draw_dashed_line(info, pcb_draw_out.fgGC, bb->X2, bb->Y2, bb->X1, bb->Y2, freq, rnd_true);
 	}
 
-	return RND_R_DIR_FOUND_CONTINUE;
+	return rnd_RTREE_DIR_FOUND_CONT;
 }
 
-rnd_r_dir_t draw_subc_mark_callback(const rnd_box_t *b, void *cl)
+rnd_rtree_dir_t draw_subc_mark_callback(void *cl, void *obj, const rnd_rtree_box_t *b)
 {
 	pcb_draw_info_t *info = cl;
-	pcb_subc_t *subc = (pcb_subc_t *) b;
+	pcb_subc_t *subc = (pcb_subc_t *)obj;
 	pcb_extobj_t *extobj = pcb_extobj_get(subc);
 
 	if ((extobj != NULL) && (extobj->draw_mark != NULL)) {
 		extobj->draw_mark(info, subc);
-		return RND_R_DIR_FOUND_CONTINUE;
+		return rnd_RTREE_DIR_FOUND_CONT;
 	}
 
-	return pcb_draw_subc_mark(b, cl);
+	return pcb_draw_subc_mark(cl, obj, b);
 }
 
-rnd_r_dir_t draw_subc_label_callback(const rnd_box_t *b, void *cl)
+rnd_rtree_dir_t draw_subc_label_callback(void *cl, void *obj, const rnd_rtree_box_t *b)
 {
 	pcb_draw_info_t *info = cl;
-	pcb_subc_t *subc = (pcb_subc_t *) b;
+	pcb_subc_t *subc = (pcb_subc_t *)obj;
 	rnd_box_t *bb = &subc->BoundingBox;
 	rnd_coord_t x0, y0, dx, dy;
 	rnd_font_t *font = &PCB->fontkit.dflt;
@@ -2221,7 +2247,7 @@ rnd_r_dir_t draw_subc_label_callback(const rnd_box_t *b, void *cl)
 	else if (subc->refdes != NULL)
 		pcb_label_draw(info, x0, y0, conf_core.appearance.term_label_size/2.0, 0, 0, subc->refdes, 0);
 
-	return RND_R_DIR_FOUND_CONTINUE;
+	return rnd_RTREE_DIR_FOUND_CONT;
 }
 
 static int subc_prev_layer_vis(pcb_layer_t *layer)
@@ -2242,9 +2268,9 @@ static void subc_prev_draw_pstk(const pcb_subc_t *sc, const rnd_box_t *drawn_are
 
 	for(o = rnd_rtree_first(&it, sc->data->padstack_tree, (rnd_rtree_box_t *)drawn_area); o != NULL; o = rnd_rtree_next(&it)) {
 		if (pcb_obj_is_under(o, sc->data)) {
-			pcb_pstk_draw_callback((rnd_box_t *)o, info);
+			pcb_pstk_draw_callback(info, (void *)o, (rnd_rtree_box_t *)o);
 			if (PCB->hole_on)
-				pcb_pstk_draw_hole_callback((rnd_box_t *)o, info);
+				pcb_pstk_draw_hole_callback(info, (void *)o, (rnd_rtree_box_t *)o);
 		}
 	}
 }
@@ -2309,8 +2335,8 @@ void pcb_subc_draw_preview(const pcb_subc_t *sc, const rnd_box_t *drawn_area)
 	if (sc->data->padstack_tree != NULL)
 	for(o = rnd_rtree_first(&it, sc->data->padstack_tree, (rnd_rtree_box_t *)drawn_area); o != NULL; o = rnd_rtree_next(&it)) {
 		if (pcb_obj_is_under(o, sc->data)) {
-			pcb_pstk_draw_mark_callback((rnd_box_t *)o, &info);
-			pcb_pstk_draw_label_callback((rnd_box_t *)o, &info);
+			pcb_pstk_draw_mark_callback(&info, (void *)o, (rnd_rtree_box_t *)o);
+			pcb_pstk_draw_label_callback(&info, (void *)o, (rnd_rtree_box_t *)o);
 		}
 	}
 }
@@ -2776,6 +2802,7 @@ pcb_subc_t *pcb_subc_replace(pcb_board_t *pcb, pcb_subc_t *dst, pcb_subc_t *src,
 	if (dst_on_bottom != src_on_bottom)
 		pcb_subc_change_side(placed, 2 * oy - PCB->hidlib.dwg.Y2);
 
+	pcb_undo_freeze_add();
 	if (pcb_subcrepl_apply_thermals_floaters(&repl, placed)) {
 		pcb_opctx_t clip;
 		clip.clip.pcb = pcb;
@@ -2785,7 +2812,6 @@ pcb_subc_t *pcb_subc_replace(pcb_board_t *pcb, pcb_subc_t *dst, pcb_subc_t *src,
 		pcb_subc_op(pcb->Data, placed, &ClipFunctions, &clip, PCB_SUBCOP_UNDO_NORMAL);
 	}
 
-	pcb_undo_freeze_add();
 	pcb_subc_select(pcb, placed, (flags & PCB_FLAG_SELECTED) ? PCB_CHGFLG_SET : PCB_CHGFLG_CLEAR, 0);
 	pcb_undo_unfreeze_add();
 
