@@ -33,7 +33,6 @@
 #include "obj_common.h"
 #include "layer.h"
 #include <librnd/core/global_typedefs.h>
-#include <librnd/poly/rtree2_compat.h>
 
 
 typedef enum pcb_subc_cached_s {
@@ -119,9 +118,12 @@ long pcb_subc_unbind_all(pcb_board_t *pcb, pcb_layer_t *brdly, int undoable);
 pcb_layer_t *pcb_subc_get_layer(pcb_subc_t *sc, pcb_layer_type_t lyt, pcb_layer_combining_t comb, rnd_bool_t alloc, const char *name, rnd_bool req_name_match);
 
 #include <librnd/poly/rtree.h>
-rnd_r_dir_t pcb_draw_subc_mark(const rnd_box_t *b, void *cl); /* low level version, does not do extobj */
-rnd_r_dir_t draw_subc_mark_callback(const rnd_box_t *b, void *cl);
-rnd_r_dir_t draw_subc_label_callback(const rnd_box_t *b, void *cl);
+
+/* low level version, does not do extobj */
+rnd_rtree_dir_t pcb_draw_subc_mark(void *cl, void *obj, const rnd_rtree_box_t *box);
+
+rnd_rtree_dir_t draw_subc_mark_callback(void *cl, void *obj, const rnd_rtree_box_t *b);
+rnd_rtree_dir_t draw_subc_label_callback(void *cl, void *obj, const rnd_rtree_box_t *b);
 void DrawSubc(pcb_subc_t *sc);
 void EraseSubc(pcb_subc_t *sc);
 
@@ -204,7 +206,7 @@ pcb_subc_t *pcb_subc_copy_meta(pcb_subc_t *dst, const pcb_subc_t *src);
 pcb_subc_t *pcb_subc_dup_at(pcb_board_t *pcb, pcb_data_t *dst, const pcb_subc_t *src, rnd_coord_t dx, rnd_coord_t dy, rnd_bool keep_ids, rnd_bool undoable);
 
 /* Replace dst with a copy of src in place (preserving location and orientation
-   and attributes. If add_undo is true, add the old subc del and the new subc
+   and attributes). If add_undo is true, add the old subc del and the new subc
    creation to the undo list. If dub is true, do not try to match rotation or
    pick up coords, just use crosshair and current loc. */
 pcb_subc_t *pcb_subc_replace(pcb_board_t *pcb, pcb_subc_t *dst, pcb_subc_t *src, rnd_bool add_undo, rnd_bool dumb);
