@@ -550,7 +550,7 @@ int pcb_write_font(rnd_font_t *Ptr, const char *Filename, const char *fmt)
 	pcb_plug_io_t *p = pcb_io_find_writer(PCB_IOT_FONT, fmt);
 
 	if (p != NULL) {
-		res = p->write_font(p, Ptr, Filename);
+		res = p->write_font(p, Ptr, Filename, fmt);
 		/*newfmt = 1;*/
 	}
 	else
@@ -642,15 +642,15 @@ static int real_load_pcb(const char *Filename, const char *fmt, rnd_bool revert,
 
 		pcb_board_new_postproc(PCB, 0);
 		if (how == 0) {
+			pcb_board_t *pcb;
+
 			/* update cursor location */
 			PCB->hidlib.ch_x = pcb_crosshair.X = (PCB->hidlib.dwg.X1 + PCB->hidlib.dwg.X2) / 2;
 			PCB->hidlib.ch_y = pcb_crosshair.Y = (PCB->hidlib.dwg.Y1 + PCB->hidlib.dwg.Y2) / 2;
-
-			/* update cursor confinement and output area (scrollbars) */
-			pcb_board_resize(PCB->hidlib.dwg.X1, PCB->hidlib.dwg.Y1, PCB->hidlib.dwg.X2, PCB->hidlib.dwg.Y2, 0);
+			pcb_board_replaced();
 		}
 
-		/* have to be called after pcb_board_resize() so vis update is after a board changed update */
+		/* have to be called after pcb_board_replaced() so vis update is after a board changed update */
 		rnd_event(&PCB->hidlib, PCB_EVENT_LAYERS_CHANGED, NULL);
 		pcb_layervis_reset_stack(&PCB->hidlib);
 
@@ -820,29 +820,40 @@ int pcb_save_pcb(const char *file, const char *fmt)
 	return retcode;
 }
 
-int pcb_load_pcb(const char *file, const char *fmt, rnd_bool require_font, int how)
+/* When PCB is a footprint, tune board size to match the footprint's; call
+   this right after real_load_pcb(), in case real_load_pcb() did not fail.
+   Returns -1 on error. */
+static int footprint_as_pcb_resize(void)
 {
-	int res = real_load_pcb(file, fmt, rnd_false, require_font, how);
-	if (res == 0) {
-		rnd_file_loaded_set_at("design", "main", file, PCB->is_footprint ? "footprint" : "board");
 		if (PCB->is_footprint) {
 			rnd_box_t b;
 			/* a footprint has no board size set, need to invent one */
 			pcb_data_bbox(&b, PCB->Data, 0);
 			if ((b.X2 < b.X1) || (b.Y2 < b.Y1)) {
 				rnd_message(RND_MSG_ERROR, "Invalid footprint file: can not determine bounding box\n");
-				res = -1;
+				return -1;
 			}
-			else
-				pcb_board_resize(b.X1, b.Y1, b.X2*1.5, b.Y2*1.5, 0);
+			pcb_board_resize(b.X1, b.Y1, b.X2*1.5, b.Y2*1.5, 0);
 		}
+	return 0;
+}
+
+int pcb_load_pcb(const char *file, const char *fmt, rnd_bool require_font, int how)
+{
+	int res = real_load_pcb(file, fmt, rnd_false, require_font, how);
+	if (res == 0) {
+		rnd_file_loaded_set_at("design", "main", file, PCB->is_footprint ? "footprint" : "board");
+		res |= footprint_as_pcb_resize();
 	}
 	return res;
 }
 
 int pcb_revert_pcb(void)
 {
-	return real_load_pcb(PCB->hidlib.loadname, NULL, rnd_true, rnd_true, 0);
+	int r = real_load_pcb(PCB->hidlib.loadname, NULL, rnd_true, rnd_true, 0);
+	if (r == 0)
+		r |= footprint_as_pcb_resize();
+	return r;
 }
 
 int pcb_load_buffer(rnd_design_t *hidlib, pcb_buffer_t *buff, const char *fn, const char *fmt)
