@@ -33,7 +33,7 @@
  */
 #include "config.h"
 
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/rnd_conf.h>
 
 #include "board.h"
 #include "data.h"
@@ -44,7 +44,7 @@
 #include "draw.h"
 #include "search.h"
 #include "crosshair.h"
-#include <librnd/core/tool.h>
+#include <librnd/hid/tool.h>
 #include <librnd/core/actions.h>
 
 #include "obj_poly.h"
@@ -99,7 +99,7 @@ static fgw_error_t pcb_act_Polygon(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	RND_ACT_CONVARG(1, FGW_KEYWORD, Polygon, op = fgw_keyword(&argv[1]));
 
 	if ((argc > 1) && ((rnd_conf.editor.mode == pcb_crosshair.tool_poly) || (rnd_conf.editor.mode == pcb_crosshair.tool_poly_hole))) {
-		rnd_hid_notify_crosshair_change(RND_ACT_HIDLIB, rnd_false);
+		rnd_hid_notify_crosshair_change(RND_ACT_DESIGN, rnd_false);
 		switch(op) {
 			/* close open polygon if possible */
 		case F_Close:
@@ -116,7 +116,7 @@ static fgw_error_t pcb_act_Polygon(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			pcb_polygon_go_to_prev_point();
 			break;
 		}
-		rnd_hid_notify_crosshair_change(RND_ACT_HIDLIB, rnd_true);
+		rnd_hid_notify_crosshair_change(RND_ACT_DESIGN, rnd_true);
 	}
 	RND_ACT_IRES(0);
 	return 0;
