@@ -4,6 +4,7 @@
  *  pcb-rnd, interactive printed circuit board design
  *  (this file is based on PCB, interactive printed circuit board design)
  *  Copyright (C) 1994,1995,1996 Thomas Nau
+ *  Copyright (C) 2023 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -87,7 +88,7 @@ do { \
 } while(0)
 
 #define TEST_OBJST(objst, req_flag, locality, obj, locked_obj) \
-	TEST_OBJST_(objst, req_flag, locality, obj, locked_obj, return RND_R_DIR_NOT_FOUND)
+	TEST_OBJST_(objst, req_flag, locality, obj, locked_obj, return rnd_RTREE_DIR_NOT_FOUND_CONT)
 
 struct ans_info {
 	void **ptr1, **ptr2, **ptr3;
@@ -101,20 +102,20 @@ struct ans_info {
 /* ---------------------------------------------------------------------------
  * searches a padstack
  */
-static rnd_r_dir_t padstack_callback(const rnd_box_t *box, void *cl)
+static rnd_rtree_dir_t padstack_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
 	struct ans_info *i = (struct ans_info *) cl;
-	pcb_pstk_t *ps = (pcb_pstk_t *) box;
+	pcb_pstk_t *ps = (pcb_pstk_t *)obj;
 	pcb_data_t *pdata;
 
 	TEST_OBJST(i->objst, i->req_flag, g, ps, ps);
 
 	if (!pcb_is_point_in_pstk(PosX, PosY, SearchRadius, ps, NULL))
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 	if ((i->on_current) && (pcb_pstk_shape_at(PCB, ps, PCB_CURRLAYER(PCB)) == NULL) && (!pcb_pstk_bb_drills(PCB, ps, PCB_CURRLAYER(PCB)->meta.real.grp, NULL)))
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 	if ((i->on_lyt != 0) && (pcb_pstk_shape(ps, i->on_lyt, 0) == NULL))
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 	*i->ptr2 = *i->ptr3 = ps;
 	assert(ps->parent_type == PCB_PARENT_DATA);
 	pdata = ps->parent.data;
@@ -122,7 +123,7 @@ static rnd_r_dir_t padstack_callback(const rnd_box_t *box, void *cl)
 		*i->ptr1 = pdata->parent.subc; /* padstack of a subcircuit */
 	else
 		*i->ptr1 = ps; /* padstack on a board (e.g. via) */
-	return RND_R_DIR_CANCEL; /* found, stop searching */
+	return rnd_RTREE_DIR_FOUND_STOP; /* found, stop searching */
 }
 
 static rnd_bool SearchPadstackByLocation(unsigned long objst, unsigned long req_flag, pcb_pstk_t **ps, pcb_pstk_t **Dummy1, pcb_pstk_t **Dummy2, int on_current, pcb_layer_type_t on_lyt)
@@ -141,9 +142,7 @@ static rnd_bool SearchPadstackByLocation(unsigned long objst, unsigned long req_
 	info.on_current = on_current;
 	info.on_lyt = on_lyt;
 
-	if (rnd_r_search(PCB->Data->padstack_tree, &SearchBox, NULL, padstack_callback, &info, NULL) != RND_R_DIR_NOT_FOUND)
-		return rnd_true;
-	return rnd_false;
+	return (rnd_rtree_search_any(PCB->Data->padstack_tree, (rnd_rtree_box_t *)&SearchBox, NULL, padstack_callback, &info, NULL) & rnd_RTREE_DIR_FOUND);
 }
 
 /* ---------------------------------------------------------------------------
@@ -158,19 +157,19 @@ struct line_info {
 };
 
 
-static rnd_r_dir_t line_callback(const rnd_box_t * box, void *cl)
+static rnd_rtree_dir_t line_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
 	struct line_info *i = (struct line_info *) cl;
-	pcb_line_t *l = (pcb_line_t *) box;
+	pcb_line_t *l = (pcb_line_t *)obj;
 
 	TEST_OBJST(i->objst, i->req_flag, l, l, l);
 
 	if (!pcb_is_point_in_line(PosX, PosY, SearchRadius, (pcb_any_line_t *)l))
-		return RND_R_DIR_NOT_FOUND;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 	*i->Line = l;
 	*i->Point = (rnd_point_t *) l;
 
-	return RND_R_DIR_CANCEL; /* found what we were looking for */
+	return rnd_RTREE_DIR_FOUND_STOP; /* found what we were looking for */
 }
 
 
@@ -184,15 +183,12 @@ static rnd_bool SearchLineByLocation(unsigned long objst, unsigned long req_flag
 	info.req_flag = req_flag;
 
 	*Layer = SearchLayer;
-	if (rnd_r_search(SearchLayer->line_tree, &SearchBox, NULL, line_callback, &info, NULL) != RND_R_DIR_NOT_FOUND)
-		return rnd_true;
-
-	return rnd_false;
+	return (rnd_rtree_search_any(SearchLayer->line_tree, (rnd_rtree_box_t *)&SearchBox, NULL, line_callback, &info, NULL) & rnd_RTREE_DIR_FOUND);
 }
 
-static rnd_r_dir_t rat_callback(const rnd_box_t * box, void *cl)
+static rnd_rtree_dir_t rat_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
-	pcb_line_t *line = (pcb_line_t *) box;
+	pcb_line_t *line = (pcb_line_t *)obj;
 	struct ans_info *i = (struct ans_info *) cl;
 
 	TEST_OBJST(i->objst, i->req_flag, l, line, line);
@@ -201,9 +197,9 @@ static rnd_r_dir_t rat_callback(const rnd_box_t * box, void *cl)
 			(rnd_distance(line->Point1.X, line->Point1.Y, PosX, PosY) <=
 			 line->Thickness * 2 + SearchRadius) : pcb_is_point_on_line(PosX, PosY, SearchRadius, line)) {
 		*i->ptr1 = *i->ptr2 = *i->ptr3 = line;
-		return RND_R_DIR_CANCEL;
+		return rnd_RTREE_DIR_FOUND_STOP;
 	}
-	return RND_R_DIR_NOT_FOUND;
+	return rnd_RTREE_DIR_NOT_FOUND_CONT;
 }
 
 /* ---------------------------------------------------------------------------
@@ -219,9 +215,7 @@ static rnd_bool SearchRatLineByLocation(unsigned long objst, unsigned long req_f
 	info.objst = objst;
 	info.req_flag = req_flag;
 
-	if (rnd_r_search(PCB->Data->rat_tree, &SearchBox, NULL, rat_callback, &info, NULL) != RND_R_DIR_NOT_FOUND)
-		return rnd_true;
-	return rnd_false;
+	return (rnd_rtree_search_any(PCB->Data->rat_tree, (rnd_rtree_box_t *)&SearchBox, NULL, rat_callback, &info, NULL) & rnd_RTREE_DIR_FOUND);
 }
 
 /* ---------------------------------------------------------------------------
@@ -234,18 +228,18 @@ struct arc_info {
 	double least;
 };
 
-static rnd_r_dir_t arc_callback(const rnd_box_t * box, void *cl)
+static rnd_rtree_dir_t arc_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
 	struct arc_info *i = (struct arc_info *) cl;
-	pcb_arc_t *a = (pcb_arc_t *) box;
+	pcb_arc_t *a = (pcb_arc_t *)obj;
 
 	TEST_OBJST(i->objst, i->req_flag, l, a, a);
 
 	if (!pcb_is_point_on_arc(PosX, PosY, SearchRadius, a))
-		return 0;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 	*i->Arc = a;
 	*i->Dummy = a;
-	return RND_R_DIR_CANCEL; /* found */
+	return rnd_RTREE_DIR_FOUND_STOP;
 }
 
 
@@ -259,9 +253,7 @@ static rnd_bool SearchArcByLocation(unsigned long objst, unsigned long req_flag,
 	info.req_flag = req_flag;
 
 	*Layer = SearchLayer;
-	if (rnd_r_search(SearchLayer->arc_tree, &SearchBox, NULL, arc_callback, &info, NULL) != RND_R_DIR_NOT_FOUND)
-		return rnd_true;
-	return rnd_false;
+	return (rnd_rtree_search_any(SearchLayer->arc_tree, (rnd_rtree_box_t *)&SearchBox, NULL, arc_callback, &info, NULL) & rnd_RTREE_DIR_FOUND);
 }
 
 /* ---------------------------------------------------------------------------
@@ -274,10 +266,10 @@ struct gfx_info {
 	int level;
 };
 
-static rnd_r_dir_t gfx_callback(const rnd_box_t *box, void *cl)
+static rnd_rtree_dir_t gfx_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
 	struct gfx_info *i = (struct gfx_info *)cl;
-	pcb_gfx_t *g = (pcb_gfx_t *)box;
+	pcb_gfx_t *g = (pcb_gfx_t *)obj;
 
 	TEST_OBJST(i->objst, i->req_flag, l, g, g);
 
@@ -286,10 +278,10 @@ static rnd_r_dir_t gfx_callback(const rnd_box_t *box, void *cl)
 	if ((i->level > 0) && g->render_under) return 0;
 
 	if (!pcb_is_point_in_gfx(PosX, PosY, SearchRadius, g))
-		return 0;
+		return rnd_RTREE_DIR_NOT_FOUND_CONT;
 	*i->Gfx = g;
 	*i->Dummy = g;
-	return RND_R_DIR_CANCEL; /* found */
+	return rnd_RTREE_DIR_FOUND_STOP;
 }
 
 /* level: -1 returns only "render_under", +1 returns only render-above, 0
@@ -305,23 +297,21 @@ static rnd_bool SearchGfxByLocation(unsigned long objst, unsigned long req_flag,
 	info.level = level;
 
 	*Layer = SearchLayer;
-	if (rnd_r_search(SearchLayer->gfx_tree, &SearchBox, NULL, gfx_callback, &info, NULL) != RND_R_DIR_NOT_FOUND)
-		return rnd_true;
-	return rnd_false;
+	return (rnd_rtree_search_any(SearchLayer->gfx_tree, (rnd_rtree_box_t *)&SearchBox, NULL, gfx_callback, &info, NULL) & rnd_RTREE_DIR_FOUND);
 }
 
-static rnd_r_dir_t text_callback(const rnd_box_t * box, void *cl)
+static rnd_rtree_dir_t text_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
-	pcb_text_t *text = (pcb_text_t *) box;
-	struct ans_info *i = (struct ans_info *) cl;
+	pcb_text_t *text = (pcb_text_t *)obj;
+	struct ans_info *i = (struct ans_info *)cl;
 
 	TEST_OBJST(i->objst, i->req_flag, l, text, text);
 
 	if (PCB_POINT_IN_BOX(PosX, PosY, &text->BoundingBox)) {
 		*i->ptr2 = *i->ptr3 = text;
-		return RND_R_DIR_CANCEL; /* found */
+		return rnd_RTREE_DIR_FOUND_STOP;
 	}
-	return RND_R_DIR_NOT_FOUND;
+	return rnd_RTREE_DIR_NOT_FOUND_CONT;
 }
 
 /* ---------------------------------------------------------------------------
@@ -337,26 +327,24 @@ static rnd_bool SearchTextByLocation(unsigned long objst, unsigned long req_flag
 	info.objst = objst;
 	info.req_flag = req_flag;
 
-	if (rnd_r_search(SearchLayer->text_tree, &SearchBox, NULL, text_callback, &info, NULL) != RND_R_DIR_NOT_FOUND)
-		return rnd_true;
-	return rnd_false;
+	return (rnd_rtree_search_any(SearchLayer->text_tree, (rnd_rtree_box_t *)&SearchBox, NULL, text_callback, &info, NULL) & rnd_RTREE_DIR_FOUND);
 }
 
-static rnd_r_dir_t polygon_callback(const rnd_box_t * box, void *cl)
+static rnd_rtree_dir_t polygon_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
-	pcb_poly_t *polygon = (pcb_poly_t *) box;
-	struct ans_info *i = (struct ans_info *) cl;
+	pcb_poly_t *polygon = (pcb_poly_t *)obj;
+	struct ans_info *i = (struct ans_info *)cl;
 
 	TEST_OBJST(i->objst, i->req_flag, l, polygon, polygon);
 
 	if (polygon->Clipped == NULL)
-		return RND_R_DIR_NOT_FOUND; /* polygon cleared out of existence */
+		return rnd_RTREE_DIR_NOT_FOUND_CONT; /* polygon cleared out of existence */
 
 	if (pcb_poly_is_point_in_p(PosX, PosY, SearchRadius, polygon)) {
 		*i->ptr2 = *i->ptr3 = polygon;
-		return RND_R_DIR_CANCEL; /* found */
+		return rnd_RTREE_DIR_FOUND_STOP; /* found */
 	}
-	return RND_R_DIR_NOT_FOUND;
+	return rnd_RTREE_DIR_NOT_FOUND_CONT;
 }
 
 
@@ -373,16 +361,14 @@ static rnd_bool SearchPolygonByLocation(unsigned long objst, unsigned long req_f
 	info.objst = objst;
 	info.req_flag = req_flag;
 
-	if (rnd_r_search(SearchLayer->polygon_tree, &SearchBox, NULL, polygon_callback, &info, NULL) != RND_R_DIR_NOT_FOUND)
-		return rnd_true;
-	return rnd_false;
+	return (rnd_rtree_search_any(SearchLayer->polygon_tree, (rnd_rtree_box_t *)&SearchBox, NULL, polygon_callback, &info, NULL) & rnd_RTREE_DIR_FOUND);
 }
 
-static rnd_r_dir_t linepoint_callback(const rnd_box_t * b, void *cl)
+static rnd_rtree_dir_t linepoint_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
-	pcb_line_t *line = (pcb_line_t *) b;
+	pcb_line_t *line = (pcb_line_t *) obj;
 	struct line_info *i = (struct line_info *) cl;
-	rnd_r_dir_t ret_val = RND_R_DIR_NOT_FOUND;
+	rnd_rtree_dir_t ret_val = rnd_RTREE_DIR_NOT_FOUND_CONT;
 	double d;
 
 	TEST_OBJST(i->objst, i->req_flag, l, line, line);
@@ -393,7 +379,7 @@ static rnd_r_dir_t linepoint_callback(const rnd_box_t * b, void *cl)
 		i->least = d;
 		*i->Line = line;
 		*i->Point = &line->Point1;
-		ret_val = RND_R_DIR_FOUND_CONTINUE;
+		ret_val = rnd_RTREE_DIR_FOUND_CONT;
 	}
 
 	d = rnd_distance(PosX, PosY, line->Point2.X, line->Point2.Y);
@@ -401,17 +387,17 @@ static rnd_r_dir_t linepoint_callback(const rnd_box_t * b, void *cl)
 		i->least = d;
 		*i->Line = line;
 		*i->Point = &line->Point2;
-		ret_val = RND_R_DIR_FOUND_CONTINUE;
+		ret_val = rnd_RTREE_DIR_FOUND_CONT;
 	}
 	return ret_val;
 }
 
-static rnd_r_dir_t arcpoint_callback(const rnd_box_t * b, void *cl)
+static rnd_rtree_dir_t arcpoint_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
 	rnd_box_t ab;
-	pcb_arc_t *arc = (pcb_arc_t *) b;
+	pcb_arc_t *arc = (pcb_arc_t *)obj;
 	struct arc_info *i = (struct arc_info *) cl;
-	rnd_r_dir_t ret_val = RND_R_DIR_NOT_FOUND;
+	rnd_rtree_dir_t ret_val = rnd_RTREE_DIR_NOT_FOUND_CONT;
 	double d;
 
 	TEST_OBJST(i->objst, i->req_flag, l, arc, arc);
@@ -425,7 +411,7 @@ static rnd_r_dir_t arcpoint_callback(const rnd_box_t * b, void *cl)
 		i->least = d;
 		*i->Arc = arc;
 		*i->arc_pt = pcb_arc_start_ptr;
-		ret_val = RND_R_DIR_FOUND_CONTINUE;
+		ret_val = rnd_RTREE_DIR_FOUND_CONT;
 	}
 
 	d = rnd_distance(PosX, PosY, ab.X2, ab.Y2);
@@ -433,7 +419,7 @@ static rnd_r_dir_t arcpoint_callback(const rnd_box_t * b, void *cl)
 		i->least = d;
 		*i->Arc = arc;
 		*i->arc_pt = pcb_arc_end_ptr;
-		ret_val = RND_R_DIR_FOUND_CONTINUE;
+		ret_val = rnd_RTREE_DIR_FOUND_CONT;
 	}
 	return ret_val;
 }
@@ -452,9 +438,7 @@ static rnd_bool SearchLinePointByLocation(unsigned long objst, unsigned long req
 	info.objst = objst;
 	info.req_flag = req_flag;
 
-	if (rnd_r_search(SearchLayer->line_tree, &SearchBox, NULL, linepoint_callback, &info, NULL))
-		return rnd_true;
-	return rnd_false;
+	return (rnd_rtree_search_any(SearchLayer->line_tree, (rnd_rtree_box_t *)&SearchBox, NULL, linepoint_callback, &info, NULL) & rnd_RTREE_DIR_FOUND);
 }
 
 /* ---------------------------------------------------------------------------
@@ -471,9 +455,7 @@ static rnd_bool SearchArcPointByLocation(unsigned long objst, unsigned long req_
 	info.objst = objst;
 	info.req_flag = req_flag;
 
-	if (rnd_r_search(SearchLayer->arc_tree, &SearchBox, NULL, arcpoint_callback, &info, NULL))
-		return rnd_true;
-	return rnd_false;
+	return (rnd_rtree_search_any(SearchLayer->arc_tree, (rnd_rtree_box_t *)&SearchBox, NULL, arcpoint_callback, &info, NULL) & rnd_RTREE_DIR_FOUND);
 }
 
 /* ---------------------------------------------------------------------------
@@ -490,9 +472,9 @@ typedef struct {
 	rnd_point_t **Point;
 } ptcb_t;
 
-static rnd_r_dir_t polypoint_callback(const rnd_box_t *box, void *cl)
+static rnd_rtree_dir_t polypoint_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
-	pcb_poly_t *polygon = (pcb_poly_t *)box;
+	pcb_poly_t *polygon = (pcb_poly_t *)obj;
 	ptcb_t *ctx = (ptcb_t *)cl;
 	double d;
 	pcb_data_t *dt;
@@ -501,11 +483,11 @@ static rnd_r_dir_t polypoint_callback(const rnd_box_t *box, void *cl)
 	if ((dt != NULL) && (dt->parent_type == PCB_PARENT_SUBC)) {
 		/* do not find subc part poly points if not explicitly requested */
 		if (!(ctx->Type & PCB_OBJ_SUBC_PART))
-			return RND_R_DIR_NOT_FOUND;
+			return rnd_RTREE_DIR_NOT_FOUND_CONT;
 
 		/* don't find subc poly points even as subc part unless we are editing a subc */
 		if (!PCB->loose_subc)
-			return RND_R_DIR_NOT_FOUND;
+			return rnd_RTREE_DIR_NOT_FOUND_CONT;
 	}
 
 	PCB_POLY_POINT_LOOP(polygon);
@@ -520,7 +502,7 @@ static rnd_r_dir_t polypoint_callback(const rnd_box_t *box, void *cl)
 	}
 	PCB_END_LOOP;
 
-	return RND_R_DIR_NOT_FOUND;
+	return rnd_RTREE_DIR_NOT_FOUND_CONT;
 }
 
 static rnd_bool SearchPointByLocation(unsigned long Type, unsigned long objst, unsigned long req_flag, pcb_layer_t ** Layer, pcb_poly_t ** Polygon, rnd_point_t ** Point)
@@ -534,7 +516,7 @@ static rnd_bool SearchPointByLocation(unsigned long Type, unsigned long objst, u
 	ctx.found = rnd_false;;
 	ctx.least = SearchRadius + PCB_MAX_POLYGON_POINT_DISTANCE;
 	ctx.least = ctx.least * ctx.least;
-	rnd_r_search(SearchLayer->polygon_tree, &SearchBox, NULL, polypoint_callback, &ctx, NULL);
+	rnd_rtree_search_any(SearchLayer->polygon_tree, (rnd_rtree_box_t *)&SearchBox, NULL, polypoint_callback, &ctx, NULL);
 
 	if (ctx.found)
 		return rnd_true;
@@ -555,9 +537,9 @@ typedef struct {
 	rnd_point_t **Point;
 } gfxptcb_t;
 
-static rnd_r_dir_t gfxpoint_callback(const rnd_box_t *box, void *cl)
+static rnd_rtree_dir_t gfxpoint_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
-	pcb_gfx_t *gfx = (pcb_gfx_t *)box;
+	pcb_gfx_t *gfx = (pcb_gfx_t *)obj;
 	gfxptcb_t *ctx = (gfxptcb_t *)cl;
 	double d;
 	pcb_data_t *dt;
@@ -567,11 +549,11 @@ static rnd_r_dir_t gfxpoint_callback(const rnd_box_t *box, void *cl)
 	if ((dt != NULL) && (dt->parent_type == PCB_PARENT_SUBC)) {
 		/* do not find subc part poly points if not explicitly requested */
 		if (!(ctx->Type & PCB_OBJ_SUBC_PART))
-			return RND_R_DIR_NOT_FOUND;
+			return rnd_RTREE_DIR_NOT_FOUND_CONT;
 
 		/* don't find subc poly points even as subc part unless we are editing a subc */
 		if (!PCB->loose_subc)
-			return RND_R_DIR_NOT_FOUND;
+			return rnd_RTREE_DIR_NOT_FOUND_CONT;
 	}
 
 	for(n = 0; n < 4; n++) {
@@ -584,7 +566,7 @@ static rnd_r_dir_t gfxpoint_callback(const rnd_box_t *box, void *cl)
 		}
 	}
 
-	return RND_R_DIR_NOT_FOUND;
+	return rnd_RTREE_DIR_NOT_FOUND_CONT;
 }
 
 static rnd_bool SearchGfxPointByLocation(unsigned long Type, unsigned long objst, unsigned long req_flag, pcb_layer_t **Layer, pcb_gfx_t **gfx, rnd_point_t **Point)
@@ -598,7 +580,7 @@ static rnd_bool SearchGfxPointByLocation(unsigned long Type, unsigned long objst
 	ctx.found = rnd_false;;
 	ctx.least = SearchRadius + PCB_MAX_POLYGON_POINT_DISTANCE;
 	ctx.least = ctx.least * ctx.least;
-	rnd_r_search(SearchLayer->gfx_tree, &SearchBox, NULL, gfxpoint_callback, &ctx, NULL);
+	rnd_rtree_search_any(SearchLayer->gfx_tree, (rnd_rtree_box_t *)&SearchBox, NULL, gfxpoint_callback, &ctx, NULL);
 
 	if (ctx.found)
 		return rnd_true;
@@ -606,9 +588,9 @@ static rnd_bool SearchGfxPointByLocation(unsigned long Type, unsigned long objst
 }
 
 
-static rnd_r_dir_t subc_callback(const rnd_box_t *box, void *cl)
+static rnd_rtree_dir_t subc_callback(void *cl, void *obj, const rnd_rtree_box_t *box)
 {
-	pcb_subc_t *subc = (pcb_subc_t *) box;
+	pcb_subc_t *subc = (pcb_subc_t *)obj;
 	struct ans_info *i = (struct ans_info *) cl;
 	double newarea;
 	int subc_on_bottom = 0, front;
@@ -624,17 +606,17 @@ static rnd_r_dir_t subc_callback(const rnd_box_t *box, void *cl)
 			/* extended objects are special case: only the origin should be clickable
 			   to avoid problems with large extended objects that cover the board */
 			if ((PosX < ox) || (PosX > ox + PCB_SUBC_AUX_UNIT) || (PosY < oy) || (PosY > oy + PCB_SUBC_AUX_UNIT))
-				return RND_R_DIR_NOT_FOUND;
+				return rnd_RTREE_DIR_NOT_FOUND_CONT;
 		}
 		/* use the subcircuit with the smallest bounding box */
 		newarea = (subc->BoundingBox.X2 - subc->BoundingBox.X1) * (double) (subc->BoundingBox.Y2 - subc->BoundingBox.Y1);
 		if (newarea < i->area) {
 			i->area = newarea;
 			*i->ptr1 = *i->ptr2 = *i->ptr3 = subc;
-			return RND_R_DIR_FOUND_CONTINUE;
+			return rnd_RTREE_DIR_FOUND_CONT;
 		}
 	}
-	return RND_R_DIR_NOT_FOUND;
+	return rnd_RTREE_DIR_NOT_FOUND_CONT;
 }
 
 
@@ -656,9 +638,7 @@ SearchSubcByLocation(unsigned long objst, unsigned long req_flag, pcb_subc_t **s
 	info.objst = objst;
 	info.req_flag = req_flag;
 
-	if (rnd_r_search(PCB->Data->subc_tree, &SearchBox, NULL, subc_callback, &info, NULL))
-		return rnd_true;
-	return rnd_false;
+	return (rnd_rtree_search_any(PCB->Data->subc_tree, (rnd_rtree_box_t *)&SearchBox, NULL, subc_callback, &info, NULL) & rnd_RTREE_DIR_FOUND);
 }
 
 /* find the first floater on any layer */
@@ -1932,11 +1912,11 @@ int pcb_lines_intersect(rnd_coord_t ax1, rnd_coord_t ay1, rnd_coord_t ax2, rnd_c
 	return pcb_lines_intersect_at(ax1, ay1, ax2, ay2, bx1, by1, bx2, by2, NULL, NULL);
 }
 
-rnd_r_dir_t pcb_search_data_by_loc(pcb_data_t *data, pcb_objtype_t type, const rnd_box_t *query_box, rnd_r_dir_t (*cb_)(void *closure, pcb_any_obj_t *obj, void *box), void *closure)
+rnd_rtree_dir_t pcb_search_data_by_loc(pcb_data_t *data, pcb_objtype_t type, const rnd_box_t *query_box, rnd_rtree_dir_t (*cb_)(void *closure, pcb_any_obj_t *obj, void *box), void *closure)
 {
 	pcb_layer_t *ly;
 	rnd_layer_id_t lid;
-	rnd_r_dir_t res;
+	rnd_rtree_dir_t res;
 	const rnd_rtree_box_t *query = (const rnd_rtree_box_t *)query_box;
 	rnd_rtree_dir_t (*cb)(void *, void *, const rnd_rtree_box_t *) = (rnd_rtree_dir_t(*)(void *, void *, const rnd_rtree_box_t *))cb_;
 
