@@ -34,17 +34,19 @@
 #include "global_typedefs.h"
 
 void pcb_undo_move_obj_to_remove(int, void *, void *, void *);
-void pcb_undo_add_obj_to_remove_point(int, void *, void *, pcb_cardinal_t);
+void pcb_undo_add_obj_to_remove_point(int, void *, void *, rnd_cardinal_t);
 void pcb_undo_add_obj_to_insert_point(int, void *, void *, void *);
 void pcb_undo_add_obj_to_remove_contour(int, pcb_layer_t *, pcb_poly_t *);
 void pcb_undo_add_obj_to_insert_contour(int, pcb_layer_t *, pcb_poly_t *);
-void pcb_undo_add_obj_to_move(int, void *, void *, void *, pcb_coord_t, pcb_coord_t);
+void pcb_undo_add_obj_to_move(int, void *, void *, void *, rnd_coord_t, rnd_coord_t);
 void pcb_undo_add_obj_to_change_name(int, void *, void *, void *, char *);
 void pcb_undo_add_obj_to_change_pinnum(int, void *, void *, void *, char *);
-void pcb_undo_add_obj_to_rotate90(int, void *, void *, void *, pcb_coord_t, pcb_coord_t, unsigned int);
-void pcb_undo_add_obj_to_rotate(int Type, void *Ptr1, void *Ptr2, void *Ptr3, pcb_coord_t CenterX, pcb_coord_t CenterY, pcb_angle_t angle);
+void pcb_undo_add_obj_to_rotate90(int, void *, void *, void *, rnd_coord_t, rnd_coord_t, unsigned int);
+void pcb_undo_add_obj_to_rotate(int Type, void *Ptr1, void *Ptr2, void *Ptr3, rnd_coord_t CenterX, rnd_coord_t CenterY, rnd_angle_t angle);
 void pcb_undo_add_obj_to_create(int, void *, void *, void *);
-void pcb_undo_add_subc_to_otherside(int Type, void *Ptr1, void *Ptr2, void *Ptr3, pcb_coord_t yoff);
+void pcb_undo_add_obj_to_create_noclear(int Type, void *Ptr1, void *Ptr2, void *Ptr3);
+void pcb_undo_add_obj_to_create_nocreate(int, void *, void *, void *);
+void pcb_undo_add_subc_to_otherside(int Type, void *Ptr1, void *Ptr2, void *Ptr3, rnd_coord_t yoff);
 void pcb_undo_add_obj_to_move_to_layer(int, void *, void *, void *);
 void pcb_undo_add_obj_to_flag(void *obj);
 void pcb_undo_add_obj_to_size(int, void *, void *, void *);
@@ -53,8 +55,7 @@ void pcb_undo_add_obj_to_rot(int Type, void *ptr1, void *ptr2, void *ptr3);
 void pcb_undo_add_obj_to_clear_size(int, void *, void *, void *);
 void pcb_undo_add_obj_to_change_angles(int, void *, void *, void *);
 void pcb_undo_add_obj_to_change_radii(int, void *, void *, void *);
-void pcb_undo_add_obj_to_clear_poly(int, void *, void *, void *, pcb_bool);
-void pcb_undo_add_layer_move(int, int, int);
+void pcb_undo_add_obj_to_clear_poly(int, void *, void *, void *, rnd_bool);
 
 /* ---------------------------------------------------------------------------
  * define supported types of undo operations
@@ -75,7 +76,6 @@ typedef enum {
 	PCB_UNDO_CHANGESIZE        = 0x000800, /* change size of object */
 	PCB_UNDO_CHANGECLEARSIZE   = 0x004000, /* change clearance size */
 	PCB_UNDO_CHANGEANGLES      = 0x010000, /* change arc angles */
-	PCB_UNDO_LAYERMOVE         = 0x020000, /* layer new/delete/move */
 	PCB_UNDO_CLEAR             = 0x040000, /* clear/restore to polygons */
 	PCB_UNDO_CHANGERADII       = 0x200000, /* change arc radii */
 	PCB_UNDO_OTHERSIDE         = 0x400000, /* change side of board (subcircuit) */
