@@ -27,7 +27,7 @@
  */
 
 #include <librnd/core/safe_fs.h>
-#include <librnd/core/hid_dad.h>
+#include <librnd/hid/hid_dad.h>
 
 typedef struct {
 	RND_DAD_DECL_NOINIT(dlg)
@@ -192,11 +192,11 @@ static void save_conf_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *
 {
 	FILE *f;
 	char *fname;
-	rnd_hidlib_t *hl = rnd_gui->get_dad_hidlib(hid_ctx);
+	rnd_design_t *hl = rnd_gui->get_dad_design(hid_ctx);
 
 	fname = rnd_hid_fileselect(rnd_gui, "Save autoroute settings to...",
 		"Pick a file for saving autoroute settings to.\n",
-		"autoroute.cfg.lht", ".lht", NULL, "ar_extern", RND_HID_FSD_MAY_NOT_EXIST, NULL);
+		"autoroute.cfg.lht", ".lht", NULL, "ar_extern", 0, NULL);
 
 	if (fname == NULL)
 		return;
@@ -216,7 +216,7 @@ static void load_conf_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *
 {
 	FILE *f;
 	char *fname;
-	rnd_hidlib_t *hl = rnd_gui->get_dad_hidlib(hid_ctx);
+	rnd_design_t *hl = rnd_gui->get_dad_design(hid_ctx);
 
 	fname = rnd_hid_fileselect(rnd_gui, "Load autoroute settings from...",
 		"Pick a file for loading autoroute settings from.\n",
