@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  pcb-rnd, interactive printed circuit board design
- *  Copyright (C) 2019 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2019,2023 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -59,6 +59,17 @@ fgw_error_t pcb_act_Load(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	static char *last_footprint = NULL, *last_layout = NULL, *last_netlist = NULL;
 	const char *function = "Layout";
 	char *name = NULL;
+	static const char *flt_any[] = {"*", "*.*", NULL};
+	static const char *pat_lht[] = {"*.rp", "*.lht", NULL};
+	static const char *pat_pcb[] = {"*.pcb", NULL};
+	static const char *pat_tdx[] = {"*.tdx", NULL};
+	static const rnd_hid_fsd_filter_t flt_brd[] = {
+			{"rp/lihata", "rp/lihata", pat_lht},
+			{"pcb",       "pcb", pat_pcb},
+			{"tEDAx",     "tEDAx", pat_tdx},
+			{"all",       NULL, flt_any},
+			{NULL, NULL, NULL}
+		};
 
 	if (last_footprint == NULL)  last_footprint = dup_cwd();
 	if (last_layout == NULL)     last_layout = dup_cwd();
@@ -75,9 +86,9 @@ fgw_error_t pcb_act_Load(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	else if ((rnd_strcasecmp(function, "FootprintToBuffer") == 0) || (rnd_strcasecmp(function, "ElementToBuffer") == 0))
 		name = rnd_hid_fileselect(rnd_gui, "Load footprint to buffer", "Import footprint from file", last_footprint, NULL, NULL, "footprint", RND_HID_FSD_READ, NULL);
 	else if (rnd_strcasecmp(function, "LayoutToBuffer") == 0)
-		name = rnd_hid_fileselect(rnd_gui, "Load layout to buffer", "load layout (board) to buffer", last_layout, NULL, NULL, "board", RND_HID_FSD_READ, NULL);
+		name = rnd_hid_fileselect(rnd_gui, "Load layout to buffer", "load layout (board) to buffer", last_layout, NULL, flt_brd, "board", RND_HID_FSD_READ, NULL);
 	else if (rnd_strcasecmp(function, "Layout") == 0)
-		name = rnd_hid_fileselect(rnd_gui, "Load layout file", "load layout (board) as board to edit", last_layout, NULL, NULL, "board", RND_HID_FSD_READ, NULL);
+		name = rnd_hid_fileselect(rnd_gui, "Load layout file", "load layout (board) as board to edit", last_layout, NULL, flt_brd, "board", RND_HID_FSD_READ, NULL);
 	else {
 		rnd_message(RND_MSG_ERROR, "Invalid subcommand for Load(): '%s'\n", function);
 		RND_ACT_IRES(1);
@@ -385,9 +396,10 @@ static void setup_fmt_sub(save_t *save, pcb_plug_iot_t save_type)
 
 const char pcb_acts_Save[] = 
 	"Save()\n"
-	"Save(Layout|LayoutAs)\n"
-	"Save(AllConnections|AllUnusedPins|ElementConnections)\n"
-	"Save(PasteBuffer)\n"
+	"Save(Layout)\n"
+	"Save(LayoutAs, [path])\n"
+	"Save(AllConnections|AllUnusedPins|ElementConnections, [path])\n"
+	"Save(PasteBuffer, [path])\n"
 	"Save(DialogByPattern, pcb|footprint|font|buffer, none|board|fp, prompt, [default_pattern])";
 const char pcb_acth_Save[] = "Save layout data to a user-selected file.";
 /* DOC: save.html */
