@@ -39,7 +39,9 @@ typedef struct {
 	pcb_board_t *pcb;
 	rnd_box_t bb_prv;
 	int wnetlist, wprev, wtermlist;
-	int wsel, wunsel, wfind, wunfind, wrats, wnorats, wallrats, wnoallrats, wripup, waddrats, wrename, wmerge, wattr, wnlcalc, wnlon, wnloff;
+	int wsel, wunsel, wfind, wunfind, wrats, wnorats, wallrats, wnoallrats;
+	int wripup, waddrats, wrename, wmerge, wattr, wnlcalc, wnlon, wnloff;
+	int wbrkconn, wdel;
 	void *last_selected_row;
 	double last_selected_time;
 	int active; /* already open - allow only one instance */
@@ -243,6 +245,48 @@ static void netlist_update_len_by_name(netlist_ctx_t *ctx, const char *name)
 }
 #endif
 
+static void brkconn_button_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
+{
+	netlist_ctx_t *ctx = caller_data;
+	rnd_hid_attribute_t *nltree = &ctx->dlg[ctx->wnetlist];
+	rnd_hid_attribute_t *tmtree = &ctx->dlg[ctx->wtermlist];
+	rnd_hid_row_t *row_net  = rnd_dad_tree_get_selected(nltree);
+	rnd_hid_row_t *row_term = rnd_dad_tree_get_selected(tmtree);
+
+	if ((row_net == NULL) || (row_term == NULL)) {
+		rnd_message(RND_MSG_ERROR, "Select a terminal in the dialog box's \"terminal list\" first\n");
+		return;
+	}
+
+	pcb_ratspatch_append_optimize(ctx->pcb, RATP_DEL_CONN, row_term->cell[0], row_net->cell[0], NULL);
+	pcb_ratspatch_make_edited(ctx->pcb);
+	pcb_netlist_changed(0);
+}
+
+static void addconn_button_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
+{
+	netlist_ctx_t *ctx = caller_data;
+	rnd_hid_attribute_t *nltree = &ctx->dlg[ctx->wnetlist];
+	rnd_hid_row_t *row_net = rnd_dad_tree_get_selected(nltree);
+	pcb_net_t *net;
+
+	if (row_net == NULL) {
+		rnd_message(RND_MSG_ERROR, "Select a net in the netlist window first\n");
+		return;
+	}
+
+	net = pcb_net_get(ctx->pcb, &ctx->pcb->netlist[PCB_NETLIST_EDITED], row_net->cell[0], 0);
+	if (net == NULL) {
+		rnd_message(RND_MSG_ERROR, "Internal error: selected net doesn't exist\n");
+		return;
+	}
+
+	if (pcb_ratspatch_addconn_selected(ctx->pcb, ctx->pcb->Data, net) == 0) {
+		rnd_message(RND_MSG_ERROR, "No terminals selected on board or all selected terminals are already on the netlist\n");
+		return;
+	}
+}
+
 static void netlist_button_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
 {
 	netlist_ctx_t *ctx = caller_data;
@@ -288,6 +332,8 @@ static void netlist_button_cb(void *hid_ctx, void *caller_data, rnd_hid_attribut
 		rnd_actionva(&ctx->pcb->hidlib, "netlist", "AddRats", name, NULL);
 	else if (w == ctx->wrename)
 		rnd_actionva(&ctx->pcb->hidlib, "netlist", "rename", name, NULL);
+	else if (w == ctx->wdel)
+		rnd_actionva(&ctx->pcb->hidlib, "netlist", "remove", name, NULL);
 	else if (w == ctx->wmerge)
 		rnd_actionva(&ctx->pcb->hidlib, "netlist", "merge", name, NULL);
 	else if (w == ctx->wattr) {
@@ -457,6 +503,17 @@ static void pcb_dlg_netlist(pcb_board_t *pcb)
 							netlist_ctx.wtermlist = RND_DAD_CURRENT(netlist_ctx.dlg);
 							RND_DAD_TREE_SET_CB(netlist_ctx.dlg, selected_cb, termlist_row_selected);
 							RND_DAD_TREE_SET_CB(netlist_ctx.dlg, ctx, &netlist_ctx);
+
+						RND_DAD_BEGIN_HBOX(netlist_ctx.dlg); /* connection buttons */
+							RND_DAD_BUTTON(netlist_ctx.dlg, "break conn");
+								RND_DAD_CHANGE_CB(netlist_ctx.dlg, brkconn_button_cb);
+								netlist_ctx.wbrkconn = RND_DAD_CURRENT(netlist_ctx.dlg);
+								RND_DAD_HELP(netlist_ctx.dlg, "Remove terminal (selected in the above list) from the net\nRemember removal on the back annotation netlist patch");
+							RND_DAD_BUTTON(netlist_ctx.dlg, "add conn");
+								RND_DAD_CHANGE_CB(netlist_ctx.dlg, addconn_button_cb);
+								netlist_ctx.wbrkconn = RND_DAD_CURRENT(netlist_ctx.dlg);
+								RND_DAD_HELP(netlist_ctx.dlg, "Add terminals (selected on the board) to the net\nAlso add them on the back annotation netlist patch");
+						RND_DAD_END(netlist_ctx.dlg);
 					RND_DAD_END(netlist_ctx.dlg);
 				RND_DAD_END(netlist_ctx.dlg);
 			RND_DAD_END(netlist_ctx.dlg);
@@ -513,36 +570,44 @@ static void pcb_dlg_netlist(pcb_board_t *pcb)
 					RND_DAD_CHANGE_CB(netlist_ctx.dlg, netlist_button_cb);
 					RND_DAD_HELP(netlist_ctx.dlg, "remove all objects (except for terminals) on the selected network");
 			RND_DAD_END(netlist_ctx.dlg);
-			RND_DAD_BEGIN_VBOX(netlist_ctx.dlg);
-				RND_DAD_BUTTON(netlist_ctx.dlg, "rename");
-					netlist_ctx.wrename = RND_DAD_CURRENT(netlist_ctx.dlg);
-					RND_DAD_CHANGE_CB(netlist_ctx.dlg, netlist_button_cb);
-					RND_DAD_HELP(netlist_ctx.dlg, "change the name of the selected network");
+
+			RND_DAD_BEGIN_VBOX(netlist_ctx.dlg); /* back annotated changes */
+				RND_DAD_COMPFLAG(netlist_ctx.dlg, RND_HATF_FRAME);
+				RND_DAD_BEGIN_HBOX(netlist_ctx.dlg);
+					RND_DAD_BUTTON(netlist_ctx.dlg, "rename");
+						netlist_ctx.wrename = RND_DAD_CURRENT(netlist_ctx.dlg);
+						RND_DAD_CHANGE_CB(netlist_ctx.dlg, netlist_button_cb);
+						RND_DAD_HELP(netlist_ctx.dlg, "change the name of the selected network\nBack annotated.");
+					RND_DAD_BUTTON(netlist_ctx.dlg, "del");
+						netlist_ctx.wdel = RND_DAD_CURRENT(netlist_ctx.dlg);
+						RND_DAD_CHANGE_CB(netlist_ctx.dlg, netlist_button_cb);
+						RND_DAD_HELP(netlist_ctx.dlg, "Remove network\nBack annotated.");
+				RND_DAD_END(netlist_ctx.dlg);
 				RND_DAD_BEGIN_HBOX(netlist_ctx.dlg);
 					RND_DAD_BUTTON(netlist_ctx.dlg, "merge");
 						netlist_ctx.wmerge = RND_DAD_CURRENT(netlist_ctx.dlg);
 						RND_DAD_CHANGE_CB(netlist_ctx.dlg, netlist_button_cb);
-					RND_DAD_HELP(netlist_ctx.dlg, "merge the selected network into another network");
+					RND_DAD_HELP(netlist_ctx.dlg, "merge the selected network into another (named) network\nBack annotated.");
 					RND_DAD_BUTTON(netlist_ctx.dlg, "attr");
 						netlist_ctx.wattr = RND_DAD_CURRENT(netlist_ctx.dlg);
 						RND_DAD_CHANGE_CB(netlist_ctx.dlg, netlist_button_cb);
-						RND_DAD_HELP(netlist_ctx.dlg, "change attributes of the selected network");
+						RND_DAD_HELP(netlist_ctx.dlg, "change attributes of the selected network\nBack annotated.");
 				RND_DAD_END(netlist_ctx.dlg);
 			RND_DAD_END(netlist_ctx.dlg);
 		RND_DAD_END(netlist_ctx.dlg);
 
 		RND_DAD_BEGIN_HBOX(netlist_ctx.dlg); /* bottom button row */
-			RND_DAD_LABEL(netlist_ctx.dlg, "Claim:");
-				RND_DAD_HELP(netlist_ctx.dlg, "Map galvanic connection of existing objects and convert them into a network on the netlist");
+			RND_DAD_LABEL(netlist_ctx.dlg, "Claim:"); /* back annotated */
+				RND_DAD_HELP(netlist_ctx.dlg, "Map galvanic connection of existing objects and convert them into a network on the netlist\nBack annotated.");
 			RND_DAD_BUTTON(netlist_ctx.dlg, "click");
 				RND_DAD_CHANGE_CB(netlist_ctx.dlg, netlist_claim_obj_cb);
-				RND_DAD_HELP(netlist_ctx.dlg, "Click on an object to create a new network of all connected objects from there");
+				RND_DAD_HELP(netlist_ctx.dlg, "Click on an object to create a new network of all connected objects from there\nBack annotated.");
 			RND_DAD_BUTTON(netlist_ctx.dlg, "select");
 				RND_DAD_CHANGE_CB(netlist_ctx.dlg, netlist_claim_sel_cb);
-				RND_DAD_HELP(netlist_ctx.dlg, "create a new network of all selected objects");
+				RND_DAD_HELP(netlist_ctx.dlg, "create a new network of all selected objects\nBack annotated.");
 			RND_DAD_BUTTON(netlist_ctx.dlg, "found");
 				RND_DAD_CHANGE_CB(netlist_ctx.dlg, netlist_claim_fnd_cb);
-				RND_DAD_HELP(netlist_ctx.dlg, "create a new network of all found (green) objects");
+				RND_DAD_HELP(netlist_ctx.dlg, "create a new network of all found (green) objects\nBack annotated.");
 
 			RND_DAD_LABEL(netlist_ctx.dlg, "Len:");
 			RND_DAD_BUTTON(netlist_ctx.dlg, "calc");
