@@ -35,6 +35,7 @@
 #include <liblihata/dom.h>
 #include <liblihata/tree.h>
 #include <librnd/core/actions.h>
+#include <librnd/hid/hid.h>
 #include <librnd/core/anyload.h>
 #include <librnd/core/plugins.h>
 #include <librnd/core/error.h>
@@ -43,6 +44,8 @@
 #include <librnd/core/list_conf.h>
 #include <librnd/core/compat_misc.h>
 #include <librnd/core/safe_fs.h>
+#include <librnd/core/hidlib.h>
+#include <librnd/core/conf_multi.h>
 
 #include "board.h"
 #include "drc.h"
@@ -244,7 +247,7 @@ static int *drc_get_disable(const char *name)
 
 static int drc_query_progress(pcb_qry_exec_t *ec, long at, long total);
 
-static void pcb_drc_query(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void pcb_drc_query(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	pcb_board_t *pcb = (pcb_board_t *)hidlib;
 	gdl_iterator_t it;
@@ -297,7 +300,7 @@ static void pcb_drc_query(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_e
 }
 
 static void drc_query_refresh_def(void);
-static void drc_query_defchg(rnd_conf_native_t *cfg, int v)
+static void drc_query_defchg(rnd_conf_native_t *cfg, int v, void *user_data)
 {
 	drc_query_refresh_def();
 }
@@ -305,12 +308,12 @@ static void drc_query_defchg(rnd_conf_native_t *cfg, int v)
 static vtp0_t free_drc_conf_nodes;
 static rnd_conf_native_t *nat_defs = NULL;
 static rnd_conf_native_t *nat_rules = NULL;
-static void drc_query_newconf(rnd_conf_native_t *cfg, rnd_conf_listitem_t *i)
+static void drc_query_newconf(rnd_conf_native_t *cfg, rnd_conf_listitem_t *i, void *user_data)
 {
 	if (nat_rules == NULL) {
 		if (strncmp(cfg->hash_path, DRC_CONF_PATH_RULES, strlen(DRC_CONF_PATH_RULES)-1) == 0) {
 			nat_rules = cfg;
-			nat_rules->gui_edit_act = "DrcQueryEditRule";
+			nat_rules->shared->gui_edit_act = "DrcQueryEditRule";
 		}
 	}
 
@@ -570,7 +573,7 @@ static int pcb_drc_query_def_by_name(const char *name, lht_node_t **nd_out, int
 }
 
 
-static int pcb_drc_query_clear(rnd_hidlib_t *hidlib, int is_rule, const char *src)
+static int pcb_drc_query_clear(rnd_design_t *hidlib, int is_rule, const char *src)
 {
 	const rnd_conflist_t *l = DRC_QUERY_RULE_OR_DEF(is_rule);
 	gdl_iterator_t it;
@@ -598,7 +601,7 @@ static int pcb_drc_query_clear(rnd_hidlib_t *hidlib, int is_rule, const char *sr
 	return -1;
 }
 
-static int pcb_drc_query_create(rnd_hidlib_t *hidlib, int is_rule, const char *rule)
+static int pcb_drc_query_create(rnd_design_t *hidlib, int is_rule, const char *rule)
 {
 	lht_node_t *nd;
 
@@ -610,7 +613,7 @@ static int pcb_drc_query_create(rnd_hidlib_t *hidlib, int is_rule, const char *r
 
 void d2() {}
 
-static int pcb_drc_query_set(rnd_hidlib_t *hidlib, int is_rule, const char *rule, const char *key, const char *val)
+static int pcb_drc_query_set(rnd_design_t *hidlib, int is_rule, const char *rule, const char *key, const char *val)
 {
 	lht_node_t *nd;
 
@@ -628,7 +631,7 @@ static int pcb_drc_query_set(rnd_hidlib_t *hidlib, int is_rule, const char *rule
 		if ((nat == NULL) || (nat->used == 0)) {
 			rnd_conf_listitem_t i = {0};
 			i.prop.src = nd;
-			drc_query_newconf(nat_defs, &i);
+			drc_query_newconf(nat_defs, &i, NULL);
 		}
 		free(path);
 	}
@@ -636,7 +639,7 @@ static int pcb_drc_query_set(rnd_hidlib_t *hidlib, int is_rule, const char *rule
 	return 0;
 }
 
-static int pcb_drc_query_remove(rnd_hidlib_t *hidlib, int is_rule, const char *name)
+static int pcb_drc_query_remove(rnd_design_t *hidlib, int is_rule, const char *name)
 {
 	const rnd_conflist_t *l = DRC_QUERY_RULE_OR_DEF(is_rule);
 	gdl_iterator_t it;
@@ -654,7 +657,7 @@ static int pcb_drc_query_remove(rnd_hidlib_t *hidlib, int is_rule, const char *n
 	return -1;
 }
 
-static int pcb_drc_query_get(rnd_hidlib_t *hidlib, int is_rule, const char *rule, const char *key, fgw_arg_t *res)
+static int pcb_drc_query_get(rnd_design_t *hidlib, int is_rule, const char *rule, const char *key, fgw_arg_t *res)
 {
 	lht_node_t *nd;
 
@@ -667,7 +670,7 @@ static int pcb_drc_query_get(rnd_hidlib_t *hidlib, int is_rule, const char *rule
 	return 0;
 }
 
-static int pcb_drc_query_get_rule_defs(rnd_hidlib_t *hidlib, const char *rule, fgw_arg_t *res)
+static int pcb_drc_query_get_rule_defs(rnd_design_t *hidlib, const char *rule, fgw_arg_t *res)
 {
 	htsi_t defs;
 	htsi_entry_t *e;
@@ -710,7 +713,7 @@ static const char pcb_acth_DrcQueryRuleMod[] = "Automated DRC rule editing (for
 static fgw_error_t pcb_act_DrcQueryRuleMod(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	const char *cmd, *target, *key = NULL, *val=NULL;
-	rnd_hidlib_t *hl = RND_ACT_HIDLIB;
+	rnd_design_t *hl = RND_ACT_DESIGN;
 	int resi = -1;
 
 	RND_ACT_CONVARG(1, FGW_STR, DrcQueryRuleMod, cmd = argv[1].val.str);
@@ -744,7 +747,7 @@ static const char pcb_acth_DrcQueryDefMod[] = "Automated DRC rule editing (for s
 static fgw_error_t pcb_act_DrcQueryDefMod(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	const char *cmd, *target, *key = NULL, *val=NULL;
-	rnd_hidlib_t *hl = RND_ACT_HIDLIB;
+	rnd_design_t *hl = RND_ACT_DESIGN;
 	int resi = -1;
 
 	RND_ACT_CONVARG(1, FGW_STR, DrcQueryDefMod, cmd = argv[1].val.str);
@@ -786,7 +789,7 @@ static fgw_error_t pcb_act_DrcQueryExport(fgw_arg_t *res, int argc, fgw_arg_t *a
 	int ires = 0;
 	const char *id, *fn = NULL, *fmt;
 	char *autofree = NULL;
-	rnd_hidlib_t *hl = RND_ACT_HIDLIB;
+	rnd_design_t *hl = RND_ACT_DESIGN;
 	const rnd_hid_fsd_filter_t *flt = init_flt(&fmt);
 
 	RND_ACT_CONVARG(1, FGW_STR, DrcQueryExport, id = argv[1].val.str);
@@ -831,7 +834,7 @@ static fgw_error_t pcb_act_DrcQueryImport(fgw_arg_t *res, int argc, fgw_arg_t *a
 	int ires = 0;
 	const char *fn = NULL, *fmt;
 	char *autofree = NULL;
-	rnd_hidlib_t *hl = RND_ACT_HIDLIB;
+	rnd_design_t *hl = RND_ACT_DESIGN;
 	FILE *f;
 	fgw_arg_t args[2], tpres;
 	const rnd_hid_fsd_filter_t *flt = init_flt(&fmt);
@@ -889,12 +892,12 @@ static rnd_action_t drc_query_action_list[] = {
 	{"DrcQueryImport", pcb_act_DrcQueryImport, pcb_acth_DrcQueryImport, pcb_acts_DrcQueryImport}
 };
 
-static int drc_query_anyload_subtree(const rnd_anyload_t *al, rnd_hidlib_t *hl, lht_node_t *root)
+static int drc_query_anyload_subtree(const rnd_anyload_t *al, rnd_design_t *hl, lht_node_t *root)
 {
 	return drc_query_lht_load_subtree(hl, root);
 }
 
-static int drc_query_anyload_file(const rnd_anyload_t *al, rnd_hidlib_t *hl, const char *filename, const char *type, lht_node_t *nd)
+static int drc_query_anyload_file(const rnd_anyload_t *al, rnd_design_t *hl, const char *filename, const char *type, lht_node_t *nd)
 {
 	if (strncmp(type, "pcb-rnd-drc-query", 17) == 0)
 		return drc_query_lht_load_rules(hl, filename);
@@ -913,8 +916,8 @@ void pplg_uninit_drc_query(void)
 	rnd_anyload_unreg_by_cookie(drc_query_cookie);
 	pcb_drc_impl_unreg(&drc_query_impl);
 	rnd_event_unbind_allcookie(drc_query_cookie);
-	rnd_conf_unreg_intern(drc_query_conf_internal);
-	rnd_conf_unreg_fields(DRC_CONF_PATH_PLUGIN);
+	rnd_conf_plug_unreg(DRC_CONF_PATH_PLUGIN, drc_query_conf_internal, drc_query_cookie);
+
 	rnd_conf_hid_unreg(drc_query_cookie);
 
 	for(n = 0; n < free_drc_conf_nodes.used; n++)
@@ -942,7 +945,7 @@ int pplg_init_drc_query(void)
 	cbs.new_hlist_item_post = drc_query_newconf;
 	cfgid = rnd_conf_hid_reg(drc_query_cookie, &cbs);
 
-	rnd_conf_reg_intern(drc_query_conf_internal);
+	rnd_conf_plug_reg(conf_drc_query, drc_query_conf_internal, drc_query_cookie);
 #define conf_reg(field,isarray,type_name,cpath,cname,desc,flags) \
 	rnd_conf_reg_field(conf_drc_query, field,isarray,type_name,cpath,cname,desc,flags);
 #include "drc_query_conf_fields.h"
