@@ -26,7 +26,7 @@
 
 #include "config.h"
 
-#include <librnd/core/hid_dad.h>
+#include <librnd/hid/hid_dad.h>
 #include "event.h"
 
 #define MAX_EXC 16
@@ -555,7 +555,7 @@ static char *pcb_openems_excitation_get(pcb_board_t *pcb, int fmt_matlab)
 	return excitations[exc_ctx.selected].get(exc_ctx.selected, fmt_matlab);
 }
 
-static void exc_ev_board_changed(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void exc_ev_board_changed(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	load_selector();
 	if (exc_ctx.active)
@@ -564,7 +564,7 @@ static void exc_ev_board_changed(rnd_hidlib_t *hidlib, void *user_data, int argc
 
 static void pcb_openems_excitation_init(void)
 {
-	rnd_event_bind(RND_EVENT_BOARD_CHANGED, exc_ev_board_changed, NULL, openems_cookie);
+	rnd_event_bind(RND_EVENT_DESIGN_SET_CURRENT, exc_ev_board_changed, NULL, openems_cookie);
 }
 
 static void pcb_openems_excitation_uninit(void)
