@@ -44,12 +44,12 @@
 #include "obj_subc_parent.h"
 #include "obj_pstk_inlines.h"
 
-#include <librnd/core/hid.h>
+#include <librnd/hid/hid.h>
 #include <librnd/core/actions.h>
-#include <librnd/core/hid_nogui.h>
+#include <librnd/hid/hid_nogui.h>
 #include "hid_cam.h"
-#include <librnd/core/hid_attrib.h>
-#include <librnd/core/hid_init.h>
+#include <librnd/hid/hid_attrib.h>
+#include <librnd/hid/hid_init.h>
 #include "../src_plugins/lib_polyhelp/topoly.h"
 #include "mesh.h"
 
@@ -166,14 +166,14 @@ static const rnd_export_opt_t openems_attribute_list[] = {
 
 static rnd_hid_attr_val_t openems_values[NUM_OPTIONS];
 
-static const rnd_export_opt_t *openems_get_export_options(rnd_hid_t *hid, int *n)
+static const rnd_export_opt_t *openems_get_export_options(rnd_hid_t *hid, int *n, rnd_design_t *dsg, void *appspec)
 {
 	const char *suffix = ".m";
 	pcb_mesh_t *mesh = pcb_mesh_get(MESH_NAME);
 	const char *val = openems_values[HA_openemsfile].str;
 
-	if ((PCB != NULL) && ((val == NULL) || (*val == '\0')))
-		pcb_derive_default_filename(PCB->hidlib.filename, &openems_values[HA_openemsfile], suffix);
+	if ((dsg != NULL) && ((val == NULL) || (*val == '\0')))
+		pcb_derive_default_filename(dsg->loadname, &openems_values[HA_openemsfile], suffix);
 
 	if (mesh != NULL) {
 		openems_values[HA_def_substrate_thick].crd = mesh->def_subs_thick;
@@ -361,10 +361,10 @@ TODO("layer: consider multiple outline layers instead")
 	}
 	else {
 		/* rectangular board size */
-		rnd_fprintf(ctx->f, "outline_xy(1, 1) = 0; outline_xy(2, 1) = 0;\n");
-		rnd_fprintf(ctx->f, "outline_xy(1, 2) = %mm; outline_xy(2, 2) = 0;\n", ctx->pcb->hidlib.size_x);
-		rnd_fprintf(ctx->f, "outline_xy(1, 3) = %mm; outline_xy(2, 3) = %mm;\n", ctx->pcb->hidlib.size_x, -ctx->pcb->hidlib.size_y);
-		rnd_fprintf(ctx->f, "outline_xy(1, 4) = 0; outline_xy(2, 4) = %mm;\n", -ctx->pcb->hidlib.size_y);
+		rnd_fprintf(ctx->f, "outline_xy(1, 1) = %mm; outline_xy(2, 1) = %mm;\n", ctx->pcb->hidlib.dwg.X1, -ctx->pcb->hidlib.dwg.Y1);
+		rnd_fprintf(ctx->f, "outline_xy(1, 2) = %mm; outline_xy(2, 2) = %mm;\n", ctx->pcb->hidlib.dwg.X2, -ctx->pcb->hidlib.dwg.Y1);
+		rnd_fprintf(ctx->f, "outline_xy(1, 3) = %mm; outline_xy(2, 3) = %mm;\n", ctx->pcb->hidlib.dwg.X2, -ctx->pcb->hidlib.dwg.Y2);
+		rnd_fprintf(ctx->f, "outline_xy(1, 4) = %mm; outline_xy(2, 4) = %mm;\n", ctx->pcb->hidlib.dwg.X1, -ctx->pcb->hidlib.dwg.Y2);
 	}
 
 	/* create all substrate layers using this polygon*/
@@ -617,7 +617,7 @@ static void openems_wr_m_sim(wctx_t *wctx)
 
 #include "openems_xml.c"
 
-static void openems_hid_export_to_file(const char *filename, FILE *the_file, FILE *fsim, rnd_hid_attr_val_t *options, int fmt_matlab)
+static void openems_hid_export_to_file(rnd_design_t *dsg, const char *filename, FILE *the_file, FILE *fsim, rnd_hid_attr_val_t *options, int fmt_matlab)
 {
 	rnd_hid_expose_ctx_t ctx;
 	wctx_t wctx;
@@ -626,15 +626,16 @@ static void openems_hid_export_to_file(const char *filename, FILE *the_file, FIL
 	wctx.filename = filename;
 	wctx.f = the_file;
 	wctx.fsim = fsim;
-	wctx.pcb = PCB;
+	wctx.pcb = (pcb_board_t *)dsg;
 	wctx.options = options;
 	wctx.fmt_matlab = fmt_matlab;
 	ems_ctx = &wctx;
 
-	ctx.view.X1 = 0;
-	ctx.view.Y1 = 0;
-	ctx.view.X2 = PCB->hidlib.size_x;
-	ctx.view.Y2 = PCB->hidlib.size_y;
+	ctx.design = dsg;
+	ctx.view.X1 = dsg->dwg.X1;
+	ctx.view.Y1 = dsg->dwg.Y1;
+	ctx.view.X2 = dsg->dwg.X2;
+	ctx.view.Y2 = dsg->dwg.Y2;
 
 	f = the_file;
 
@@ -664,7 +665,7 @@ static void openems_hid_export_to_file(const char *filename, FILE *the_file, FIL
 	rnd_conf_update(NULL, -1); /* restore forced sets */
 }
 
-static void openems_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
+static void openems_do_export(rnd_hid_t *hid, rnd_design_t *design, rnd_hid_attr_val_t *options, void *appspec)
 {
 	const char *filename;
 	char *runfn = NULL, *end;
@@ -675,7 +676,7 @@ static void openems_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 	openems_ovr = 0;
 
 	if (!options) {
-		openems_get_export_options(hid, 0);
+		openems_get_export_options(hid, 0, design, appspec);
 		options = openems_values;
 	}
 
@@ -702,7 +703,7 @@ static void openems_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 			end = runfn + len;
 		strcpy(end, ".sim.m");
 
-		fsim = rnd_fopen_askovr(&PCB->hidlib, runfn, "wb", &openems_ovr);
+		fsim = rnd_fopen_askovr(design, runfn, "wb", &openems_ovr);
 		if (fsim == NULL) {
 			perror(runfn);
 			return;
@@ -714,7 +715,7 @@ static void openems_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 
 	pcb_hid_save_and_show_layer_ons(save_ons);
 
-	openems_hid_export_to_file(filename, f, fsim, options, fmt_matlab);
+	openems_hid_export_to_file(design, filename, f, fsim, options, fmt_matlab);
 
 	pcb_hid_restore_layer_ons(save_ons);
 
@@ -731,7 +732,7 @@ static int openems_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv)
 	return rnd_hid_parse_command_line(argc, argv);
 }
 
-static int openems_set_layer_group(rnd_hid_t *hid, rnd_layergrp_id_t group, const char *purpose, int purpi, rnd_layer_id_t layer, unsigned int flags, int is_empty, rnd_xform_t **xform)
+static int openems_set_layer_group(rnd_hid_t *hid, rnd_design_t *design, rnd_layergrp_id_t group, const char *purpose, int purpi, rnd_layer_id_t layer, unsigned int flags, int is_empty, rnd_xform_t **xform)
 {
 	if (flags & PCB_LYT_COPPER) { /* export copper layers only */
 		ems_ctx->clayer = ems_ctx->lg_pcb2ems[group];
@@ -888,10 +889,6 @@ static void openems_draw_line(rnd_hid_gc_t gc, rnd_coord_t x1, rnd_coord_t y1, r
 	}
 }
 
-static void openems_set_crosshair(rnd_hid_t *hid, rnd_coord_t x, rnd_coord_t y, int a)
-{
-}
-
 static int openems_usage(rnd_hid_t *hid, const char *topic)
 {
 	fprintf(stderr, "\nopenems exporter command line arguments:\n\n");
@@ -946,7 +943,6 @@ int pplg_init_export_openems(void)
 	openems_hid.fill_polygon = openems_fill_polygon;
 	openems_hid.fill_polygon_offs = openems_fill_polygon_offs;
 	openems_hid.fill_rect = openems_fill_rect;
-	openems_hid.set_crosshair = openems_set_crosshair;
 	openems_hid.argument_array = openems_values;
 
 	openems_hid.usage = openems_usage;
