@@ -32,7 +32,7 @@
 #include <librnd/core/actions.h>
 #include "board.h"
 #include "data.h"
-#include <librnd/core/hid_dad.h>
+#include <librnd/hid/hid_dad.h>
 #include "event.h"
 #include <librnd/core/safe_fs.h>
 #include <librnd/core/rnd_printf.h>
@@ -589,7 +589,7 @@ static int mesh_sort(pcb_mesh_t *mesh, pcb_mesh_dir_t dir)
 
 	r = vtr0_alloc_append(&mesh->line[dir].dens, 1);
 	r->begin = mesh->line[dir].dens.array[vtr0_len(&mesh->line[dir].dens)-2].end;
-	r->end = (dir == PCB_MESH_HORIZONTAL) ? PCB->hidlib.size_y : PCB->hidlib.size_x;
+	r->end = (dir == PCB_MESH_HORIZONTAL) ? PCB->hidlib.dwg.Y2 : PCB->hidlib.dwg.X2;
 	r->data[0].c = mesh->dens_gap;
 
 
@@ -762,7 +762,7 @@ static int mesh_vis_xy(pcb_mesh_t *mesh, pcb_mesh_dir_t dir)
 	mesh_trace("\n");
 
 	mesh_trace("%s result:\n", dir == PCB_MESH_HORIZONTAL ? "horizontal" : "vertical");
-	end = (dir == PCB_MESH_HORIZONTAL) ? PCB->hidlib.size_x : PCB->hidlib.size_y;
+	end = (dir == PCB_MESH_HORIZONTAL) ? PCB->hidlib.dwg.X2 : PCB->hidlib.dwg.Y2;
 	for(n = 0; n < vtc0_len(&mesh->line[dir].result); n++) {
 		mesh_trace(" %mm", mesh->line[dir].result.array[n]);
 		mesh_draw_line(mesh, dir, mesh->line[dir].result.array[n], 0, end, RND_MM_TO_COORD(0.03));
@@ -776,9 +776,9 @@ static int mesh_vis_z(pcb_mesh_t *mesh)
 {
 	int n;
 	rnd_layergrp_id_t gid;
-	rnd_coord_t y0 = PCB->hidlib.size_y/3, y = y0, y2;
-	rnd_coord_t xl = PCB->hidlib.size_x/5; /* board left */
-	rnd_coord_t xr = PCB->hidlib.size_x/5*3; /* board right */
+	rnd_coord_t y0 = PCB->hidlib.dwg.Y2/3, y = y0, y2;
+	rnd_coord_t xl = PCB->hidlib.dwg.X2/5; /* board left */
+	rnd_coord_t xr = PCB->hidlib.dwg.X2/5*3; /* board right */
 	rnd_coord_t spen = RND_MM_TO_COORD(0.3), cpen = RND_MM_TO_COORD(0.2), mpen = RND_MM_TO_COORD(0.03);
 	int mag = 2;
 
@@ -804,7 +804,7 @@ static int mesh_vis_z(pcb_mesh_t *mesh)
 	for(n = 0; n < vtc0_len(&mesh->line[PCB_MESH_Z].result); n++) {
 		rnd_coord_t y = y0+mesh->line[PCB_MESH_Z].result.array[n]*mag;
 		mesh_trace(" %mm", y);
-		pcb_line_new(mesh->ui_layer_z, 0, y, PCB->hidlib.size_x, y, mpen, 0, pcb_no_flags());
+		pcb_line_new(mesh->ui_layer_z, 0, y, PCB->hidlib.dwg.X2, y, mpen, 0, pcb_no_flags());
 	}
 	mesh_trace("\n");
 	return 0;
@@ -926,7 +926,7 @@ static int mesh_auto_build(pcb_mesh_t *mesh, pcb_mesh_dir_t dir)
 	/* right edge, after the last known line */
 	if (!mesh->noimpl) {
 		c1 = mesh->line[dir].edge.array[vtc0_len(&mesh->line[dir].edge)-1];
-		c2 = (dir == PCB_MESH_HORIZONTAL) ? PCB->hidlib.size_y : PCB->hidlib.size_x;
+		c2 = (dir == PCB_MESH_HORIZONTAL) ? PCB->hidlib.dwg.Y2 : PCB->hidlib.dwg.X2;
 		mesh_find_range(&mesh->line[dir].dens, (c1+c2)/2, &d, &d1, &d2);
 		if (mesh->smooth)
 			mesh_auto_add_smooth(&mesh->line[dir].result, c1, c2, d1, d, d2);
@@ -991,7 +991,7 @@ static void ia_save_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *at
 
 	fname = rnd_hid_fileselect(rnd_gui, "Save mesh settings...",
 															"Picks file for saving mesh settings.\n",
-															default_file, ".lht", NULL, "mesh", RND_HID_FSD_MAY_NOT_EXIST, NULL);
+															default_file, ".lht", NULL, "mesh", 0, NULL);
 	if (fname == NULL)
 		return; /* cancel */
 
