@@ -41,7 +41,7 @@
 #include <genvector/gds_char.h>
 
 #include <librnd/core/math_helper.h>
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/rnd_conf.h>
 #include "board.h"
 #include "data.h"
 #include "draw.h"
@@ -54,11 +54,11 @@
 #include <librnd/core/safe_fs.h>
 #include "funchash_core.h"
 
-#include <librnd/core/hid.h>
-#include <librnd/core/hid_nogui.h>
+#include <librnd/hid/hid.h>
+#include <librnd/hid/hid_nogui.h>
 
-#include <librnd/core/hid_init.h>
-#include <librnd/core/hid_attrib.h>
+#include <librnd/hid/hid_init.h>
+#include <librnd/hid/hid_attrib.h>
 #include "hid_cam.h"
 
 #include <librnd/plugins/lib_exp_text/draw_svg.h>
@@ -142,28 +142,29 @@ Flip board, look at it from the bottom side
 
 static rnd_hid_attr_val_t svg_values[NUM_OPTIONS];
 
-static const rnd_export_opt_t *svg_get_export_options(rnd_hid_t *hid, int *n)
+static const rnd_export_opt_t *svg_get_export_options(rnd_hid_t *hid, int *n, rnd_design_t *dsg, void *appspec)
 {
 	const char *suffix = ".svg";
 	const char *val = svg_values[HA_svgfile].str;
 
-	if ((PCB != NULL) && ((val == NULL) || (*val == '\0')))
-		pcb_derive_default_filename(PCB->hidlib.filename, &svg_values[HA_svgfile], suffix);
+	if ((dsg != NULL) && ((val == NULL) || (*val == '\0')))
+		pcb_derive_default_filename(dsg->loadname, &svg_values[HA_svgfile], suffix);
 
 	if (n)
 		*n = NUM_OPTIONS;
 	return svg_attribute_list;
 }
 
-void svg_hid_export_to_file(FILE * the_file, rnd_hid_attr_val_t * options, rnd_xform_t *xform)
+static void svg_hid_export_to_file(rnd_design_t *dsg, FILE * the_file, rnd_hid_attr_val_t * options, rnd_xform_t *xform)
 {
 	static int saved_layer_stack[PCB_MAX_LAYER];
 	rnd_hid_expose_ctx_t ctx;
 
-	ctx.view.X1 = 0;
-	ctx.view.Y1 = 0;
-	ctx.view.X2 = PCB->hidlib.size_x;
-	ctx.view.Y2 = PCB->hidlib.size_y;
+	ctx.design = dsg;
+	ctx.view.X1 = dsg->dwg.X1;
+	ctx.view.Y1 = dsg->dwg.Y1;
+	ctx.view.X2 = dsg->dwg.X2;
+	ctx.view.Y2 = dsg->dwg.Y2;
 
 	pctx->outf = the_file;
 
@@ -215,7 +216,7 @@ void svg_hid_export_to_file(FILE * the_file, rnd_hid_attr_val_t * options, rnd_x
 	rnd_conf_update(NULL, -1); /* restore forced sets */
 }
 
-static void svg_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
+static void svg_do_export(rnd_hid_t *hid, rnd_design_t *design, rnd_hid_attr_val_t *options, void *appspec)
 {
 	const char *filename;
 	int save_ons[PCB_MAX_LAYER];
@@ -225,7 +226,7 @@ static void svg_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 	pctx->comp_cnt = 0;
 
 	if (!options) {
-		svg_get_export_options(hid, 0);
+		svg_get_export_options(hid, 0, design, appspec);
 		options = svg_values;
 	}
 
@@ -251,14 +252,14 @@ static void svg_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 	else
 		f = NULL;
 
-	rnd_svg_init(pctx, &PCB->hidlib, f, options[HA_opacity].lng, options[HA_flip].lng, options[HA_true_size].lng);
+	rnd_svg_init(pctx, design, f, options[HA_opacity].lng, options[HA_flip].lng, options[HA_true_size].lng);
 	if (f != NULL)
 		rnd_svg_header(pctx);
 
 	if (!svg_cam.active)
 		pcb_hid_save_and_show_layer_ons(save_ons);
 
-	svg_hid_export_to_file(pctx->outf, options, &xform);
+	svg_hid_export_to_file(design, pctx->outf, options, &xform);
 
 
 	if (!svg_cam.active)
@@ -290,7 +291,7 @@ static int svg_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv)
 	return rnd_hid_parse_command_line(argc, argv);
 }
 
-static int svg_set_layer_group(rnd_hid_t *hid, rnd_layergrp_id_t group, const char *purpose, int purpi, rnd_layer_id_t layer, unsigned int flags, int is_empty, rnd_xform_t **xform)
+static int svg_set_layer_group(rnd_hid_t *hid, rnd_design_t *design, rnd_layergrp_id_t group, const char *purpose, int purpi, rnd_layer_id_t layer, unsigned int flags, int is_empty, rnd_xform_t **xform)
 {
 	int is_our_mask = 0, is_our_silk = 0;
 
