@@ -27,10 +27,10 @@
 #include <librnd/core/safe_fs.h>
 #include <librnd/core/compat_fs.h>
 
-#include <librnd/core/hid.h>
-#include <librnd/core/hid_attrib.h>
-#include <librnd/core/hid_init.h>
-#include <librnd/core/hid_nogui.h>
+#include <librnd/hid/hid.h>
+#include <librnd/hid/hid_attrib.h>
+#include <librnd/hid/hid_init.h>
+#include <librnd/hid/hid_nogui.h>
 
 #include "../src_plugins/lib_vfs/lib_vfs.h"
 
@@ -38,7 +38,7 @@ static const char *export_vfs_fuse_cookie = "export_vfs_fuse HID";
 static int pcb_fuse_changed;
 static char fuse_cwd[RND_PATH_MAX];
 
-static const rnd_export_opt_t *export_vfs_fuse_get_export_options(rnd_hid_t *hid, int *n)
+static const rnd_export_opt_t *export_vfs_fuse_get_export_options(rnd_hid_t *hid, int *n, rnd_design_t *dsg, void *appspec)
 {
 	return 0;
 }
@@ -237,14 +237,14 @@ static int pcb_fuse_open(const char *path, struct fuse_file_info *fi)
 
 static void pcb_fuse_destroy(void *private_data)
 {
-	char *fn = PCB->hidlib.filename;
+	char *fn = PCB->hidlib.loadname;
 
 	if (!pcb_fuse_changed)
 		return;
 
 	/* pwd is lost during daemonisation */
-	if (!rnd_is_path_abs(PCB->hidlib.filename))
-		fn = rnd_strdup_printf("%s%c%s", fuse_cwd, RND_DIR_SEPARATOR_C, PCB->hidlib.filename);
+	if (!rnd_is_path_abs(PCB->hidlib.loadname))
+		fn = rnd_strdup_printf("%s%c%s", fuse_cwd, RND_DIR_SEPARATOR_C, PCB->hidlib.loadname);
 
 	if (pcb_save_pcb(fn, NULL) != 0) {
 		fprintf(stderr, "Failed to save the modified board file\n");
@@ -255,7 +255,7 @@ static void pcb_fuse_destroy(void *private_data)
 
 static char **fuse_argv;
 static int fuse_argc = 0;
-static void export_vfs_fuse_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
+static void export_vfs_fuse_do_export(rnd_hid_t *hid, rnd_design_t *design, rnd_hid_attr_val_t *options, void *appspec)
 {
 	static struct fuse_operations oper;
 
